# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_insurance_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_insurance_rpc.proto',
  package='injective_insurance_rpc',
  syntax='proto3',
  serialized_options=b'Z\032/injective_insurance_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&exchange/injective_insurance_rpc.proto\x12\x17injective_insurance_rpc\"\x0e\n\x0c\x46undsRequest\"F\n\rFundsResponse\x12\x35\n\x05\x66unds\x18\x01 \x03(\x0b\x32&.injective_insurance_rpc.InsuranceFund\"\xcb\x02\n\rInsuranceFund\x12\x15\n\rmarket_ticker\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rdeposit_denom\x18\x03 \x01(\t\x12\x18\n\x10pool_token_denom\x18\x04 \x01(\t\x12)\n!redemption_notice_period_duration\x18\x05 \x01(\x12\x12\x0f\n\x07\x62\x61lance\x18\x06 \x01(\t\x12\x13\n\x0btotal_share\x18\x07 \x01(\t\x12\x13\n\x0boracle_base\x18\x08 \x01(\t\x12\x14\n\x0coracle_quote\x18\t \x01(\t\x12\x13\n\x0boracle_type\x18\n \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x0b \x01(\x12\x12>\n\x12\x64\x65posit_token_meta\x18\x0c \x01(\x0b\x32\".injective_insurance_rpc.TokenMeta\"n\n\tTokenMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"P\n\x12RedemptionsRequest\x12\x10\n\x08redeemer\x18\x01 \x01(\t\x12\x18\n\x10redemption_denom\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"`\n\x13RedemptionsResponse\x12I\n\x14redemption_schedules\x18\x01 \x03(\x0b\x32+.injective_insurance_rpc.RedemptionSchedule\"\x84\x02\n\x12RedemptionSchedule\x12\x15\n\rredemption_id\x18\x01 \x01(\x04\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x10\n\x08redeemer\x18\x03 \x01(\t\x12!\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x12\x12\x19\n\x11redemption_amount\x18\x05 \x01(\t\x12\x18\n\x10redemption_denom\x18\x06 \x01(\t\x12\x14\n\x0crequested_at\x18\x07 \x01(\x12\x12\x18\n\x10\x64isbursed_amount\x18\x08 \x01(\t\x12\x17\n\x0f\x64isbursed_denom\x18\t \x01(\t\x12\x14\n\x0c\x64isbursed_at\x18\n \x01(\x12\x32\xd9\x01\n\x15InjectiveInsuranceRPC\x12V\n\x05\x46unds\x12%.injective_insurance_rpc.FundsRequest\x1a&.injective_insurance_rpc.FundsResponse\x12h\n\x0bRedemptions\x12+.injective_insurance_rpc.RedemptionsRequest\x1a,.injective_insurance_rpc.RedemptionsResponseB\x1cZ\x1a/injective_insurance_rpcpbb\x06proto3'
)




_FUNDSREQUEST = _descriptor.Descriptor(
  name='FundsRequest',
  full_name='injective_insurance_rpc.FundsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=81,
)


_FUNDSRESPONSE = _descriptor.Descriptor(
  name='FundsResponse',
  full_name='injective_insurance_rpc.FundsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='funds', full_name='injective_insurance_rpc.FundsResponse.funds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=153,
)


_INSURANCEFUND = _descriptor.Descriptor(
  name='InsuranceFund',
  full_name='injective_insurance_rpc.InsuranceFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ticker', full_name='injective_insurance_rpc.InsuranceFund.market_ticker', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_insurance_rpc.InsuranceFund.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit_denom', full_name='injective_insurance_rpc.InsuranceFund.deposit_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_token_denom', full_name='injective_insurance_rpc.InsuranceFund.pool_token_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_notice_period_duration', full_name='injective_insurance_rpc.InsuranceFund.redemption_notice_period_duration', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='injective_insurance_rpc.InsuranceFund.balance', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_share', full_name='injective_insurance_rpc.InsuranceFund.total_share', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective_insurance_rpc.InsuranceFund.oracle_base', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective_insurance_rpc.InsuranceFund.oracle_quote', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_insurance_rpc.InsuranceFund.oracle_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective_insurance_rpc.InsuranceFund.expiry', index=10,
      number=11, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit_token_meta', full_name='injective_insurance_rpc.InsuranceFund.deposit_token_meta', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=487,
)


_TOKENMETA = _descriptor.Descriptor(
  name='TokenMeta',
  full_name='injective_insurance_rpc.TokenMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='injective_insurance_rpc.TokenMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective_insurance_rpc.TokenMeta.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective_insurance_rpc.TokenMeta.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logo', full_name='injective_insurance_rpc.TokenMeta.logo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective_insurance_rpc.TokenMeta.decimals', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_insurance_rpc.TokenMeta.updated_at', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=599,
)


_REDEMPTIONSREQUEST = _descriptor.Descriptor(
  name='RedemptionsRequest',
  full_name='injective_insurance_rpc.RedemptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redeemer', full_name='injective_insurance_rpc.RedemptionsRequest.redeemer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_denom', full_name='injective_insurance_rpc.RedemptionsRequest.redemption_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective_insurance_rpc.RedemptionsRequest.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=681,
)


_REDEMPTIONSRESPONSE = _descriptor.Descriptor(
  name='RedemptionsResponse',
  full_name='injective_insurance_rpc.RedemptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redemption_schedules', full_name='injective_insurance_rpc.RedemptionsResponse.redemption_schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=779,
)


_REDEMPTIONSCHEDULE = _descriptor.Descriptor(
  name='RedemptionSchedule',
  full_name='injective_insurance_rpc.RedemptionSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redemption_id', full_name='injective_insurance_rpc.RedemptionSchedule.redemption_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective_insurance_rpc.RedemptionSchedule.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redeemer', full_name='injective_insurance_rpc.RedemptionSchedule.redeemer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claimable_redemption_time', full_name='injective_insurance_rpc.RedemptionSchedule.claimable_redemption_time', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_amount', full_name='injective_insurance_rpc.RedemptionSchedule.redemption_amount', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_denom', full_name='injective_insurance_rpc.RedemptionSchedule.redemption_denom', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_at', full_name='injective_insurance_rpc.RedemptionSchedule.requested_at', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disbursed_amount', full_name='injective_insurance_rpc.RedemptionSchedule.disbursed_amount', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disbursed_denom', full_name='injective_insurance_rpc.RedemptionSchedule.disbursed_denom', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disbursed_at', full_name='injective_insurance_rpc.RedemptionSchedule.disbursed_at', index=9,
      number=10, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=1042,
)

_FUNDSRESPONSE.fields_by_name['funds'].message_type = _INSURANCEFUND
_INSURANCEFUND.fields_by_name['deposit_token_meta'].message_type = _TOKENMETA
_REDEMPTIONSRESPONSE.fields_by_name['redemption_schedules'].message_type = _REDEMPTIONSCHEDULE
DESCRIPTOR.message_types_by_name['FundsRequest'] = _FUNDSREQUEST
DESCRIPTOR.message_types_by_name['FundsResponse'] = _FUNDSRESPONSE
DESCRIPTOR.message_types_by_name['InsuranceFund'] = _INSURANCEFUND
DESCRIPTOR.message_types_by_name['TokenMeta'] = _TOKENMETA
DESCRIPTOR.message_types_by_name['RedemptionsRequest'] = _REDEMPTIONSREQUEST
DESCRIPTOR.message_types_by_name['RedemptionsResponse'] = _REDEMPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['RedemptionSchedule'] = _REDEMPTIONSCHEDULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FundsRequest = _reflection.GeneratedProtocolMessageType('FundsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FUNDSREQUEST,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.FundsRequest)
  })
_sym_db.RegisterMessage(FundsRequest)

FundsResponse = _reflection.GeneratedProtocolMessageType('FundsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FUNDSRESPONSE,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.FundsResponse)
  })
_sym_db.RegisterMessage(FundsResponse)

InsuranceFund = _reflection.GeneratedProtocolMessageType('InsuranceFund', (_message.Message,), {
  'DESCRIPTOR' : _INSURANCEFUND,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.InsuranceFund)
  })
_sym_db.RegisterMessage(InsuranceFund)

TokenMeta = _reflection.GeneratedProtocolMessageType('TokenMeta', (_message.Message,), {
  'DESCRIPTOR' : _TOKENMETA,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.TokenMeta)
  })
_sym_db.RegisterMessage(TokenMeta)

RedemptionsRequest = _reflection.GeneratedProtocolMessageType('RedemptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSREQUEST,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.RedemptionsRequest)
  })
_sym_db.RegisterMessage(RedemptionsRequest)

RedemptionsResponse = _reflection.GeneratedProtocolMessageType('RedemptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSRESPONSE,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.RedemptionsResponse)
  })
_sym_db.RegisterMessage(RedemptionsResponse)

RedemptionSchedule = _reflection.GeneratedProtocolMessageType('RedemptionSchedule', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSCHEDULE,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.RedemptionSchedule)
  })
_sym_db.RegisterMessage(RedemptionSchedule)


DESCRIPTOR._options = None

_INJECTIVEINSURANCERPC = _descriptor.ServiceDescriptor(
  name='InjectiveInsuranceRPC',
  full_name='injective_insurance_rpc.InjectiveInsuranceRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1045,
  serialized_end=1262,
  methods=[
  _descriptor.MethodDescriptor(
    name='Funds',
    full_name='injective_insurance_rpc.InjectiveInsuranceRPC.Funds',
    index=0,
    containing_service=None,
    input_type=_FUNDSREQUEST,
    output_type=_FUNDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Redemptions',
    full_name='injective_insurance_rpc.InjectiveInsuranceRPC.Redemptions',
    index=1,
    containing_service=None,
    input_type=_REDEMPTIONSREQUEST,
    output_type=_REDEMPTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEINSURANCERPC)

DESCRIPTOR.services_by_name['InjectiveInsuranceRPC'] = _INJECTIVEINSURANCERPC

# @@protoc_insertion_point(module_scope)
