# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/ibc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmwasm/wasm/v1/ibc.proto',
  package='cosmwasm.wasm.v1',
  syntax='proto3',
  serialized_options=b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63osmwasm/wasm/v1/ibc.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\"\xb2\x01\n\nMsgIBCSend\x12*\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"\x12\x31\n\x0etimeout_height\x18\x04 \x01(\x04\x42\x19\xf2\xde\x1f\x15yaml:\"timeout_height\"\x12\x37\n\x11timeout_timestamp\x18\x05 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\"\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\"@\n\x12MsgIBCCloseChannel\x12*\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"B,Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_MSGIBCSEND = _descriptor.Descriptor(
  name='MsgIBCSend',
  full_name='cosmwasm.wasm.v1.MsgIBCSend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='cosmwasm.wasm.v1.MsgIBCSend.channel', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"source_channel\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_height', full_name='cosmwasm.wasm.v1.MsgIBCSend.timeout_height', index=1,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"timeout_height\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_timestamp', full_name='cosmwasm.wasm.v1.MsgIBCSend.timeout_timestamp', index=2,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"timeout_timestamp\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.MsgIBCSend.data', index=3,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=249,
)


_MSGIBCCLOSECHANNEL = _descriptor.Descriptor(
  name='MsgIBCCloseChannel',
  full_name='cosmwasm.wasm.v1.MsgIBCCloseChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='cosmwasm.wasm.v1.MsgIBCCloseChannel.channel', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"source_channel\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=315,
)

DESCRIPTOR.message_types_by_name['MsgIBCSend'] = _MSGIBCSEND
DESCRIPTOR.message_types_by_name['MsgIBCCloseChannel'] = _MSGIBCCLOSECHANNEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgIBCSend = _reflection.GeneratedProtocolMessageType('MsgIBCSend', (_message.Message,), {
  'DESCRIPTOR' : _MSGIBCSEND,
  '__module__' : 'cosmwasm.wasm.v1.ibc_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.MsgIBCSend)
  })
_sym_db.RegisterMessage(MsgIBCSend)

MsgIBCCloseChannel = _reflection.GeneratedProtocolMessageType('MsgIBCCloseChannel', (_message.Message,), {
  'DESCRIPTOR' : _MSGIBCCLOSECHANNEL,
  '__module__' : 'cosmwasm.wasm.v1.ibc_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.MsgIBCCloseChannel)
  })
_sym_db.RegisterMessage(MsgIBCCloseChannel)


DESCRIPTOR._options = None
_MSGIBCSEND.fields_by_name['channel']._options = None
_MSGIBCSEND.fields_by_name['timeout_height']._options = None
_MSGIBCSEND.fields_by_name['timeout_timestamp']._options = None
_MSGIBCCLOSECHANNEL.fields_by_name['channel']._options = None
# @@protoc_insertion_point(module_scope)
