# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/insurance/v1beta1/tx.proto',
  package='injective.insurance.v1beta1',
  syntax='proto3',
  serialized_options=b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$injective/insurance/v1beta1/tx.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x87\x02\n\x16MsgCreateInsuranceFund\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\x07 \x01(\x03\x12\x38\n\x0finitial_deposit\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgCreateInsuranceFundResponse\"n\n\rMsgUnderwrite\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgUnderwriteResponse\"t\n\x14MsgRequestRedemption\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgRequestRedemptionResponse2\x81\x03\n\x03Msg\x12\x87\x01\n\x13\x43reateInsuranceFund\x12\x33.injective.insurance.v1beta1.MsgCreateInsuranceFund\x1a;.injective.insurance.v1beta1.MsgCreateInsuranceFundResponse\x12l\n\nUnderwrite\x12*.injective.insurance.v1beta1.MsgUnderwrite\x1a\x32.injective.insurance.v1beta1.MsgUnderwriteResponse\x12\x81\x01\n\x11RequestRedemption\x12\x31.injective.insurance.v1beta1.MsgRequestRedemption\x1a\x39.injective.insurance.v1beta1.MsgRequestRedemptionResponseBQZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,])




_MSGCREATEINSURANCEFUND = _descriptor.Descriptor(
  name='MsgCreateInsuranceFund',
  full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.quote_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.oracle_base', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.oracle_quote', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.oracle_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.expiry', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_deposit', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.initial_deposit', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=426,
)


_MSGCREATEINSURANCEFUNDRESPONSE = _descriptor.Descriptor(
  name='MsgCreateInsuranceFundResponse',
  full_name='injective.insurance.v1beta1.MsgCreateInsuranceFundResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=460,
)


_MSGUNDERWRITE = _descriptor.Descriptor(
  name='MsgUnderwrite',
  full_name='injective.insurance.v1beta1.MsgUnderwrite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.insurance.v1beta1.MsgUnderwrite.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.MsgUnderwrite.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='injective.insurance.v1beta1.MsgUnderwrite.deposit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=572,
)


_MSGUNDERWRITERESPONSE = _descriptor.Descriptor(
  name='MsgUnderwriteResponse',
  full_name='injective.insurance.v1beta1.MsgUnderwriteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=597,
)


_MSGREQUESTREDEMPTION = _descriptor.Descriptor(
  name='MsgRequestRedemption',
  full_name='injective.insurance.v1beta1.MsgRequestRedemption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.insurance.v1beta1.MsgRequestRedemption.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.MsgRequestRedemption.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.insurance.v1beta1.MsgRequestRedemption.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=715,
)


_MSGREQUESTREDEMPTIONRESPONSE = _descriptor.Descriptor(
  name='MsgRequestRedemptionResponse',
  full_name='injective.insurance.v1beta1.MsgRequestRedemptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=747,
)

_MSGCREATEINSURANCEFUND.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_MSGCREATEINSURANCEFUND.fields_by_name['initial_deposit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGUNDERWRITE.fields_by_name['deposit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGREQUESTREDEMPTION.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgCreateInsuranceFund'] = _MSGCREATEINSURANCEFUND
DESCRIPTOR.message_types_by_name['MsgCreateInsuranceFundResponse'] = _MSGCREATEINSURANCEFUNDRESPONSE
DESCRIPTOR.message_types_by_name['MsgUnderwrite'] = _MSGUNDERWRITE
DESCRIPTOR.message_types_by_name['MsgUnderwriteResponse'] = _MSGUNDERWRITERESPONSE
DESCRIPTOR.message_types_by_name['MsgRequestRedemption'] = _MSGREQUESTREDEMPTION
DESCRIPTOR.message_types_by_name['MsgRequestRedemptionResponse'] = _MSGREQUESTREDEMPTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgCreateInsuranceFund = _reflection.GeneratedProtocolMessageType('MsgCreateInsuranceFund', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEINSURANCEFUND,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgCreateInsuranceFund)
  })
_sym_db.RegisterMessage(MsgCreateInsuranceFund)

MsgCreateInsuranceFundResponse = _reflection.GeneratedProtocolMessageType('MsgCreateInsuranceFundResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEINSURANCEFUNDRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgCreateInsuranceFundResponse)
  })
_sym_db.RegisterMessage(MsgCreateInsuranceFundResponse)

MsgUnderwrite = _reflection.GeneratedProtocolMessageType('MsgUnderwrite', (_message.Message,), {
  'DESCRIPTOR' : _MSGUNDERWRITE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgUnderwrite)
  })
_sym_db.RegisterMessage(MsgUnderwrite)

MsgUnderwriteResponse = _reflection.GeneratedProtocolMessageType('MsgUnderwriteResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGUNDERWRITERESPONSE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgUnderwriteResponse)
  })
_sym_db.RegisterMessage(MsgUnderwriteResponse)

MsgRequestRedemption = _reflection.GeneratedProtocolMessageType('MsgRequestRedemption', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTREDEMPTION,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgRequestRedemption)
  })
_sym_db.RegisterMessage(MsgRequestRedemption)

MsgRequestRedemptionResponse = _reflection.GeneratedProtocolMessageType('MsgRequestRedemptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTREDEMPTIONRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgRequestRedemptionResponse)
  })
_sym_db.RegisterMessage(MsgRequestRedemptionResponse)


DESCRIPTOR._options = None
_MSGCREATEINSURANCEFUND.fields_by_name['initial_deposit']._options = None
_MSGCREATEINSURANCEFUND._options = None
_MSGUNDERWRITE.fields_by_name['deposit']._options = None
_MSGUNDERWRITE._options = None
_MSGREQUESTREDEMPTION.fields_by_name['amount']._options = None
_MSGREQUESTREDEMPTION._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.insurance.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=750,
  serialized_end=1135,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateInsuranceFund',
    full_name='injective.insurance.v1beta1.Msg.CreateInsuranceFund',
    index=0,
    containing_service=None,
    input_type=_MSGCREATEINSURANCEFUND,
    output_type=_MSGCREATEINSURANCEFUNDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Underwrite',
    full_name='injective.insurance.v1beta1.Msg.Underwrite',
    index=1,
    containing_service=None,
    input_type=_MSGUNDERWRITE,
    output_type=_MSGUNDERWRITERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestRedemption',
    full_name='injective.insurance.v1beta1.Msg.RequestRedemption',
    index=2,
    containing_service=None,
    input_type=_MSGREQUESTREDEMPTION,
    output_type=_MSGREQUESTREDEMPTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
