# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/port/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/core/port/v1/query.proto',
  package='ibc.core.port.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cibc/core/port/v1/query.proto\x12\x10ibc.core.port.v1\x1a!ibc/core/channel/v1/channel.proto\"\xc1\x01\n\x16QueryAppVersionRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12,\n\x08ordering\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12\x37\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32!.ibc.core.channel.v1.Counterparty\x12\x18\n\x10proposed_version\x18\x05 \x01(\t\";\n\x17QueryAppVersionResponse\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t2l\n\x05Query\x12\x63\n\nAppVersion\x12(.ibc.core.port.v1.QueryAppVersionRequest\x1a).ibc.core.port.v1.QueryAppVersionResponse\"\x00\x42\x38Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/typesb\x06proto3'
  ,
  dependencies=[ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2.DESCRIPTOR,])




_QUERYAPPVERSIONREQUEST = _descriptor.Descriptor(
  name='QueryAppVersionRequest',
  full_name='ibc.core.port.v1.QueryAppVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.port.v1.QueryAppVersionRequest.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='ibc.core.port.v1.QueryAppVersionRequest.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordering', full_name='ibc.core.port.v1.QueryAppVersionRequest.ordering', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.port.v1.QueryAppVersionRequest.counterparty', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposed_version', full_name='ibc.core.port.v1.QueryAppVersionRequest.proposed_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=279,
)


_QUERYAPPVERSIONRESPONSE = _descriptor.Descriptor(
  name='QueryAppVersionResponse',
  full_name='ibc.core.port.v1.QueryAppVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.port.v1.QueryAppVersionResponse.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ibc.core.port.v1.QueryAppVersionResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=340,
)

_QUERYAPPVERSIONREQUEST.fields_by_name['ordering'].enum_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._ORDER
_QUERYAPPVERSIONREQUEST.fields_by_name['counterparty'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._COUNTERPARTY
DESCRIPTOR.message_types_by_name['QueryAppVersionRequest'] = _QUERYAPPVERSIONREQUEST
DESCRIPTOR.message_types_by_name['QueryAppVersionResponse'] = _QUERYAPPVERSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryAppVersionRequest = _reflection.GeneratedProtocolMessageType('QueryAppVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAPPVERSIONREQUEST,
  '__module__' : 'ibc.core.port.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.port.v1.QueryAppVersionRequest)
  })
_sym_db.RegisterMessage(QueryAppVersionRequest)

QueryAppVersionResponse = _reflection.GeneratedProtocolMessageType('QueryAppVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAPPVERSIONRESPONSE,
  '__module__' : 'ibc.core.port.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.port.v1.QueryAppVersionResponse)
  })
_sym_db.RegisterMessage(QueryAppVersionResponse)


DESCRIPTOR._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='ibc.core.port.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=342,
  serialized_end=450,
  methods=[
  _descriptor.MethodDescriptor(
    name='AppVersion',
    full_name='ibc.core.port.v1.Query.AppVersion',
    index=0,
    containing_service=None,
    input_type=_QUERYAPPVERSIONREQUEST,
    output_type=_QUERYAPPVERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)
