# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/msgs.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dinjective/peggy/v1/msgs.proto\x12\x12injective.peggy.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x19google/protobuf/any.proto\"X\n\x1bMsgSetOrchestratorAddresses\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\"%\n#MsgSetOrchestratorAddressesResponse\"_\n\x10MsgValsetConfirm\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t\"\x1a\n\x18MsgValsetConfirmResponse\"\x96\x01\n\x0cMsgSendToEth\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x65th_dest\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x33\n\nbridge_fee\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x16\n\x14MsgSendToEthResponse\"6\n\x0fMsgRequestBatch\x12\x14\n\x0corchestrator\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"\x19\n\x17MsgRequestBatchResponse\"u\n\x0fMsgConfirmBatch\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x02 \x01(\t\x12\x12\n\neth_signer\x18\x03 \x01(\t\x12\x14\n\x0corchestrator\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x05 \x01(\t\"\x19\n\x17MsgConfirmBatchResponse\"\xea\x01\n\x0fMsgDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x03 \x01(\t\x12>\n\x06\x61mount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x17\n\x0f\x65thereum_sender\x18\x05 \x01(\t\x12\x17\n\x0f\x63osmos_receiver\x18\x06 \x01(\t\x12\x14\n\x0corchestrator\x18\x07 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\t\"\x19\n\x17MsgDepositClaimResponse\"\x80\x01\n\x10MsgWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\x14\n\x0corchestrator\x18\x05 \x01(\t\"\x1a\n\x18MsgWithdrawClaimResponse\"\xb6\x01\n\x15MsgERC20DeployedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x14\n\x0c\x63osmos_denom\x18\x03 \x01(\t\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06symbol\x18\x06 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x07 \x01(\x04\x12\x14\n\x0corchestrator\x18\x08 \x01(\t\"\x1f\n\x1dMsgERC20DeployedClaimResponse\"<\n\x12MsgCancelSendToEth\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\"\x1c\n\x1aMsgCancelSendToEthResponse\"i\n\x1dMsgSubmitBadSignatureEvidence\x12%\n\x07subject\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tsignature\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\'\n%MsgSubmitBadSignatureEvidenceResponse\"\x81\x02\n\x15MsgValsetUpdatedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0cvalset_nonce\x18\x02 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x03 \x01(\x04\x12\x34\n\x07members\x18\x04 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x06 \x01(\t\x12\x14\n\x0corchestrator\x18\x07 \x01(\t\"\x1f\n\x1dMsgValsetUpdatedClaimResponse2\xc4\r\n\x03Msg\x12\x8f\x01\n\rValsetConfirm\x12$.injective.peggy.v1.MsgValsetConfirm\x1a,.injective.peggy.v1.MsgValsetConfirmResponse\"*\x82\xd3\xe4\x93\x02$\"\"/injective/peggy/v1/valset_confirm\x12\x80\x01\n\tSendToEth\x12 .injective.peggy.v1.MsgSendToEth\x1a(.injective.peggy.v1.MsgSendToEthResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1f/injective/peggy/v1/send_to_eth\x12\x8b\x01\n\x0cRequestBatch\x12#.injective.peggy.v1.MsgRequestBatch\x1a+.injective.peggy.v1.MsgRequestBatchResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/request_batch\x12\x8b\x01\n\x0c\x43onfirmBatch\x12#.injective.peggy.v1.MsgConfirmBatch\x1a+.injective.peggy.v1.MsgConfirmBatchResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/confirm_batch\x12\x8b\x01\n\x0c\x44\x65positClaim\x12#.injective.peggy.v1.MsgDepositClaim\x1a+.injective.peggy.v1.MsgDepositClaimResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/deposit_claim\x12\x8f\x01\n\rWithdrawClaim\x12$.injective.peggy.v1.MsgWithdrawClaim\x1a,.injective.peggy.v1.MsgWithdrawClaimResponse\"*\x82\xd3\xe4\x93\x02$\"\"/injective/peggy/v1/withdraw_claim\x12\xa3\x01\n\x11ValsetUpdateClaim\x12).injective.peggy.v1.MsgValsetUpdatedClaim\x1a\x31.injective.peggy.v1.MsgValsetUpdatedClaimResponse\"0\x82\xd3\xe4\x93\x02*\"(/injective/peggy/v1/valset_updated_claim\x12\xa4\x01\n\x12\x45RC20DeployedClaim\x12).injective.peggy.v1.MsgERC20DeployedClaim\x1a\x31.injective.peggy.v1.MsgERC20DeployedClaimResponse\"0\x82\xd3\xe4\x93\x02*\"(/injective/peggy/v1/erc20_deployed_claim\x12\xba\x01\n\x18SetOrchestratorAddresses\x12/.injective.peggy.v1.MsgSetOrchestratorAddresses\x1a\x37.injective.peggy.v1.MsgSetOrchestratorAddressesResponse\"4\x82\xd3\xe4\x93\x02.\",/injective/peggy/v1/set_orchestrator_address\x12\x99\x01\n\x0f\x43\x61ncelSendToEth\x12&.injective.peggy.v1.MsgCancelSendToEth\x1a..injective.peggy.v1.MsgCancelSendToEthResponse\".\x82\xd3\xe4\x93\x02(\"&/injective/peggy/v1/cancel_send_to_eth\x12\xc5\x01\n\x1aSubmitBadSignatureEvidence\x12\x31.injective.peggy.v1.MsgSubmitBadSignatureEvidence\x1a\x39.injective.peggy.v1.MsgSubmitBadSignatureEvidenceResponse\"9\x82\xd3\xe4\x93\x02\x33\"1/injective/peggy/v1/submit_bad_signature_evidenceBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_types__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_MSGSETORCHESTRATORADDRESSES = _descriptor.Descriptor(
  name='MsgSetOrchestratorAddresses',
  full_name='injective.peggy.v1.MsgSetOrchestratorAddresses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.peggy.v1.MsgSetOrchestratorAddresses.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgSetOrchestratorAddresses.orchestrator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eth_address', full_name='injective.peggy.v1.MsgSetOrchestratorAddresses.eth_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=284,
)


_MSGSETORCHESTRATORADDRESSESRESPONSE = _descriptor.Descriptor(
  name='MsgSetOrchestratorAddressesResponse',
  full_name='injective.peggy.v1.MsgSetOrchestratorAddressesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=323,
)


_MSGVALSETCONFIRM = _descriptor.Descriptor(
  name='MsgValsetConfirm',
  full_name='injective.peggy.v1.MsgValsetConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.MsgValsetConfirm.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgValsetConfirm.orchestrator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eth_address', full_name='injective.peggy.v1.MsgValsetConfirm.eth_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='injective.peggy.v1.MsgValsetConfirm.signature', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=420,
)


_MSGVALSETCONFIRMRESPONSE = _descriptor.Descriptor(
  name='MsgValsetConfirmResponse',
  full_name='injective.peggy.v1.MsgValsetConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=448,
)


_MSGSENDTOETH = _descriptor.Descriptor(
  name='MsgSendToEth',
  full_name='injective.peggy.v1.MsgSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.peggy.v1.MsgSendToEth.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eth_dest', full_name='injective.peggy.v1.MsgSendToEth.eth_dest', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.MsgSendToEth.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_fee', full_name='injective.peggy.v1.MsgSendToEth.bridge_fee', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=601,
)


_MSGSENDTOETHRESPONSE = _descriptor.Descriptor(
  name='MsgSendToEthResponse',
  full_name='injective.peggy.v1.MsgSendToEthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=625,
)


_MSGREQUESTBATCH = _descriptor.Descriptor(
  name='MsgRequestBatch',
  full_name='injective.peggy.v1.MsgRequestBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgRequestBatch.orchestrator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.peggy.v1.MsgRequestBatch.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=681,
)


_MSGREQUESTBATCHRESPONSE = _descriptor.Descriptor(
  name='MsgRequestBatchResponse',
  full_name='injective.peggy.v1.MsgRequestBatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=708,
)


_MSGCONFIRMBATCH = _descriptor.Descriptor(
  name='MsgConfirmBatch',
  full_name='injective.peggy.v1.MsgConfirmBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.MsgConfirmBatch.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.MsgConfirmBatch.token_contract', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eth_signer', full_name='injective.peggy.v1.MsgConfirmBatch.eth_signer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgConfirmBatch.orchestrator', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='injective.peggy.v1.MsgConfirmBatch.signature', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=827,
)


_MSGCONFIRMBATCHRESPONSE = _descriptor.Descriptor(
  name='MsgConfirmBatchResponse',
  full_name='injective.peggy.v1.MsgConfirmBatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=854,
)


_MSGDEPOSITCLAIM = _descriptor.Descriptor(
  name='MsgDepositClaim',
  full_name='injective.peggy.v1.MsgDepositClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.MsgDepositClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='injective.peggy.v1.MsgDepositClaim.block_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.MsgDepositClaim.token_contract', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.MsgDepositClaim.amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_sender', full_name='injective.peggy.v1.MsgDepositClaim.ethereum_sender', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_receiver', full_name='injective.peggy.v1.MsgDepositClaim.cosmos_receiver', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgDepositClaim.orchestrator', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.peggy.v1.MsgDepositClaim.data', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=1091,
)


_MSGDEPOSITCLAIMRESPONSE = _descriptor.Descriptor(
  name='MsgDepositClaimResponse',
  full_name='injective.peggy.v1.MsgDepositClaimResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1118,
)


_MSGWITHDRAWCLAIM = _descriptor.Descriptor(
  name='MsgWithdrawClaim',
  full_name='injective.peggy.v1.MsgWithdrawClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.MsgWithdrawClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='injective.peggy.v1.MsgWithdrawClaim.block_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.MsgWithdrawClaim.batch_nonce', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.MsgWithdrawClaim.token_contract', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgWithdrawClaim.orchestrator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1249,
)


_MSGWITHDRAWCLAIMRESPONSE = _descriptor.Descriptor(
  name='MsgWithdrawClaimResponse',
  full_name='injective.peggy.v1.MsgWithdrawClaimResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1277,
)


_MSGERC20DEPLOYEDCLAIM = _descriptor.Descriptor(
  name='MsgERC20DeployedClaim',
  full_name='injective.peggy.v1.MsgERC20DeployedClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.MsgERC20DeployedClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='injective.peggy.v1.MsgERC20DeployedClaim.block_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_denom', full_name='injective.peggy.v1.MsgERC20DeployedClaim.cosmos_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.MsgERC20DeployedClaim.token_contract', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='injective.peggy.v1.MsgERC20DeployedClaim.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.peggy.v1.MsgERC20DeployedClaim.symbol', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective.peggy.v1.MsgERC20DeployedClaim.decimals', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgERC20DeployedClaim.orchestrator', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1462,
)


_MSGERC20DEPLOYEDCLAIMRESPONSE = _descriptor.Descriptor(
  name='MsgERC20DeployedClaimResponse',
  full_name='injective.peggy.v1.MsgERC20DeployedClaimResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1464,
  serialized_end=1495,
)


_MSGCANCELSENDTOETH = _descriptor.Descriptor(
  name='MsgCancelSendToEth',
  full_name='injective.peggy.v1.MsgCancelSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='injective.peggy.v1.MsgCancelSendToEth.transaction_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.peggy.v1.MsgCancelSendToEth.sender', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1497,
  serialized_end=1557,
)


_MSGCANCELSENDTOETHRESPONSE = _descriptor.Descriptor(
  name='MsgCancelSendToEthResponse',
  full_name='injective.peggy.v1.MsgCancelSendToEthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1559,
  serialized_end=1587,
)


_MSGSUBMITBADSIGNATUREEVIDENCE = _descriptor.Descriptor(
  name='MsgSubmitBadSignatureEvidence',
  full_name='injective.peggy.v1.MsgSubmitBadSignatureEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='injective.peggy.v1.MsgSubmitBadSignatureEvidence.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='injective.peggy.v1.MsgSubmitBadSignatureEvidence.signature', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.peggy.v1.MsgSubmitBadSignatureEvidence.sender', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1589,
  serialized_end=1694,
)


_MSGSUBMITBADSIGNATUREEVIDENCERESPONSE = _descriptor.Descriptor(
  name='MsgSubmitBadSignatureEvidenceResponse',
  full_name='injective.peggy.v1.MsgSubmitBadSignatureEvidenceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1696,
  serialized_end=1735,
)


_MSGVALSETUPDATEDCLAIM = _descriptor.Descriptor(
  name='MsgValsetUpdatedClaim',
  full_name='injective.peggy.v1.MsgValsetUpdatedClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.valset_nonce', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.block_height', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.members', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_amount', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.reward_amount', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_token', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.reward_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator', full_name='injective.peggy.v1.MsgValsetUpdatedClaim.orchestrator', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1738,
  serialized_end=1995,
)


_MSGVALSETUPDATEDCLAIMRESPONSE = _descriptor.Descriptor(
  name='MsgValsetUpdatedClaimResponse',
  full_name='injective.peggy.v1.MsgValsetUpdatedClaimResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2028,
)

_MSGSENDTOETH.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGSENDTOETH.fields_by_name['bridge_fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGSUBMITBADSIGNATUREEVIDENCE.fields_by_name['subject'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MSGVALSETUPDATEDCLAIM.fields_by_name['members'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._BRIDGEVALIDATOR
DESCRIPTOR.message_types_by_name['MsgSetOrchestratorAddresses'] = _MSGSETORCHESTRATORADDRESSES
DESCRIPTOR.message_types_by_name['MsgSetOrchestratorAddressesResponse'] = _MSGSETORCHESTRATORADDRESSESRESPONSE
DESCRIPTOR.message_types_by_name['MsgValsetConfirm'] = _MSGVALSETCONFIRM
DESCRIPTOR.message_types_by_name['MsgValsetConfirmResponse'] = _MSGVALSETCONFIRMRESPONSE
DESCRIPTOR.message_types_by_name['MsgSendToEth'] = _MSGSENDTOETH
DESCRIPTOR.message_types_by_name['MsgSendToEthResponse'] = _MSGSENDTOETHRESPONSE
DESCRIPTOR.message_types_by_name['MsgRequestBatch'] = _MSGREQUESTBATCH
DESCRIPTOR.message_types_by_name['MsgRequestBatchResponse'] = _MSGREQUESTBATCHRESPONSE
DESCRIPTOR.message_types_by_name['MsgConfirmBatch'] = _MSGCONFIRMBATCH
DESCRIPTOR.message_types_by_name['MsgConfirmBatchResponse'] = _MSGCONFIRMBATCHRESPONSE
DESCRIPTOR.message_types_by_name['MsgDepositClaim'] = _MSGDEPOSITCLAIM
DESCRIPTOR.message_types_by_name['MsgDepositClaimResponse'] = _MSGDEPOSITCLAIMRESPONSE
DESCRIPTOR.message_types_by_name['MsgWithdrawClaim'] = _MSGWITHDRAWCLAIM
DESCRIPTOR.message_types_by_name['MsgWithdrawClaimResponse'] = _MSGWITHDRAWCLAIMRESPONSE
DESCRIPTOR.message_types_by_name['MsgERC20DeployedClaim'] = _MSGERC20DEPLOYEDCLAIM
DESCRIPTOR.message_types_by_name['MsgERC20DeployedClaimResponse'] = _MSGERC20DEPLOYEDCLAIMRESPONSE
DESCRIPTOR.message_types_by_name['MsgCancelSendToEth'] = _MSGCANCELSENDTOETH
DESCRIPTOR.message_types_by_name['MsgCancelSendToEthResponse'] = _MSGCANCELSENDTOETHRESPONSE
DESCRIPTOR.message_types_by_name['MsgSubmitBadSignatureEvidence'] = _MSGSUBMITBADSIGNATUREEVIDENCE
DESCRIPTOR.message_types_by_name['MsgSubmitBadSignatureEvidenceResponse'] = _MSGSUBMITBADSIGNATUREEVIDENCERESPONSE
DESCRIPTOR.message_types_by_name['MsgValsetUpdatedClaim'] = _MSGVALSETUPDATEDCLAIM
DESCRIPTOR.message_types_by_name['MsgValsetUpdatedClaimResponse'] = _MSGVALSETUPDATEDCLAIMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgSetOrchestratorAddresses = _reflection.GeneratedProtocolMessageType('MsgSetOrchestratorAddresses', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETORCHESTRATORADDRESSES,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgSetOrchestratorAddresses)
  })
_sym_db.RegisterMessage(MsgSetOrchestratorAddresses)

MsgSetOrchestratorAddressesResponse = _reflection.GeneratedProtocolMessageType('MsgSetOrchestratorAddressesResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETORCHESTRATORADDRESSESRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgSetOrchestratorAddressesResponse)
  })
_sym_db.RegisterMessage(MsgSetOrchestratorAddressesResponse)

MsgValsetConfirm = _reflection.GeneratedProtocolMessageType('MsgValsetConfirm', (_message.Message,), {
  'DESCRIPTOR' : _MSGVALSETCONFIRM,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgValsetConfirm)
  })
_sym_db.RegisterMessage(MsgValsetConfirm)

MsgValsetConfirmResponse = _reflection.GeneratedProtocolMessageType('MsgValsetConfirmResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGVALSETCONFIRMRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgValsetConfirmResponse)
  })
_sym_db.RegisterMessage(MsgValsetConfirmResponse)

MsgSendToEth = _reflection.GeneratedProtocolMessageType('MsgSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _MSGSENDTOETH,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgSendToEth)
  })
_sym_db.RegisterMessage(MsgSendToEth)

MsgSendToEthResponse = _reflection.GeneratedProtocolMessageType('MsgSendToEthResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSENDTOETHRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgSendToEthResponse)
  })
_sym_db.RegisterMessage(MsgSendToEthResponse)

MsgRequestBatch = _reflection.GeneratedProtocolMessageType('MsgRequestBatch', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTBATCH,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgRequestBatch)
  })
_sym_db.RegisterMessage(MsgRequestBatch)

MsgRequestBatchResponse = _reflection.GeneratedProtocolMessageType('MsgRequestBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTBATCHRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgRequestBatchResponse)
  })
_sym_db.RegisterMessage(MsgRequestBatchResponse)

MsgConfirmBatch = _reflection.GeneratedProtocolMessageType('MsgConfirmBatch', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONFIRMBATCH,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgConfirmBatch)
  })
_sym_db.RegisterMessage(MsgConfirmBatch)

MsgConfirmBatchResponse = _reflection.GeneratedProtocolMessageType('MsgConfirmBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCONFIRMBATCHRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgConfirmBatchResponse)
  })
_sym_db.RegisterMessage(MsgConfirmBatchResponse)

MsgDepositClaim = _reflection.GeneratedProtocolMessageType('MsgDepositClaim', (_message.Message,), {
  'DESCRIPTOR' : _MSGDEPOSITCLAIM,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgDepositClaim)
  })
_sym_db.RegisterMessage(MsgDepositClaim)

MsgDepositClaimResponse = _reflection.GeneratedProtocolMessageType('MsgDepositClaimResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGDEPOSITCLAIMRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgDepositClaimResponse)
  })
_sym_db.RegisterMessage(MsgDepositClaimResponse)

MsgWithdrawClaim = _reflection.GeneratedProtocolMessageType('MsgWithdrawClaim', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWCLAIM,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgWithdrawClaim)
  })
_sym_db.RegisterMessage(MsgWithdrawClaim)

MsgWithdrawClaimResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawClaimResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWCLAIMRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgWithdrawClaimResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawClaimResponse)

MsgERC20DeployedClaim = _reflection.GeneratedProtocolMessageType('MsgERC20DeployedClaim', (_message.Message,), {
  'DESCRIPTOR' : _MSGERC20DEPLOYEDCLAIM,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgERC20DeployedClaim)
  })
_sym_db.RegisterMessage(MsgERC20DeployedClaim)

MsgERC20DeployedClaimResponse = _reflection.GeneratedProtocolMessageType('MsgERC20DeployedClaimResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGERC20DEPLOYEDCLAIMRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgERC20DeployedClaimResponse)
  })
_sym_db.RegisterMessage(MsgERC20DeployedClaimResponse)

MsgCancelSendToEth = _reflection.GeneratedProtocolMessageType('MsgCancelSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELSENDTOETH,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgCancelSendToEth)
  })
_sym_db.RegisterMessage(MsgCancelSendToEth)

MsgCancelSendToEthResponse = _reflection.GeneratedProtocolMessageType('MsgCancelSendToEthResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELSENDTOETHRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgCancelSendToEthResponse)
  })
_sym_db.RegisterMessage(MsgCancelSendToEthResponse)

MsgSubmitBadSignatureEvidence = _reflection.GeneratedProtocolMessageType('MsgSubmitBadSignatureEvidence', (_message.Message,), {
  'DESCRIPTOR' : _MSGSUBMITBADSIGNATUREEVIDENCE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgSubmitBadSignatureEvidence)
  })
_sym_db.RegisterMessage(MsgSubmitBadSignatureEvidence)

MsgSubmitBadSignatureEvidenceResponse = _reflection.GeneratedProtocolMessageType('MsgSubmitBadSignatureEvidenceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSUBMITBADSIGNATUREEVIDENCERESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgSubmitBadSignatureEvidenceResponse)
  })
_sym_db.RegisterMessage(MsgSubmitBadSignatureEvidenceResponse)

MsgValsetUpdatedClaim = _reflection.GeneratedProtocolMessageType('MsgValsetUpdatedClaim', (_message.Message,), {
  'DESCRIPTOR' : _MSGVALSETUPDATEDCLAIM,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgValsetUpdatedClaim)
  })
_sym_db.RegisterMessage(MsgValsetUpdatedClaim)

MsgValsetUpdatedClaimResponse = _reflection.GeneratedProtocolMessageType('MsgValsetUpdatedClaimResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGVALSETUPDATEDCLAIMRESPONSE,
  '__module__' : 'injective.peggy.v1.msgs_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.MsgValsetUpdatedClaimResponse)
  })
_sym_db.RegisterMessage(MsgValsetUpdatedClaimResponse)


DESCRIPTOR._options = None
_MSGSENDTOETH.fields_by_name['amount']._options = None
_MSGSENDTOETH.fields_by_name['bridge_fee']._options = None
_MSGDEPOSITCLAIM.fields_by_name['amount']._options = None
_MSGVALSETUPDATEDCLAIM.fields_by_name['reward_amount']._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.peggy.v1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2031,
  serialized_end=3763,
  methods=[
  _descriptor.MethodDescriptor(
    name='ValsetConfirm',
    full_name='injective.peggy.v1.Msg.ValsetConfirm',
    index=0,
    containing_service=None,
    input_type=_MSGVALSETCONFIRM,
    output_type=_MSGVALSETCONFIRMRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\"/injective/peggy/v1/valset_confirm',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendToEth',
    full_name='injective.peggy.v1.Msg.SendToEth',
    index=1,
    containing_service=None,
    input_type=_MSGSENDTOETH,
    output_type=_MSGSENDTOETHRESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\037/injective/peggy/v1/send_to_eth',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestBatch',
    full_name='injective.peggy.v1.Msg.RequestBatch',
    index=2,
    containing_service=None,
    input_type=_MSGREQUESTBATCH,
    output_type=_MSGREQUESTBATCHRESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/injective/peggy/v1/request_batch',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfirmBatch',
    full_name='injective.peggy.v1.Msg.ConfirmBatch',
    index=3,
    containing_service=None,
    input_type=_MSGCONFIRMBATCH,
    output_type=_MSGCONFIRMBATCHRESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/injective/peggy/v1/confirm_batch',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DepositClaim',
    full_name='injective.peggy.v1.Msg.DepositClaim',
    index=4,
    containing_service=None,
    input_type=_MSGDEPOSITCLAIM,
    output_type=_MSGDEPOSITCLAIMRESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/injective/peggy/v1/deposit_claim',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WithdrawClaim',
    full_name='injective.peggy.v1.Msg.WithdrawClaim',
    index=5,
    containing_service=None,
    input_type=_MSGWITHDRAWCLAIM,
    output_type=_MSGWITHDRAWCLAIMRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\"/injective/peggy/v1/withdraw_claim',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValsetUpdateClaim',
    full_name='injective.peggy.v1.Msg.ValsetUpdateClaim',
    index=6,
    containing_service=None,
    input_type=_MSGVALSETUPDATEDCLAIM,
    output_type=_MSGVALSETUPDATEDCLAIMRESPONSE,
    serialized_options=b'\202\323\344\223\002*\"(/injective/peggy/v1/valset_updated_claim',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ERC20DeployedClaim',
    full_name='injective.peggy.v1.Msg.ERC20DeployedClaim',
    index=7,
    containing_service=None,
    input_type=_MSGERC20DEPLOYEDCLAIM,
    output_type=_MSGERC20DEPLOYEDCLAIMRESPONSE,
    serialized_options=b'\202\323\344\223\002*\"(/injective/peggy/v1/erc20_deployed_claim',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetOrchestratorAddresses',
    full_name='injective.peggy.v1.Msg.SetOrchestratorAddresses',
    index=8,
    containing_service=None,
    input_type=_MSGSETORCHESTRATORADDRESSES,
    output_type=_MSGSETORCHESTRATORADDRESSESRESPONSE,
    serialized_options=b'\202\323\344\223\002.\",/injective/peggy/v1/set_orchestrator_address',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelSendToEth',
    full_name='injective.peggy.v1.Msg.CancelSendToEth',
    index=9,
    containing_service=None,
    input_type=_MSGCANCELSENDTOETH,
    output_type=_MSGCANCELSENDTOETHRESPONSE,
    serialized_options=b'\202\323\344\223\002(\"&/injective/peggy/v1/cancel_send_to_eth',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitBadSignatureEvidence',
    full_name='injective.peggy.v1.Msg.SubmitBadSignatureEvidence',
    index=10,
    containing_service=None,
    input_type=_MSGSUBMITBADSIGNATUREEVIDENCE,
    output_type=_MSGSUBMITBADSIGNATUREEVIDENCERESPONSE,
    serialized_options=b'\202\323\344\223\0023\"1/injective/peggy/v1/submit_bad_signature_evidence',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
