# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_ext.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/types/v1beta1/tx_ext.proto',
  package='injective.types.v1beta1',
  syntax='proto3',
  serialized_options=b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$injective/types/v1beta1/tx_ext.proto\x12\x17injective.types.v1beta1\x1a\x14gogoproto/gogo.proto\"_\n\x16\x45xtensionOptionsWeb3Tx\x12\x18\n\x10typedDataChainID\x18\x01 \x01(\x04\x12\x10\n\x08\x66\x65\x65Payer\x18\x02 \x01(\t\x12\x13\n\x0b\x66\x65\x65PayerSig\x18\x03 \x01(\x0c:\x04\x88\xa0\x1f\x00\x42?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_EXTENSIONOPTIONSWEB3TX = _descriptor.Descriptor(
  name='ExtensionOptionsWeb3Tx',
  full_name='injective.types.v1beta1.ExtensionOptionsWeb3Tx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typedDataChainID', full_name='injective.types.v1beta1.ExtensionOptionsWeb3Tx.typedDataChainID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feePayer', full_name='injective.types.v1beta1.ExtensionOptionsWeb3Tx.feePayer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feePayerSig', full_name='injective.types.v1beta1.ExtensionOptionsWeb3Tx.feePayerSig', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=182,
)

DESCRIPTOR.message_types_by_name['ExtensionOptionsWeb3Tx'] = _EXTENSIONOPTIONSWEB3TX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtensionOptionsWeb3Tx = _reflection.GeneratedProtocolMessageType('ExtensionOptionsWeb3Tx', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONOPTIONSWEB3TX,
  '__module__' : 'injective.types.v1beta1.tx_ext_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.ExtensionOptionsWeb3Tx)
  })
_sym_db.RegisterMessage(ExtensionOptionsWeb3Tx)


DESCRIPTOR._options = None
_EXTENSIONOPTIONSWEB3TX._options = None
# @@protoc_insertion_point(module_scope)
