# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/ocr/v1beta1/tx.proto',
  package='injective.ocr.v1beta1',
  syntax='proto3',
  serialized_options=b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1einjective/ocr/v1beta1/tx.proto\x12\x15injective.ocr.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\\\n\rMsgCreateFeed\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgCreateFeedResponse\"\xbd\x02\n\rMsgUpdateFeed\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12\x0f\n\x07signers\x18\x03 \x03(\t\x12\x14\n\x0ctransmitters\x18\x04 \x03(\t\x12L\n\x14link_per_observation\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x01\x12M\n\x15link_per_transmission\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x01\x12\x12\n\nlink_denom\x18\x07 \x01(\t\x12\x12\n\nfeed_admin\x18\x08 \x01(\t\x12\x15\n\rbilling_admin\x18\t \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgUpdateFeedResponse\"\xc9\x01\n\x0bMsgTransmit\x12\x13\n\x0btransmitter\x18\x01 \x01(\t\x12\x15\n\rconfig_digest\x18\x02 \x01(\x0c\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t\x12\r\n\x05\x65poch\x18\x04 \x01(\x04\x12\r\n\x05round\x18\x05 \x01(\x04\x12\x12\n\nextra_hash\x18\x06 \x01(\x0c\x12-\n\x06report\x18\x07 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.Report\x12\x12\n\nsignatures\x18\x08 \x03(\x0c:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x15\n\x13MsgTransmitResponse\"s\n\x15MsgFundFeedRewardPool\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgFundFeedRewardPoolResponse\"w\n\x19MsgWithdrawFeedRewardPool\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"#\n!MsgWithdrawFeedRewardPoolResponse\"_\n\x0cMsgSetPayees\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12\x14\n\x0ctransmitters\x18\x03 \x03(\t\x12\x0e\n\x06payees\x18\x04 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x16\n\x14MsgSetPayeesResponse\"h\n\x14MsgTransferPayeeship\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t\x12\x10\n\x08proposed\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgTransferPayeeshipResponse\"S\n\x12MsgAcceptPayeeship\x12\r\n\x05payee\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgAcceptPayeeshipResponse2\xed\x06\n\x03Msg\x12`\n\nCreateFeed\x12$.injective.ocr.v1beta1.MsgCreateFeed\x1a,.injective.ocr.v1beta1.MsgCreateFeedResponse\x12`\n\nUpdateFeed\x12$.injective.ocr.v1beta1.MsgUpdateFeed\x1a,.injective.ocr.v1beta1.MsgUpdateFeedResponse\x12Z\n\x08Transmit\x12\".injective.ocr.v1beta1.MsgTransmit\x1a*.injective.ocr.v1beta1.MsgTransmitResponse\x12x\n\x12\x46undFeedRewardPool\x12,.injective.ocr.v1beta1.MsgFundFeedRewardPool\x1a\x34.injective.ocr.v1beta1.MsgFundFeedRewardPoolResponse\x12\x84\x01\n\x16WithdrawFeedRewardPool\x12\x30.injective.ocr.v1beta1.MsgWithdrawFeedRewardPool\x1a\x38.injective.ocr.v1beta1.MsgWithdrawFeedRewardPoolResponse\x12]\n\tSetPayees\x12#.injective.ocr.v1beta1.MsgSetPayees\x1a+.injective.ocr.v1beta1.MsgSetPayeesResponse\x12u\n\x11TransferPayeeship\x12+.injective.ocr.v1beta1.MsgTransferPayeeship\x1a\x33.injective.ocr.v1beta1.MsgTransferPayeeshipResponse\x12o\n\x0f\x41\x63\x63\x65ptPayeeship\x12).injective.ocr.v1beta1.MsgAcceptPayeeship\x1a\x31.injective.ocr.v1beta1.MsgAcceptPayeeshipResponseBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,injective_dot_ocr_dot_v1beta1_dot_ocr__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_MSGCREATEFEED = _descriptor.Descriptor(
  name='MsgCreateFeed',
  full_name='injective.ocr.v1beta1.MsgCreateFeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.ocr.v1beta1.MsgCreateFeed.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='injective.ocr.v1beta1.MsgCreateFeed.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=236,
)


_MSGCREATEFEEDRESPONSE = _descriptor.Descriptor(
  name='MsgCreateFeedResponse',
  full_name='injective.ocr.v1beta1.MsgCreateFeedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=261,
)


_MSGUPDATEFEED = _descriptor.Descriptor(
  name='MsgUpdateFeed',
  full_name='injective.ocr.v1beta1.MsgUpdateFeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.ocr.v1beta1.MsgUpdateFeed.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgUpdateFeed.feed_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signers', full_name='injective.ocr.v1beta1.MsgUpdateFeed.signers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitters', full_name='injective.ocr.v1beta1.MsgUpdateFeed.transmitters', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_per_observation', full_name='injective.ocr.v1beta1.MsgUpdateFeed.link_per_observation', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_per_transmission', full_name='injective.ocr.v1beta1.MsgUpdateFeed.link_per_transmission', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_denom', full_name='injective.ocr.v1beta1.MsgUpdateFeed.link_denom', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_admin', full_name='injective.ocr.v1beta1.MsgUpdateFeed.feed_admin', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_admin', full_name='injective.ocr.v1beta1.MsgUpdateFeed.billing_admin', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=581,
)


_MSGUPDATEFEEDRESPONSE = _descriptor.Descriptor(
  name='MsgUpdateFeedResponse',
  full_name='injective.ocr.v1beta1.MsgUpdateFeedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=606,
)


_MSGTRANSMIT = _descriptor.Descriptor(
  name='MsgTransmit',
  full_name='injective.ocr.v1beta1.MsgTransmit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.MsgTransmit.transmitter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.MsgTransmit.config_digest', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgTransmit.feed_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='injective.ocr.v1beta1.MsgTransmit.epoch', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.ocr.v1beta1.MsgTransmit.round', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_hash', full_name='injective.ocr.v1beta1.MsgTransmit.extra_hash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='injective.ocr.v1beta1.MsgTransmit.report', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='injective.ocr.v1beta1.MsgTransmit.signatures', index=7,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=810,
)


_MSGTRANSMITRESPONSE = _descriptor.Descriptor(
  name='MsgTransmitResponse',
  full_name='injective.ocr.v1beta1.MsgTransmitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=833,
)


_MSGFUNDFEEDREWARDPOOL = _descriptor.Descriptor(
  name='MsgFundFeedRewardPool',
  full_name='injective.ocr.v1beta1.MsgFundFeedRewardPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.ocr.v1beta1.MsgFundFeedRewardPool.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgFundFeedRewardPool.feed_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.MsgFundFeedRewardPool.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=950,
)


_MSGFUNDFEEDREWARDPOOLRESPONSE = _descriptor.Descriptor(
  name='MsgFundFeedRewardPoolResponse',
  full_name='injective.ocr.v1beta1.MsgFundFeedRewardPoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=983,
)


_MSGWITHDRAWFEEDREWARDPOOL = _descriptor.Descriptor(
  name='MsgWithdrawFeedRewardPool',
  full_name='injective.ocr.v1beta1.MsgWithdrawFeedRewardPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.ocr.v1beta1.MsgWithdrawFeedRewardPool.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgWithdrawFeedRewardPool.feed_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.MsgWithdrawFeedRewardPool.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=985,
  serialized_end=1104,
)


_MSGWITHDRAWFEEDREWARDPOOLRESPONSE = _descriptor.Descriptor(
  name='MsgWithdrawFeedRewardPoolResponse',
  full_name='injective.ocr.v1beta1.MsgWithdrawFeedRewardPoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1141,
)


_MSGSETPAYEES = _descriptor.Descriptor(
  name='MsgSetPayees',
  full_name='injective.ocr.v1beta1.MsgSetPayees',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.ocr.v1beta1.MsgSetPayees.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgSetPayees.feed_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitters', full_name='injective.ocr.v1beta1.MsgSetPayees.transmitters', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payees', full_name='injective.ocr.v1beta1.MsgSetPayees.payees', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1238,
)


_MSGSETPAYEESRESPONSE = _descriptor.Descriptor(
  name='MsgSetPayeesResponse',
  full_name='injective.ocr.v1beta1.MsgSetPayeesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1240,
  serialized_end=1262,
)


_MSGTRANSFERPAYEESHIP = _descriptor.Descriptor(
  name='MsgTransferPayeeship',
  full_name='injective.ocr.v1beta1.MsgTransferPayeeship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.ocr.v1beta1.MsgTransferPayeeship.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.MsgTransferPayeeship.transmitter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgTransferPayeeship.feed_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposed', full_name='injective.ocr.v1beta1.MsgTransferPayeeship.proposed', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1264,
  serialized_end=1368,
)


_MSGTRANSFERPAYEESHIPRESPONSE = _descriptor.Descriptor(
  name='MsgTransferPayeeshipResponse',
  full_name='injective.ocr.v1beta1.MsgTransferPayeeshipResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1400,
)


_MSGACCEPTPAYEESHIP = _descriptor.Descriptor(
  name='MsgAcceptPayeeship',
  full_name='injective.ocr.v1beta1.MsgAcceptPayeeship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payee', full_name='injective.ocr.v1beta1.MsgAcceptPayeeship.payee', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.MsgAcceptPayeeship.transmitter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.MsgAcceptPayeeship.feed_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1485,
)


_MSGACCEPTPAYEESHIPRESPONSE = _descriptor.Descriptor(
  name='MsgAcceptPayeeshipResponse',
  full_name='injective.ocr.v1beta1.MsgAcceptPayeeshipResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1515,
)

_MSGCREATEFEED.fields_by_name['config'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIG
_MSGTRANSMIT.fields_by_name['report'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._REPORT
_MSGFUNDFEEDREWARDPOOL.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGWITHDRAWFEEDREWARDPOOL.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgCreateFeed'] = _MSGCREATEFEED
DESCRIPTOR.message_types_by_name['MsgCreateFeedResponse'] = _MSGCREATEFEEDRESPONSE
DESCRIPTOR.message_types_by_name['MsgUpdateFeed'] = _MSGUPDATEFEED
DESCRIPTOR.message_types_by_name['MsgUpdateFeedResponse'] = _MSGUPDATEFEEDRESPONSE
DESCRIPTOR.message_types_by_name['MsgTransmit'] = _MSGTRANSMIT
DESCRIPTOR.message_types_by_name['MsgTransmitResponse'] = _MSGTRANSMITRESPONSE
DESCRIPTOR.message_types_by_name['MsgFundFeedRewardPool'] = _MSGFUNDFEEDREWARDPOOL
DESCRIPTOR.message_types_by_name['MsgFundFeedRewardPoolResponse'] = _MSGFUNDFEEDREWARDPOOLRESPONSE
DESCRIPTOR.message_types_by_name['MsgWithdrawFeedRewardPool'] = _MSGWITHDRAWFEEDREWARDPOOL
DESCRIPTOR.message_types_by_name['MsgWithdrawFeedRewardPoolResponse'] = _MSGWITHDRAWFEEDREWARDPOOLRESPONSE
DESCRIPTOR.message_types_by_name['MsgSetPayees'] = _MSGSETPAYEES
DESCRIPTOR.message_types_by_name['MsgSetPayeesResponse'] = _MSGSETPAYEESRESPONSE
DESCRIPTOR.message_types_by_name['MsgTransferPayeeship'] = _MSGTRANSFERPAYEESHIP
DESCRIPTOR.message_types_by_name['MsgTransferPayeeshipResponse'] = _MSGTRANSFERPAYEESHIPRESPONSE
DESCRIPTOR.message_types_by_name['MsgAcceptPayeeship'] = _MSGACCEPTPAYEESHIP
DESCRIPTOR.message_types_by_name['MsgAcceptPayeeshipResponse'] = _MSGACCEPTPAYEESHIPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgCreateFeed = _reflection.GeneratedProtocolMessageType('MsgCreateFeed', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEFEED,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgCreateFeed)
  })
_sym_db.RegisterMessage(MsgCreateFeed)

MsgCreateFeedResponse = _reflection.GeneratedProtocolMessageType('MsgCreateFeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEFEEDRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgCreateFeedResponse)
  })
_sym_db.RegisterMessage(MsgCreateFeedResponse)

MsgUpdateFeed = _reflection.GeneratedProtocolMessageType('MsgUpdateFeed', (_message.Message,), {
  'DESCRIPTOR' : _MSGUPDATEFEED,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgUpdateFeed)
  })
_sym_db.RegisterMessage(MsgUpdateFeed)

MsgUpdateFeedResponse = _reflection.GeneratedProtocolMessageType('MsgUpdateFeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGUPDATEFEEDRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgUpdateFeedResponse)
  })
_sym_db.RegisterMessage(MsgUpdateFeedResponse)

MsgTransmit = _reflection.GeneratedProtocolMessageType('MsgTransmit', (_message.Message,), {
  'DESCRIPTOR' : _MSGTRANSMIT,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgTransmit)
  })
_sym_db.RegisterMessage(MsgTransmit)

MsgTransmitResponse = _reflection.GeneratedProtocolMessageType('MsgTransmitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGTRANSMITRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgTransmitResponse)
  })
_sym_db.RegisterMessage(MsgTransmitResponse)

MsgFundFeedRewardPool = _reflection.GeneratedProtocolMessageType('MsgFundFeedRewardPool', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDFEEDREWARDPOOL,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgFundFeedRewardPool)
  })
_sym_db.RegisterMessage(MsgFundFeedRewardPool)

MsgFundFeedRewardPoolResponse = _reflection.GeneratedProtocolMessageType('MsgFundFeedRewardPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDFEEDREWARDPOOLRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgFundFeedRewardPoolResponse)
  })
_sym_db.RegisterMessage(MsgFundFeedRewardPoolResponse)

MsgWithdrawFeedRewardPool = _reflection.GeneratedProtocolMessageType('MsgWithdrawFeedRewardPool', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWFEEDREWARDPOOL,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgWithdrawFeedRewardPool)
  })
_sym_db.RegisterMessage(MsgWithdrawFeedRewardPool)

MsgWithdrawFeedRewardPoolResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawFeedRewardPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWFEEDREWARDPOOLRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgWithdrawFeedRewardPoolResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawFeedRewardPoolResponse)

MsgSetPayees = _reflection.GeneratedProtocolMessageType('MsgSetPayees', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETPAYEES,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgSetPayees)
  })
_sym_db.RegisterMessage(MsgSetPayees)

MsgSetPayeesResponse = _reflection.GeneratedProtocolMessageType('MsgSetPayeesResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETPAYEESRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgSetPayeesResponse)
  })
_sym_db.RegisterMessage(MsgSetPayeesResponse)

MsgTransferPayeeship = _reflection.GeneratedProtocolMessageType('MsgTransferPayeeship', (_message.Message,), {
  'DESCRIPTOR' : _MSGTRANSFERPAYEESHIP,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgTransferPayeeship)
  })
_sym_db.RegisterMessage(MsgTransferPayeeship)

MsgTransferPayeeshipResponse = _reflection.GeneratedProtocolMessageType('MsgTransferPayeeshipResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGTRANSFERPAYEESHIPRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgTransferPayeeshipResponse)
  })
_sym_db.RegisterMessage(MsgTransferPayeeshipResponse)

MsgAcceptPayeeship = _reflection.GeneratedProtocolMessageType('MsgAcceptPayeeship', (_message.Message,), {
  'DESCRIPTOR' : _MSGACCEPTPAYEESHIP,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgAcceptPayeeship)
  })
_sym_db.RegisterMessage(MsgAcceptPayeeship)

MsgAcceptPayeeshipResponse = _reflection.GeneratedProtocolMessageType('MsgAcceptPayeeshipResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGACCEPTPAYEESHIPRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.MsgAcceptPayeeshipResponse)
  })
_sym_db.RegisterMessage(MsgAcceptPayeeshipResponse)


DESCRIPTOR._options = None
_MSGCREATEFEED._options = None
_MSGUPDATEFEED.fields_by_name['link_per_observation']._options = None
_MSGUPDATEFEED.fields_by_name['link_per_transmission']._options = None
_MSGUPDATEFEED._options = None
_MSGTRANSMIT._options = None
_MSGFUNDFEEDREWARDPOOL.fields_by_name['amount']._options = None
_MSGFUNDFEEDREWARDPOOL._options = None
_MSGWITHDRAWFEEDREWARDPOOL.fields_by_name['amount']._options = None
_MSGWITHDRAWFEEDREWARDPOOL._options = None
_MSGSETPAYEES._options = None
_MSGTRANSFERPAYEESHIP._options = None
_MSGACCEPTPAYEESHIP._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.ocr.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1518,
  serialized_end=2395,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateFeed',
    full_name='injective.ocr.v1beta1.Msg.CreateFeed',
    index=0,
    containing_service=None,
    input_type=_MSGCREATEFEED,
    output_type=_MSGCREATEFEEDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeed',
    full_name='injective.ocr.v1beta1.Msg.UpdateFeed',
    index=1,
    containing_service=None,
    input_type=_MSGUPDATEFEED,
    output_type=_MSGUPDATEFEEDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Transmit',
    full_name='injective.ocr.v1beta1.Msg.Transmit',
    index=2,
    containing_service=None,
    input_type=_MSGTRANSMIT,
    output_type=_MSGTRANSMITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FundFeedRewardPool',
    full_name='injective.ocr.v1beta1.Msg.FundFeedRewardPool',
    index=3,
    containing_service=None,
    input_type=_MSGFUNDFEEDREWARDPOOL,
    output_type=_MSGFUNDFEEDREWARDPOOLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WithdrawFeedRewardPool',
    full_name='injective.ocr.v1beta1.Msg.WithdrawFeedRewardPool',
    index=4,
    containing_service=None,
    input_type=_MSGWITHDRAWFEEDREWARDPOOL,
    output_type=_MSGWITHDRAWFEEDREWARDPOOLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPayees',
    full_name='injective.ocr.v1beta1.Msg.SetPayees',
    index=5,
    containing_service=None,
    input_type=_MSGSETPAYEES,
    output_type=_MSGSETPAYEESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransferPayeeship',
    full_name='injective.ocr.v1beta1.Msg.TransferPayeeship',
    index=6,
    containing_service=None,
    input_type=_MSGTRANSFERPAYEESHIP,
    output_type=_MSGTRANSFERPAYEESHIPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptPayeeship',
    full_name='injective.ocr.v1beta1.Msg.AcceptPayeeship',
    index=7,
    containing_service=None,
    input_type=_MSGACCEPTPAYEESHIP,
    output_type=_MSGACCEPTPAYEESHIPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
