# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/oracle.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/oracle/v1beta1/oracle.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x0e\n\x06Params:\x04\xe8\xa0\x1f\x01\"m\n\nOracleInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x39\n\x0boracle_type\x18\x02 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x14\n\x0cscale_factor\x18\x03 \x01(\r\"\xba\x01\n\x13\x43hainlinkPriceState\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12?\n\x0bprice_state\x18\x04 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\xc9\x01\n\x0e\x42\x61ndPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12<\n\x04rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x03 \x01(\x04\x12\x12\n\nrequest_ID\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"z\n\x0ePriceFeedState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\x12\x39\n\x0bprice_state\x18\x03 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\x12\x10\n\x08relayers\x18\x04 \x03(\t\"2\n\x0cProviderInfo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x10\n\x08relayers\x18\x02 \x03(\t\"\x9b\x01\n\rProviderState\x12=\n\rprovider_info\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.ProviderInfo\x12K\n\x15provider_price_states\x18\x02 \x03(\x0b\x32,.injective.oracle.v1beta1.ProviderPriceState\"Y\n\x12ProviderPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x33\n\x05state\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\",\n\rPriceFeedInfo\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\"O\n\x0ePriceFeedPrice\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x92\x01\n\x12\x43oinbasePriceState\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\xa8\x01\n\nPriceState\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x63umulative_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\x82\x02\n\x11\x42\x61ndOracleRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x04\x12\x18\n\x10oracle_script_id\x18\x02 \x01(\x03\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0bprepare_gas\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\x08 \x01(\x04\"\x8d\x01\n\rBandIBCParams\x12\x18\n\x10\x62\x61nd_ibc_enabled\x18\x01 \x01(\x08\x12\x1c\n\x14ibc_request_interval\x18\x02 \x01(\x03\x12\x1a\n\x12ibc_source_channel\x18\x03 \x01(\t\x12\x13\n\x0bibc_version\x18\x04 \x01(\t\x12\x13\n\x0bibc_port_id\x18\x05 \x01(\t\"r\n\x14SymbolPriceTimestamp\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"d\n\x13LastPriceTimestamps\x12M\n\x15last_price_timestamps\x18\x01 \x03(\x0b\x32..injective.oracle.v1beta1.SymbolPriceTimestamp\"\x9c\x01\n\x0cPriceRecords\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\x12\x43\n\x14latest_price_records\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecord\"_\n\x0bPriceRecord\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xbf\x03\n\x12MetadataStatistics\x12\x13\n\x0bgroup_count\x18\x01 \x01(\r\x12\x1b\n\x13records_sample_size\x18\x02 \x01(\r\x12<\n\x04mean\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12<\n\x04twap\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x17\n\x0f\x66irst_timestamp\x18\x05 \x01(\x03\x12\x16\n\x0elast_timestamp\x18\x06 \x01(\x03\x12\x41\n\tmin_price\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x41\n\tmax_price\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0cmedian_price\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00*\x9f\x01\n\nOracleType\x12\x0f\n\x0bUnspecified\x10\x00\x12\x08\n\x04\x42\x61nd\x10\x01\x12\r\n\tPriceFeed\x10\x02\x12\x0c\n\x08\x43oinbase\x10\x03\x12\r\n\tChainlink\x10\x04\x12\t\n\x05Razor\x10\x05\x12\x07\n\x03\x44ia\x10\x06\x12\x08\n\x04\x41PI3\x10\x07\x12\x07\n\x03Uma\x10\x08\x12\x08\n\x04Pyth\x10\t\x12\x0b\n\x07\x42\x61ndIBC\x10\n\x12\x0c\n\x08Provider\x10\x0b\x42NZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])

_ORACLETYPE = _descriptor.EnumDescriptor(
  name='OracleType',
  full_name='injective.oracle.v1beta1.OracleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Band', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PriceFeed', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Coinbase', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Chainlink', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Razor', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Dia', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API3', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Uma', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Pyth', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BandIBC', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Provider', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2843,
  serialized_end=3002,
)
_sym_db.RegisterEnumDescriptor(_ORACLETYPE)

OracleType = enum_type_wrapper.EnumTypeWrapper(_ORACLETYPE)
Unspecified = 0
Band = 1
PriceFeed = 2
Coinbase = 3
Chainlink = 4
Razor = 5
Dia = 6
API3 = 7
Uma = 8
Pyth = 9
BandIBC = 10
Provider = 11



_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.oracle.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=135,
)


_ORACLEINFO = _descriptor.Descriptor(
  name='OracleInfo',
  full_name='injective.oracle.v1beta1.OracleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.OracleInfo.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.oracle.v1beta1.OracleInfo.oracle_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_factor', full_name='injective.oracle.v1beta1.OracleInfo.scale_factor', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=246,
)


_CHAINLINKPRICESTATE = _descriptor.Descriptor(
  name='ChainlinkPriceState',
  full_name='injective.oracle.v1beta1.ChainlinkPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.oracle.v1beta1.ChainlinkPriceState.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.oracle.v1beta1.ChainlinkPriceState.answer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.ChainlinkPriceState.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.ChainlinkPriceState.price_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=435,
)


_BANDPRICESTATE = _descriptor.Descriptor(
  name='BandPriceState',
  full_name='injective.oracle.v1beta1.BandPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.BandPriceState.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='injective.oracle.v1beta1.BandPriceState.rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.BandPriceState.resolve_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_ID', full_name='injective.oracle.v1beta1.BandPriceState.request_ID', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.BandPriceState.price_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=639,
)


_PRICEFEEDSTATE = _descriptor.Descriptor(
  name='PriceFeedState',
  full_name='injective.oracle.v1beta1.PriceFeedState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.PriceFeedState.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.PriceFeedState.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.PriceFeedState.price_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.PriceFeedState.relayers', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=763,
)


_PROVIDERINFO = _descriptor.Descriptor(
  name='ProviderInfo',
  full_name='injective.oracle.v1beta1.ProviderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.oracle.v1beta1.ProviderInfo.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.ProviderInfo.relayers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=815,
)


_PROVIDERSTATE = _descriptor.Descriptor(
  name='ProviderState',
  full_name='injective.oracle.v1beta1.ProviderState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_info', full_name='injective.oracle.v1beta1.ProviderState.provider_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_price_states', full_name='injective.oracle.v1beta1.ProviderState.provider_price_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=973,
)


_PROVIDERPRICESTATE = _descriptor.Descriptor(
  name='ProviderPriceState',
  full_name='injective.oracle.v1beta1.ProviderPriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.ProviderPriceState.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.oracle.v1beta1.ProviderPriceState.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1064,
)


_PRICEFEEDINFO = _descriptor.Descriptor(
  name='PriceFeedInfo',
  full_name='injective.oracle.v1beta1.PriceFeedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.PriceFeedInfo.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.PriceFeedInfo.quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1110,
)


_PRICEFEEDPRICE = _descriptor.Descriptor(
  name='PriceFeedPrice',
  full_name='injective.oracle.v1beta1.PriceFeedPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceFeedPrice.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1191,
)


_COINBASEPRICESTATE = _descriptor.Descriptor(
  name='CoinbasePriceState',
  full_name='injective.oracle.v1beta1.CoinbasePriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='injective.oracle.v1beta1.CoinbasePriceState.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.CoinbasePriceState.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='injective.oracle.v1beta1.CoinbasePriceState.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective.oracle.v1beta1.CoinbasePriceState.value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.CoinbasePriceState.price_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1340,
)


_PRICESTATE = _descriptor.Descriptor(
  name='PriceState',
  full_name='injective.oracle.v1beta1.PriceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceState.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_price', full_name='injective.oracle.v1beta1.PriceState.cumulative_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.PriceState.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1511,
)


_BANDORACLEREQUEST = _descriptor.Descriptor(
  name='BandOracleRequest',
  full_name='injective.oracle.v1beta1.BandOracleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.BandOracleRequest.request_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='injective.oracle.v1beta1.BandOracleRequest.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.BandOracleRequest.symbols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='injective.oracle.v1beta1.BandOracleRequest.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='injective.oracle.v1beta1.BandOracleRequest.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='injective.oracle.v1beta1.BandOracleRequest.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='injective.oracle.v1beta1.BandOracleRequest.prepare_gas', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='injective.oracle.v1beta1.BandOracleRequest.execute_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1772,
)


_BANDIBCPARAMS = _descriptor.Descriptor(
  name='BandIBCParams',
  full_name='injective.oracle.v1beta1.BandIBCParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='band_ibc_enabled', full_name='injective.oracle.v1beta1.BandIBCParams.band_ibc_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_request_interval', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_request_interval', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_source_channel', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_source_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_version', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_port_id', full_name='injective.oracle.v1beta1.BandIBCParams.ibc_port_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1775,
  serialized_end=1916,
)


_SYMBOLPRICETIMESTAMP = _descriptor.Descriptor(
  name='SymbolPriceTimestamp',
  full_name='injective.oracle.v1beta1.SymbolPriceTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle', full_name='injective.oracle.v1beta1.SymbolPriceTimestamp.oracle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='injective.oracle.v1beta1.SymbolPriceTimestamp.symbol_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.SymbolPriceTimestamp.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=2032,
)


_LASTPRICETIMESTAMPS = _descriptor.Descriptor(
  name='LastPriceTimestamps',
  full_name='injective.oracle.v1beta1.LastPriceTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_price_timestamps', full_name='injective.oracle.v1beta1.LastPriceTimestamps.last_price_timestamps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2134,
)


_PRICERECORDS = _descriptor.Descriptor(
  name='PriceRecords',
  full_name='injective.oracle.v1beta1.PriceRecords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle', full_name='injective.oracle.v1beta1.PriceRecords.oracle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='injective.oracle.v1beta1.PriceRecords.symbol_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_price_records', full_name='injective.oracle.v1beta1.PriceRecords.latest_price_records', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2137,
  serialized_end=2293,
)


_PRICERECORD = _descriptor.Descriptor(
  name='PriceRecord',
  full_name='injective.oracle.v1beta1.PriceRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.PriceRecord.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.PriceRecord.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2295,
  serialized_end=2390,
)


_METADATASTATISTICS = _descriptor.Descriptor(
  name='MetadataStatistics',
  full_name='injective.oracle.v1beta1.MetadataStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_count', full_name='injective.oracle.v1beta1.MetadataStatistics.group_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records_sample_size', full_name='injective.oracle.v1beta1.MetadataStatistics.records_sample_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='injective.oracle.v1beta1.MetadataStatistics.mean', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twap', full_name='injective.oracle.v1beta1.MetadataStatistics.twap', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_timestamp', full_name='injective.oracle.v1beta1.MetadataStatistics.first_timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_timestamp', full_name='injective.oracle.v1beta1.MetadataStatistics.last_timestamp', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price', full_name='injective.oracle.v1beta1.MetadataStatistics.min_price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_price', full_name='injective.oracle.v1beta1.MetadataStatistics.max_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median_price', full_name='injective.oracle.v1beta1.MetadataStatistics.median_price', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2393,
  serialized_end=2840,
)

_ORACLEINFO.fields_by_name['oracle_type'].enum_type = _ORACLETYPE
_CHAINLINKPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_BANDPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_PRICEFEEDSTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_PROVIDERSTATE.fields_by_name['provider_info'].message_type = _PROVIDERINFO
_PROVIDERSTATE.fields_by_name['provider_price_states'].message_type = _PROVIDERPRICESTATE
_PROVIDERPRICESTATE.fields_by_name['state'].message_type = _PRICESTATE
_COINBASEPRICESTATE.fields_by_name['price_state'].message_type = _PRICESTATE
_BANDORACLEREQUEST.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_SYMBOLPRICETIMESTAMP.fields_by_name['oracle'].enum_type = _ORACLETYPE
_LASTPRICETIMESTAMPS.fields_by_name['last_price_timestamps'].message_type = _SYMBOLPRICETIMESTAMP
_PRICERECORDS.fields_by_name['oracle'].enum_type = _ORACLETYPE
_PRICERECORDS.fields_by_name['latest_price_records'].message_type = _PRICERECORD
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['OracleInfo'] = _ORACLEINFO
DESCRIPTOR.message_types_by_name['ChainlinkPriceState'] = _CHAINLINKPRICESTATE
DESCRIPTOR.message_types_by_name['BandPriceState'] = _BANDPRICESTATE
DESCRIPTOR.message_types_by_name['PriceFeedState'] = _PRICEFEEDSTATE
DESCRIPTOR.message_types_by_name['ProviderInfo'] = _PROVIDERINFO
DESCRIPTOR.message_types_by_name['ProviderState'] = _PROVIDERSTATE
DESCRIPTOR.message_types_by_name['ProviderPriceState'] = _PROVIDERPRICESTATE
DESCRIPTOR.message_types_by_name['PriceFeedInfo'] = _PRICEFEEDINFO
DESCRIPTOR.message_types_by_name['PriceFeedPrice'] = _PRICEFEEDPRICE
DESCRIPTOR.message_types_by_name['CoinbasePriceState'] = _COINBASEPRICESTATE
DESCRIPTOR.message_types_by_name['PriceState'] = _PRICESTATE
DESCRIPTOR.message_types_by_name['BandOracleRequest'] = _BANDORACLEREQUEST
DESCRIPTOR.message_types_by_name['BandIBCParams'] = _BANDIBCPARAMS
DESCRIPTOR.message_types_by_name['SymbolPriceTimestamp'] = _SYMBOLPRICETIMESTAMP
DESCRIPTOR.message_types_by_name['LastPriceTimestamps'] = _LASTPRICETIMESTAMPS
DESCRIPTOR.message_types_by_name['PriceRecords'] = _PRICERECORDS
DESCRIPTOR.message_types_by_name['PriceRecord'] = _PRICERECORD
DESCRIPTOR.message_types_by_name['MetadataStatistics'] = _METADATASTATISTICS
DESCRIPTOR.enum_types_by_name['OracleType'] = _ORACLETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

OracleInfo = _reflection.GeneratedProtocolMessageType('OracleInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.OracleInfo)
  })
_sym_db.RegisterMessage(OracleInfo)

ChainlinkPriceState = _reflection.GeneratedProtocolMessageType('ChainlinkPriceState', (_message.Message,), {
  'DESCRIPTOR' : _CHAINLINKPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ChainlinkPriceState)
  })
_sym_db.RegisterMessage(ChainlinkPriceState)

BandPriceState = _reflection.GeneratedProtocolMessageType('BandPriceState', (_message.Message,), {
  'DESCRIPTOR' : _BANDPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandPriceState)
  })
_sym_db.RegisterMessage(BandPriceState)

PriceFeedState = _reflection.GeneratedProtocolMessageType('PriceFeedState', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDSTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedState)
  })
_sym_db.RegisterMessage(PriceFeedState)

ProviderInfo = _reflection.GeneratedProtocolMessageType('ProviderInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ProviderInfo)
  })
_sym_db.RegisterMessage(ProviderInfo)

ProviderState = _reflection.GeneratedProtocolMessageType('ProviderState', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERSTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ProviderState)
  })
_sym_db.RegisterMessage(ProviderState)

ProviderPriceState = _reflection.GeneratedProtocolMessageType('ProviderPriceState', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.ProviderPriceState)
  })
_sym_db.RegisterMessage(ProviderPriceState)

PriceFeedInfo = _reflection.GeneratedProtocolMessageType('PriceFeedInfo', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDINFO,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedInfo)
  })
_sym_db.RegisterMessage(PriceFeedInfo)

PriceFeedPrice = _reflection.GeneratedProtocolMessageType('PriceFeedPrice', (_message.Message,), {
  'DESCRIPTOR' : _PRICEFEEDPRICE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceFeedPrice)
  })
_sym_db.RegisterMessage(PriceFeedPrice)

CoinbasePriceState = _reflection.GeneratedProtocolMessageType('CoinbasePriceState', (_message.Message,), {
  'DESCRIPTOR' : _COINBASEPRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.CoinbasePriceState)
  })
_sym_db.RegisterMessage(CoinbasePriceState)

PriceState = _reflection.GeneratedProtocolMessageType('PriceState', (_message.Message,), {
  'DESCRIPTOR' : _PRICESTATE,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceState)
  })
_sym_db.RegisterMessage(PriceState)

BandOracleRequest = _reflection.GeneratedProtocolMessageType('BandOracleRequest', (_message.Message,), {
  'DESCRIPTOR' : _BANDORACLEREQUEST,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandOracleRequest)
  })
_sym_db.RegisterMessage(BandOracleRequest)

BandIBCParams = _reflection.GeneratedProtocolMessageType('BandIBCParams', (_message.Message,), {
  'DESCRIPTOR' : _BANDIBCPARAMS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.BandIBCParams)
  })
_sym_db.RegisterMessage(BandIBCParams)

SymbolPriceTimestamp = _reflection.GeneratedProtocolMessageType('SymbolPriceTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLPRICETIMESTAMP,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SymbolPriceTimestamp)
  })
_sym_db.RegisterMessage(SymbolPriceTimestamp)

LastPriceTimestamps = _reflection.GeneratedProtocolMessageType('LastPriceTimestamps', (_message.Message,), {
  'DESCRIPTOR' : _LASTPRICETIMESTAMPS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.LastPriceTimestamps)
  })
_sym_db.RegisterMessage(LastPriceTimestamps)

PriceRecords = _reflection.GeneratedProtocolMessageType('PriceRecords', (_message.Message,), {
  'DESCRIPTOR' : _PRICERECORDS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceRecords)
  })
_sym_db.RegisterMessage(PriceRecords)

PriceRecord = _reflection.GeneratedProtocolMessageType('PriceRecord', (_message.Message,), {
  'DESCRIPTOR' : _PRICERECORD,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.PriceRecord)
  })
_sym_db.RegisterMessage(PriceRecord)

MetadataStatistics = _reflection.GeneratedProtocolMessageType('MetadataStatistics', (_message.Message,), {
  'DESCRIPTOR' : _METADATASTATISTICS,
  '__module__' : 'injective.oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MetadataStatistics)
  })
_sym_db.RegisterMessage(MetadataStatistics)


DESCRIPTOR._options = None
_PARAMS._options = None
_CHAINLINKPRICESTATE.fields_by_name['answer']._options = None
_CHAINLINKPRICESTATE.fields_by_name['price_state']._options = None
_BANDPRICESTATE.fields_by_name['rate']._options = None
_BANDPRICESTATE.fields_by_name['price_state']._options = None
_PRICEFEEDPRICE.fields_by_name['price']._options = None
_COINBASEPRICESTATE.fields_by_name['price_state']._options = None
_PRICESTATE.fields_by_name['price']._options = None
_PRICESTATE.fields_by_name['cumulative_price']._options = None
_BANDORACLEREQUEST.fields_by_name['fee_limit']._options = None
_PRICERECORD.fields_by_name['price']._options = None
_METADATASTATISTICS.fields_by_name['mean']._options = None
_METADATASTATISTICS.fields_by_name['twap']._options = None
_METADATASTATISTICS.fields_by_name['min_price']._options = None
_METADATASTATISTICS.fields_by_name['max_price']._options = None
_METADATASTATISTICS.fields_by_name['median_price']._options = None
# @@protoc_insertion_point(module_scope)
