# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.exchange.v1beta1 import tx_pb2 as injective_dot_exchange_dot_v1beta1_dot_tx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/genesis.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(injective/exchange/v1beta1/genesis.proto\x12\x1ainjective.exchange.v1beta1\x1a)injective/exchange/v1beta1/exchange.proto\x1a#injective/exchange/v1beta1/tx.proto\x1a\x14gogoproto/gogo.proto\"\xd9\x12\n\x0cGenesisState\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12<\n\x0cspot_markets\x18\x02 \x03(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\x12H\n\x12\x64\x65rivative_markets\x18\x03 \x03(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarket\x12G\n\x0espot_orderbook\x18\x04 \x03(\x0b\x32).injective.exchange.v1beta1.SpotOrderBookB\x04\xc8\xde\x1f\x00\x12S\n\x14\x64\x65rivative_orderbook\x18\x05 \x03(\x0b\x32/.injective.exchange.v1beta1.DerivativeOrderBookB\x04\xc8\xde\x1f\x00\x12;\n\x08\x62\x61lances\x18\x06 \x03(\x0b\x32#.injective.exchange.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\x12G\n\tpositions\x18\x07 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\x12R\n\x17subaccount_trade_nonces\x18\x08 \x03(\x0b\x32+.injective.exchange.v1beta1.SubaccountNonceB\x04\xc8\xde\x1f\x00\x12h\n expiry_futures_market_info_state\x18\t \x03(\x0b\x32\x38.injective.exchange.v1beta1.ExpiryFuturesMarketInfoStateB\x04\xc8\xde\x1f\x00\x12T\n\x15perpetual_market_info\x18\n \x03(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00\x12\x65\n\x1eperpetual_market_funding_state\x18\x0b \x03(\x0b\x32\x37.injective.exchange.v1beta1.PerpetualMarketFundingStateB\x04\xc8\xde\x1f\x00\x12p\n&derivative_market_settlement_scheduled\x18\x0c \x03(\x0b\x32:.injective.exchange.v1beta1.DerivativeMarketSettlementInfoB\x04\xc8\xde\x1f\x00\x12 \n\x18is_spot_exchange_enabled\x18\r \x01(\x08\x12\'\n\x1fis_derivatives_exchange_enabled\x18\x0e \x01(\x08\x12[\n\x1ctrading_reward_campaign_info\x18\x0f \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12]\n%trading_reward_pool_campaign_schedule\x18\x10 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12n\n&trading_reward_campaign_account_points\x18\x11 \x03(\x0b\x32>.injective.exchange.v1beta1.TradingRewardCampaignAccountPoints\x12N\n\x15\x66\x65\x65_discount_schedule\x18\x12 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\x12\\\n\x1d\x66\x65\x65_discount_account_tier_ttl\x18\x13 \x03(\x0b\x32\x35.injective.exchange.v1beta1.FeeDiscountAccountTierTTL\x12h\n#fee_discount_bucket_volume_accounts\x18\x14 \x03(\x0b\x32;.injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts\x12#\n\x1bis_first_fee_cycle_finished\x18\x15 \x01(\x08\x12\x65\n-pending_trading_reward_pool_campaign_schedule\x18\x16 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12}\n.pending_trading_reward_campaign_account_points\x18\x17 \x03(\x0b\x32\x45.injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints\x12!\n\x19rewards_opt_out_addresses\x18\x18 \x03(\t\x12J\n\x18historical_trade_records\x18\x19 \x03(\x0b\x32(.injective.exchange.v1beta1.TradeRecords\x12O\n\x16\x62inary_options_markets\x18\x1a \x03(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarket\x12:\n2binary_options_market_ids_scheduled_for_settlement\x18\x1b \x03(\t\x12\x30\n(spot_market_ids_scheduled_to_force_close\x18\x1c \x03(\t\x12G\n\x0e\x64\x65nom_decimals\x18\x1d \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimalsB\x04\xc8\xde\x1f\x00\x12\x65\n!conditional_derivative_orderbooks\x18\x1e \x03(\x0b\x32:.injective.exchange.v1beta1.ConditionalDerivativeOrderBook\"n\n\x19\x46\x65\x65\x44iscountAccountTierTTL\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12@\n\x08tier_ttl\x18\x02 \x01(\x0b\x32..injective.exchange.v1beta1.FeeDiscountTierTTL\"\x84\x01\n\x1f\x46\x65\x65\x44iscountBucketVolumeAccounts\x12\x1e\n\x16\x62ucket_start_timestamp\x18\x01 \x01(\x03\x12\x41\n\x0e\x61\x63\x63ount_volume\x18\x02 \x03(\x0b\x32).injective.exchange.v1beta1.AccountVolume\"`\n\rAccountVolume\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12>\n\x06volume\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"u\n\"TradingRewardCampaignAccountPoints\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12>\n\x06points\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa8\x01\n)TradingRewardCampaignAccountPendingPoints\x12#\n\x1breward_pool_start_timestamp\x18\x01 \x01(\x03\x12V\n\x0e\x61\x63\x63ount_points\x18\x02 \x03(\x0b\x32>.injective.exchange.v1beta1.TradingRewardCampaignAccountPoints\"{\n\rSpotOrderBook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x11\n\tisBuySide\x18\x02 \x01(\x08\x12:\n\x06orders\x18\x03 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrder:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x87\x01\n\x13\x44\x65rivativeOrderBook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x11\n\tisBuySide\x18\x02 \x01(\x08\x12@\n\x06orders\x18\x03 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xf3\x02\n\x1e\x43onditionalDerivativeOrderBook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12J\n\x10limit_buy_orders\x18\x02 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\x12L\n\x11market_buy_orders\x18\x03 \x03(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrder\x12K\n\x11limit_sell_orders\x18\x04 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\x12M\n\x12market_sell_orders\x18\x05 \x03(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrder:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"p\n\x07\x42\x61lance\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x35\n\x08\x64\x65posits\x18\x03 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x80\x01\n\x12\x44\x65rivativePosition\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x36\n\x08position\x18\x03 \x01(\x0b\x32$.injective.exchange.v1beta1.Position:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8a\x01\n\x0fSubaccountNonce\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12V\n\x16subaccount_trade_nonce\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.SubaccountTradeNonceB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"{\n\x1c\x45xpiryFuturesMarketInfoState\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12H\n\x0bmarket_info\x18\x02 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfo\"u\n\x1bPerpetualMarketFundingState\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x43\n\x07\x66unding\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DESCRIPTOR,injective_dot_exchange_dot_v1beta1_dot_tx__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='injective.exchange.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.exchange.v1beta1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_markets', full_name='injective.exchange.v1beta1.GenesisState.spot_markets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_markets', full_name='injective.exchange.v1beta1.GenesisState.derivative_markets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_orderbook', full_name='injective.exchange.v1beta1.GenesisState.spot_orderbook', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_orderbook', full_name='injective.exchange.v1beta1.GenesisState.derivative_orderbook', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balances', full_name='injective.exchange.v1beta1.GenesisState.balances', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='injective.exchange.v1beta1.GenesisState.positions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_trade_nonces', full_name='injective.exchange.v1beta1.GenesisState.subaccount_trade_nonces', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_futures_market_info_state', full_name='injective.exchange.v1beta1.GenesisState.expiry_futures_market_info_state', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_info', full_name='injective.exchange.v1beta1.GenesisState.perpetual_market_info', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_funding_state', full_name='injective.exchange.v1beta1.GenesisState.perpetual_market_funding_state', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_market_settlement_scheduled', full_name='injective.exchange.v1beta1.GenesisState.derivative_market_settlement_scheduled', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_spot_exchange_enabled', full_name='injective.exchange.v1beta1.GenesisState.is_spot_exchange_enabled', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_derivatives_exchange_enabled', full_name='injective.exchange.v1beta1.GenesisState.is_derivatives_exchange_enabled', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_campaign_info', full_name='injective.exchange.v1beta1.GenesisState.trading_reward_campaign_info', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_pool_campaign_schedule', full_name='injective.exchange.v1beta1.GenesisState.trading_reward_pool_campaign_schedule', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_campaign_account_points', full_name='injective.exchange.v1beta1.GenesisState.trading_reward_campaign_account_points', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_discount_schedule', full_name='injective.exchange.v1beta1.GenesisState.fee_discount_schedule', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_discount_account_tier_ttl', full_name='injective.exchange.v1beta1.GenesisState.fee_discount_account_tier_ttl', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_discount_bucket_volume_accounts', full_name='injective.exchange.v1beta1.GenesisState.fee_discount_bucket_volume_accounts', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_first_fee_cycle_finished', full_name='injective.exchange.v1beta1.GenesisState.is_first_fee_cycle_finished', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_trading_reward_pool_campaign_schedule', full_name='injective.exchange.v1beta1.GenesisState.pending_trading_reward_pool_campaign_schedule', index=21,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_trading_reward_campaign_account_points', full_name='injective.exchange.v1beta1.GenesisState.pending_trading_reward_campaign_account_points', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards_opt_out_addresses', full_name='injective.exchange.v1beta1.GenesisState.rewards_opt_out_addresses', index=23,
      number=24, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historical_trade_records', full_name='injective.exchange.v1beta1.GenesisState.historical_trade_records', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_markets', full_name='injective.exchange.v1beta1.GenesisState.binary_options_markets', index=25,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_market_ids_scheduled_for_settlement', full_name='injective.exchange.v1beta1.GenesisState.binary_options_market_ids_scheduled_for_settlement', index=26,
      number=27, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_market_ids_scheduled_to_force_close', full_name='injective.exchange.v1beta1.GenesisState.spot_market_ids_scheduled_to_force_close', index=27,
      number=28, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom_decimals', full_name='injective.exchange.v1beta1.GenesisState.denom_decimals', index=28,
      number=29, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditional_derivative_orderbooks', full_name='injective.exchange.v1beta1.GenesisState.conditional_derivative_orderbooks', index=29,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=2568,
)


_FEEDISCOUNTACCOUNTTIERTTL = _descriptor.Descriptor(
  name='FeeDiscountAccountTierTTL',
  full_name='injective.exchange.v1beta1.FeeDiscountAccountTierTTL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.FeeDiscountAccountTierTTL.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tier_ttl', full_name='injective.exchange.v1beta1.FeeDiscountAccountTierTTL.tier_ttl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2570,
  serialized_end=2680,
)


_FEEDISCOUNTBUCKETVOLUMEACCOUNTS = _descriptor.Descriptor(
  name='FeeDiscountBucketVolumeAccounts',
  full_name='injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_start_timestamp', full_name='injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts.bucket_start_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_volume', full_name='injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts.account_volume', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2683,
  serialized_end=2815,
)


_ACCOUNTVOLUME = _descriptor.Descriptor(
  name='AccountVolume',
  full_name='injective.exchange.v1beta1.AccountVolume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.AccountVolume.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='injective.exchange.v1beta1.AccountVolume.volume', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2817,
  serialized_end=2913,
)


_TRADINGREWARDCAMPAIGNACCOUNTPOINTS = _descriptor.Descriptor(
  name='TradingRewardCampaignAccountPoints',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPoints.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPoints.points', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2915,
  serialized_end=3032,
)


_TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS = _descriptor.Descriptor(
  name='TradingRewardCampaignAccountPendingPoints',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reward_pool_start_timestamp', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints.reward_pool_start_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_points', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints.account_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3035,
  serialized_end=3203,
)


_SPOTORDERBOOK = _descriptor.Descriptor(
  name='SpotOrderBook',
  full_name='injective.exchange.v1beta1.SpotOrderBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.SpotOrderBook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuySide', full_name='injective.exchange.v1beta1.SpotOrderBook.isBuySide', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.SpotOrderBook.orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3205,
  serialized_end=3328,
)


_DERIVATIVEORDERBOOK = _descriptor.Descriptor(
  name='DerivativeOrderBook',
  full_name='injective.exchange.v1beta1.DerivativeOrderBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativeOrderBook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuySide', full_name='injective.exchange.v1beta1.DerivativeOrderBook.isBuySide', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.DerivativeOrderBook.orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3331,
  serialized_end=3466,
)


_CONDITIONALDERIVATIVEORDERBOOK = _descriptor.Descriptor(
  name='ConditionalDerivativeOrderBook',
  full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_buy_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.limit_buy_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_buy_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.market_buy_orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_sell_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.limit_sell_orders', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_sell_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.market_sell_orders', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3469,
  serialized_end=3840,
)


_BALANCE = _descriptor.Descriptor(
  name='Balance',
  full_name='injective.exchange.v1beta1.Balance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.Balance.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.Balance.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposits', full_name='injective.exchange.v1beta1.Balance.deposits', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3842,
  serialized_end=3954,
)


_DERIVATIVEPOSITION = _descriptor.Descriptor(
  name='DerivativePosition',
  full_name='injective.exchange.v1beta1.DerivativePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.DerivativePosition.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativePosition.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='injective.exchange.v1beta1.DerivativePosition.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3957,
  serialized_end=4085,
)


_SUBACCOUNTNONCE = _descriptor.Descriptor(
  name='SubaccountNonce',
  full_name='injective.exchange.v1beta1.SubaccountNonce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.SubaccountNonce.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_trade_nonce', full_name='injective.exchange.v1beta1.SubaccountNonce.subaccount_trade_nonce', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4088,
  serialized_end=4226,
)


_EXPIRYFUTURESMARKETINFOSTATE = _descriptor.Descriptor(
  name='ExpiryFuturesMarketInfoState',
  full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfoState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfoState.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_info', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfoState.market_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4228,
  serialized_end=4351,
)


_PERPETUALMARKETFUNDINGSTATE = _descriptor.Descriptor(
  name='PerpetualMarketFundingState',
  full_name='injective.exchange.v1beta1.PerpetualMarketFundingState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.PerpetualMarketFundingState.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding', full_name='injective.exchange.v1beta1.PerpetualMarketFundingState.funding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4353,
  serialized_end=4470,
)

_GENESISSTATE.fields_by_name['params'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PARAMS
_GENESISSTATE.fields_by_name['spot_markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTMARKET
_GENESISSTATE.fields_by_name['derivative_markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKET
_GENESISSTATE.fields_by_name['spot_orderbook'].message_type = _SPOTORDERBOOK
_GENESISSTATE.fields_by_name['derivative_orderbook'].message_type = _DERIVATIVEORDERBOOK
_GENESISSTATE.fields_by_name['balances'].message_type = _BALANCE
_GENESISSTATE.fields_by_name['positions'].message_type = _DERIVATIVEPOSITION
_GENESISSTATE.fields_by_name['subaccount_trade_nonces'].message_type = _SUBACCOUNTNONCE
_GENESISSTATE.fields_by_name['expiry_futures_market_info_state'].message_type = _EXPIRYFUTURESMARKETINFOSTATE
_GENESISSTATE.fields_by_name['perpetual_market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETINFO
_GENESISSTATE.fields_by_name['perpetual_market_funding_state'].message_type = _PERPETUALMARKETFUNDINGSTATE
_GENESISSTATE.fields_by_name['derivative_market_settlement_scheduled'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETSETTLEMENTINFO
_GENESISSTATE.fields_by_name['trading_reward_campaign_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADINGREWARDCAMPAIGNINFO
_GENESISSTATE.fields_by_name['trading_reward_pool_campaign_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_GENESISSTATE.fields_by_name['trading_reward_campaign_account_points'].message_type = _TRADINGREWARDCAMPAIGNACCOUNTPOINTS
_GENESISSTATE.fields_by_name['fee_discount_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTSCHEDULE
_GENESISSTATE.fields_by_name['fee_discount_account_tier_ttl'].message_type = _FEEDISCOUNTACCOUNTTIERTTL
_GENESISSTATE.fields_by_name['fee_discount_bucket_volume_accounts'].message_type = _FEEDISCOUNTBUCKETVOLUMEACCOUNTS
_GENESISSTATE.fields_by_name['pending_trading_reward_pool_campaign_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_GENESISSTATE.fields_by_name['pending_trading_reward_campaign_account_points'].message_type = _TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS
_GENESISSTATE.fields_by_name['historical_trade_records'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADERECORDS
_GENESISSTATE.fields_by_name['binary_options_markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._BINARYOPTIONSMARKET
_GENESISSTATE.fields_by_name['denom_decimals'].message_type = injective_dot_exchange_dot_v1beta1_dot_tx__pb2._DENOMDECIMALS
_GENESISSTATE.fields_by_name['conditional_derivative_orderbooks'].message_type = _CONDITIONALDERIVATIVEORDERBOOK
_FEEDISCOUNTACCOUNTTIERTTL.fields_by_name['tier_ttl'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTTIERTTL
_FEEDISCOUNTBUCKETVOLUMEACCOUNTS.fields_by_name['account_volume'].message_type = _ACCOUNTVOLUME
_TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS.fields_by_name['account_points'].message_type = _TRADINGREWARDCAMPAIGNACCOUNTPOINTS
_SPOTORDERBOOK.fields_by_name['orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTLIMITORDER
_DERIVATIVEORDERBOOK.fields_by_name['orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['limit_buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['market_buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['limit_sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['market_sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETORDER
_BALANCE.fields_by_name['deposits'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DEPOSIT
_DERIVATIVEPOSITION.fields_by_name['position'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._POSITION
_SUBACCOUNTNONCE.fields_by_name['subaccount_trade_nonce'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SUBACCOUNTTRADENONCE
_EXPIRYFUTURESMARKETINFOSTATE.fields_by_name['market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXPIRYFUTURESMARKETINFO
_PERPETUALMARKETFUNDINGSTATE.fields_by_name['funding'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETFUNDING
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
DESCRIPTOR.message_types_by_name['FeeDiscountAccountTierTTL'] = _FEEDISCOUNTACCOUNTTIERTTL
DESCRIPTOR.message_types_by_name['FeeDiscountBucketVolumeAccounts'] = _FEEDISCOUNTBUCKETVOLUMEACCOUNTS
DESCRIPTOR.message_types_by_name['AccountVolume'] = _ACCOUNTVOLUME
DESCRIPTOR.message_types_by_name['TradingRewardCampaignAccountPoints'] = _TRADINGREWARDCAMPAIGNACCOUNTPOINTS
DESCRIPTOR.message_types_by_name['TradingRewardCampaignAccountPendingPoints'] = _TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS
DESCRIPTOR.message_types_by_name['SpotOrderBook'] = _SPOTORDERBOOK
DESCRIPTOR.message_types_by_name['DerivativeOrderBook'] = _DERIVATIVEORDERBOOK
DESCRIPTOR.message_types_by_name['ConditionalDerivativeOrderBook'] = _CONDITIONALDERIVATIVEORDERBOOK
DESCRIPTOR.message_types_by_name['Balance'] = _BALANCE
DESCRIPTOR.message_types_by_name['DerivativePosition'] = _DERIVATIVEPOSITION
DESCRIPTOR.message_types_by_name['SubaccountNonce'] = _SUBACCOUNTNONCE
DESCRIPTOR.message_types_by_name['ExpiryFuturesMarketInfoState'] = _EXPIRYFUTURESMARKETINFOSTATE
DESCRIPTOR.message_types_by_name['PerpetualMarketFundingState'] = _PERPETUALMARKETFUNDINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

FeeDiscountAccountTierTTL = _reflection.GeneratedProtocolMessageType('FeeDiscountAccountTierTTL', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTACCOUNTTIERTTL,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountAccountTierTTL)
  })
_sym_db.RegisterMessage(FeeDiscountAccountTierTTL)

FeeDiscountBucketVolumeAccounts = _reflection.GeneratedProtocolMessageType('FeeDiscountBucketVolumeAccounts', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTBUCKETVOLUMEACCOUNTS,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts)
  })
_sym_db.RegisterMessage(FeeDiscountBucketVolumeAccounts)

AccountVolume = _reflection.GeneratedProtocolMessageType('AccountVolume', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTVOLUME,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.AccountVolume)
  })
_sym_db.RegisterMessage(AccountVolume)

TradingRewardCampaignAccountPoints = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignAccountPoints', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNACCOUNTPOINTS,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignAccountPoints)
  })
_sym_db.RegisterMessage(TradingRewardCampaignAccountPoints)

TradingRewardCampaignAccountPendingPoints = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignAccountPendingPoints', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints)
  })
_sym_db.RegisterMessage(TradingRewardCampaignAccountPendingPoints)

SpotOrderBook = _reflection.GeneratedProtocolMessageType('SpotOrderBook', (_message.Message,), {
  'DESCRIPTOR' : _SPOTORDERBOOK,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotOrderBook)
  })
_sym_db.RegisterMessage(SpotOrderBook)

DerivativeOrderBook = _reflection.GeneratedProtocolMessageType('DerivativeOrderBook', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEORDERBOOK,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeOrderBook)
  })
_sym_db.RegisterMessage(DerivativeOrderBook)

ConditionalDerivativeOrderBook = _reflection.GeneratedProtocolMessageType('ConditionalDerivativeOrderBook', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONALDERIVATIVEORDERBOOK,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ConditionalDerivativeOrderBook)
  })
_sym_db.RegisterMessage(ConditionalDerivativeOrderBook)

Balance = _reflection.GeneratedProtocolMessageType('Balance', (_message.Message,), {
  'DESCRIPTOR' : _BALANCE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.Balance)
  })
_sym_db.RegisterMessage(Balance)

DerivativePosition = _reflection.GeneratedProtocolMessageType('DerivativePosition', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEPOSITION,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativePosition)
  })
_sym_db.RegisterMessage(DerivativePosition)

SubaccountNonce = _reflection.GeneratedProtocolMessageType('SubaccountNonce', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTNONCE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountNonce)
  })
_sym_db.RegisterMessage(SubaccountNonce)

ExpiryFuturesMarketInfoState = _reflection.GeneratedProtocolMessageType('ExpiryFuturesMarketInfoState', (_message.Message,), {
  'DESCRIPTOR' : _EXPIRYFUTURESMARKETINFOSTATE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ExpiryFuturesMarketInfoState)
  })
_sym_db.RegisterMessage(ExpiryFuturesMarketInfoState)

PerpetualMarketFundingState = _reflection.GeneratedProtocolMessageType('PerpetualMarketFundingState', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETFUNDINGSTATE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PerpetualMarketFundingState)
  })
_sym_db.RegisterMessage(PerpetualMarketFundingState)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_GENESISSTATE.fields_by_name['spot_orderbook']._options = None
_GENESISSTATE.fields_by_name['derivative_orderbook']._options = None
_GENESISSTATE.fields_by_name['balances']._options = None
_GENESISSTATE.fields_by_name['positions']._options = None
_GENESISSTATE.fields_by_name['subaccount_trade_nonces']._options = None
_GENESISSTATE.fields_by_name['expiry_futures_market_info_state']._options = None
_GENESISSTATE.fields_by_name['perpetual_market_info']._options = None
_GENESISSTATE.fields_by_name['perpetual_market_funding_state']._options = None
_GENESISSTATE.fields_by_name['derivative_market_settlement_scheduled']._options = None
_GENESISSTATE.fields_by_name['denom_decimals']._options = None
_ACCOUNTVOLUME.fields_by_name['volume']._options = None
_TRADINGREWARDCAMPAIGNACCOUNTPOINTS.fields_by_name['points']._options = None
_SPOTORDERBOOK._options = None
_DERIVATIVEORDERBOOK._options = None
_CONDITIONALDERIVATIVEORDERBOOK._options = None
_BALANCE._options = None
_DERIVATIVEPOSITION._options = None
_SUBACCOUNTNONCE.fields_by_name['subaccount_trade_nonce']._options = None
_SUBACCOUNTNONCE._options = None
# @@protoc_insertion_point(module_scope)
