# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/pool.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dinjective/peggy/v1/pool.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\"\x14\n\x05IDSet\x12\x0b\n\x03ids\x18\x01 \x03(\x04\"^\n\tBatchFees\x12\r\n\x05token\x18\x01 \x01(\t\x12\x42\n\ntotal_fees\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_IDSET = _descriptor.Descriptor(
  name='IDSet',
  full_name='injective.peggy.v1.IDSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='injective.peggy.v1.IDSet.ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=95,
)


_BATCHFEES = _descriptor.Descriptor(
  name='BatchFees',
  full_name='injective.peggy.v1.BatchFees',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='injective.peggy.v1.BatchFees.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_fees', full_name='injective.peggy.v1.BatchFees.total_fees', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=191,
)

DESCRIPTOR.message_types_by_name['IDSet'] = _IDSET
DESCRIPTOR.message_types_by_name['BatchFees'] = _BATCHFEES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IDSet = _reflection.GeneratedProtocolMessageType('IDSet', (_message.Message,), {
  'DESCRIPTOR' : _IDSET,
  '__module__' : 'injective.peggy.v1.pool_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.IDSet)
  })
_sym_db.RegisterMessage(IDSet)

BatchFees = _reflection.GeneratedProtocolMessageType('BatchFees', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEES,
  '__module__' : 'injective.peggy.v1.pool_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.BatchFees)
  })
_sym_db.RegisterMessage(BatchFees)


DESCRIPTOR._options = None
_BATCHFEES.fields_by_name['total_fees']._options = None
# @@protoc_insertion_point(module_scope)
