# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_meta_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_meta_rpc.proto',
  package='injective_meta_rpc',
  syntax='proto3',
  serialized_options=b'Z\025/injective_meta_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!exchange/injective_meta_rpc.proto\x12\x12injective_meta_rpc\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x10\n\x0eVersionRequest\"\x8f\x01\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12=\n\x05\x62uild\x18\x02 \x03(\x0b\x32..injective_meta_rpc.VersionResponse.BuildEntry\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x0bInfoRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\"\xc1\x01\n\x0cInfoResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\x12\x13\n\x0bserver_time\x18\x02 \x01(\x12\x12\x0f\n\x07version\x18\x03 \x01(\t\x12:\n\x05\x62uild\x18\x04 \x03(\x0b\x32+.injective_meta_rpc.InfoResponse.BuildEntry\x12\x0e\n\x06region\x18\x05 \x01(\t\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x18\n\x16StreamKeepaliveRequest\"Q\n\x17StreamKeepaliveResponse\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x14\n\x0cnew_endpoint\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x32\xea\x02\n\x10InjectiveMetaRPC\x12I\n\x04Ping\x12\x1f.injective_meta_rpc.PingRequest\x1a .injective_meta_rpc.PingResponse\x12R\n\x07Version\x12\".injective_meta_rpc.VersionRequest\x1a#.injective_meta_rpc.VersionResponse\x12I\n\x04Info\x12\x1f.injective_meta_rpc.InfoRequest\x1a .injective_meta_rpc.InfoResponse\x12l\n\x0fStreamKeepalive\x12*.injective_meta_rpc.StreamKeepaliveRequest\x1a+.injective_meta_rpc.StreamKeepaliveResponse0\x01\x42\x17Z\x15/injective_meta_rpcpbb\x06proto3'
)




_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='injective_meta_rpc.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=70,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='injective_meta_rpc.PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=86,
)


_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='injective_meta_rpc.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=104,
)


_VERSIONRESPONSE_BUILDENTRY = _descriptor.Descriptor(
  name='BuildEntry',
  full_name='injective_meta_rpc.VersionResponse.BuildEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='injective_meta_rpc.VersionResponse.BuildEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective_meta_rpc.VersionResponse.BuildEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=250,
)

_VERSIONRESPONSE = _descriptor.Descriptor(
  name='VersionResponse',
  full_name='injective_meta_rpc.VersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='injective_meta_rpc.VersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build', full_name='injective_meta_rpc.VersionResponse.build', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VERSIONRESPONSE_BUILDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=250,
)


_INFOREQUEST = _descriptor.Descriptor(
  name='InfoRequest',
  full_name='injective_meta_rpc.InfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_meta_rpc.InfoRequest.timestamp', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=284,
)


_INFORESPONSE_BUILDENTRY = _descriptor.Descriptor(
  name='BuildEntry',
  full_name='injective_meta_rpc.InfoResponse.BuildEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='injective_meta_rpc.InfoResponse.BuildEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective_meta_rpc.InfoResponse.BuildEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=250,
)

_INFORESPONSE = _descriptor.Descriptor(
  name='InfoResponse',
  full_name='injective_meta_rpc.InfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_meta_rpc.InfoResponse.timestamp', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='injective_meta_rpc.InfoResponse.server_time', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='injective_meta_rpc.InfoResponse.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build', full_name='injective_meta_rpc.InfoResponse.build', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='injective_meta_rpc.InfoResponse.region', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INFORESPONSE_BUILDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=480,
)


_STREAMKEEPALIVEREQUEST = _descriptor.Descriptor(
  name='StreamKeepaliveRequest',
  full_name='injective_meta_rpc.StreamKeepaliveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=506,
)


_STREAMKEEPALIVERESPONSE = _descriptor.Descriptor(
  name='StreamKeepaliveResponse',
  full_name='injective_meta_rpc.StreamKeepaliveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='injective_meta_rpc.StreamKeepaliveResponse.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_endpoint', full_name='injective_meta_rpc.StreamKeepaliveResponse.new_endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_meta_rpc.StreamKeepaliveResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=589,
)

_VERSIONRESPONSE_BUILDENTRY.containing_type = _VERSIONRESPONSE
_VERSIONRESPONSE.fields_by_name['build'].message_type = _VERSIONRESPONSE_BUILDENTRY
_INFORESPONSE_BUILDENTRY.containing_type = _INFORESPONSE
_INFORESPONSE.fields_by_name['build'].message_type = _INFORESPONSE_BUILDENTRY
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionResponse'] = _VERSIONRESPONSE
DESCRIPTOR.message_types_by_name['InfoRequest'] = _INFOREQUEST
DESCRIPTOR.message_types_by_name['InfoResponse'] = _INFORESPONSE
DESCRIPTOR.message_types_by_name['StreamKeepaliveRequest'] = _STREAMKEEPALIVEREQUEST
DESCRIPTOR.message_types_by_name['StreamKeepaliveResponse'] = _STREAMKEEPALIVERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {

  'BuildEntry' : _reflection.GeneratedProtocolMessageType('BuildEntry', (_message.Message,), {
    'DESCRIPTOR' : _VERSIONRESPONSE_BUILDENTRY,
    '__module__' : 'exchange.injective_meta_rpc_pb2'
    # @@protoc_insertion_point(class_scope:injective_meta_rpc.VersionResponse.BuildEntry)
    })
  ,
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)
_sym_db.RegisterMessage(VersionResponse.BuildEntry)

InfoRequest = _reflection.GeneratedProtocolMessageType('InfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _INFOREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.InfoRequest)
  })
_sym_db.RegisterMessage(InfoRequest)

InfoResponse = _reflection.GeneratedProtocolMessageType('InfoResponse', (_message.Message,), {

  'BuildEntry' : _reflection.GeneratedProtocolMessageType('BuildEntry', (_message.Message,), {
    'DESCRIPTOR' : _INFORESPONSE_BUILDENTRY,
    '__module__' : 'exchange.injective_meta_rpc_pb2'
    # @@protoc_insertion_point(class_scope:injective_meta_rpc.InfoResponse.BuildEntry)
    })
  ,
  'DESCRIPTOR' : _INFORESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.InfoResponse)
  })
_sym_db.RegisterMessage(InfoResponse)
_sym_db.RegisterMessage(InfoResponse.BuildEntry)

StreamKeepaliveRequest = _reflection.GeneratedProtocolMessageType('StreamKeepaliveRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMKEEPALIVEREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.StreamKeepaliveRequest)
  })
_sym_db.RegisterMessage(StreamKeepaliveRequest)

StreamKeepaliveResponse = _reflection.GeneratedProtocolMessageType('StreamKeepaliveResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMKEEPALIVERESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.StreamKeepaliveResponse)
  })
_sym_db.RegisterMessage(StreamKeepaliveResponse)


DESCRIPTOR._options = None
_VERSIONRESPONSE_BUILDENTRY._options = None
_INFORESPONSE_BUILDENTRY._options = None

_INJECTIVEMETARPC = _descriptor.ServiceDescriptor(
  name='InjectiveMetaRPC',
  full_name='injective_meta_rpc.InjectiveMetaRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=592,
  serialized_end=954,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='injective_meta_rpc.InjectiveMetaRPC.Ping',
    index=0,
    containing_service=None,
    input_type=_PINGREQUEST,
    output_type=_PINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='injective_meta_rpc.InjectiveMetaRPC.Version',
    index=1,
    containing_service=None,
    input_type=_VERSIONREQUEST,
    output_type=_VERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Info',
    full_name='injective_meta_rpc.InjectiveMetaRPC.Info',
    index=2,
    containing_service=None,
    input_type=_INFOREQUEST,
    output_type=_INFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamKeepalive',
    full_name='injective_meta_rpc.InjectiveMetaRPC.StreamKeepalive',
    index=3,
    containing_service=None,
    input_type=_STREAMKEEPALIVEREQUEST,
    output_type=_STREAMKEEPALIVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEMETARPC)

DESCRIPTOR.services_by_name['InjectiveMetaRPC'] = _INJECTIVEMETARPC

# @@protoc_insertion_point(module_scope)
