# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/events.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1finjective/peggy/v1/events.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a$injective/peggy/v1/attestation.proto\x1a\x1einjective/peggy/v1/types.proto\"\xac\x01\n\x18\x45ventAttestationObserved\x12\x37\n\x10\x61ttestation_type\x18\x01 \x01(\x0e\x32\x1d.injective.peggy.v1.ClaimType\x12\x17\n\x0f\x62ridge_contract\x18\x02 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x03 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x04 \x01(\x0c\x12\r\n\x05nonce\x18\x05 \x01(\x04\"O\n\x1b\x45ventBridgeWithdrawCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\"\x83\x01\n\x12\x45ventOutgoingBatch\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x04 \x01(\x04\x12\x14\n\x0c\x62\x61tch_tx_ids\x18\x05 \x03(\x04\"o\n\x1a\x45ventOutgoingBatchCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x04\x12\r\n\x05nonce\x18\x04 \x01(\x04\"\xe1\x01\n\x18\x45ventValsetUpdateRequest\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x15\n\rvalset_height\x18\x02 \x01(\x04\x12;\n\x0evalset_members\x18\x03 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x05 \x01(\t\"v\n\x1d\x45ventSetOrchestratorAddresses\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x1c\n\x14operator_eth_address\x18\x03 \x01(\t\"H\n\x12\x45ventValsetConfirm\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"\xd0\x01\n\x0e\x45ventSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12?\n\x06\x61mount\x18\x04 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\x43\n\nbridge_fee\x18\x05 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\"F\n\x11\x45ventConfirmBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"R\n\x14\x45ventAttestationVote\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x02 \x01(\x0c\x12\r\n\x05voter\x18\x03 \x01(\t\"\x8c\x02\n\x11\x45ventDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x17\n\x0f\x65thereum_sender\x18\x04 \x01(\t\x12\x17\n\x0f\x63osmos_receiver\x18\x05 \x01(\t\x12\x16\n\x0etoken_contract\x18\x06 \x01(\t\x12>\n\x06\x61mount\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\t \x01(\t\"\xa2\x01\n\x12\x45ventWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x13\n\x0b\x62\x61tch_nonce\x18\x04 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x06 \x01(\t\"\xd8\x01\n\x17\x45ventERC20DeployedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63osmos_denom\x18\x04 \x01(\t\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x08 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\t \x01(\t\"\xa9\x02\n\x16\x45ventValsetUpdateClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0cvalset_nonce\x18\x04 \x01(\x04\x12;\n\x0evalset_members\x18\x05 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x07 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\".\n\x14\x45ventCancelSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\"_\n\x1f\x45ventSubmitBadSignatureEvidence\x12\x19\n\x11\x62\x61\x64_eth_signature\x18\x01 \x01(\t\x12!\n\x19\x62\x61\x64_eth_signature_subject\x18\x02 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_attestation__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_types__pb2.DESCRIPTOR,])




_EVENTATTESTATIONOBSERVED = _descriptor.Descriptor(
  name='EventAttestationObserved',
  full_name='injective.peggy.v1.EventAttestationObserved',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attestation_type', full_name='injective.peggy.v1.EventAttestationObserved.attestation_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_contract', full_name='injective.peggy.v1.EventAttestationObserved.bridge_contract', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.EventAttestationObserved.bridge_chain_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventAttestationObserved.attestation_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.EventAttestationObserved.nonce', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=320,
)


_EVENTBRIDGEWITHDRAWCANCELED = _descriptor.Descriptor(
  name='EventBridgeWithdrawCanceled',
  full_name='injective.peggy.v1.EventBridgeWithdrawCanceled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bridge_contract', full_name='injective.peggy.v1.EventBridgeWithdrawCanceled.bridge_contract', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.EventBridgeWithdrawCanceled.bridge_chain_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=401,
)


_EVENTOUTGOINGBATCH = _descriptor.Descriptor(
  name='EventOutgoingBatch',
  full_name='injective.peggy.v1.EventOutgoingBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.peggy.v1.EventOutgoingBatch.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventOutgoingBatch.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.EventOutgoingBatch.batch_nonce', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_timeout', full_name='injective.peggy.v1.EventOutgoingBatch.batch_timeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_tx_ids', full_name='injective.peggy.v1.EventOutgoingBatch.batch_tx_ids', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=535,
)


_EVENTOUTGOINGBATCHCANCELED = _descriptor.Descriptor(
  name='EventOutgoingBatchCanceled',
  full_name='injective.peggy.v1.EventOutgoingBatchCanceled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bridge_contract', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.bridge_contract', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.bridge_chain_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.batch_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.nonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=648,
)


_EVENTVALSETUPDATEREQUEST = _descriptor.Descriptor(
  name='EventValsetUpdateRequest',
  full_name='injective.peggy.v1.EventValsetUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.EventValsetUpdateRequest.valset_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_height', full_name='injective.peggy.v1.EventValsetUpdateRequest.valset_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_members', full_name='injective.peggy.v1.EventValsetUpdateRequest.valset_members', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_amount', full_name='injective.peggy.v1.EventValsetUpdateRequest.reward_amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_token', full_name='injective.peggy.v1.EventValsetUpdateRequest.reward_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=876,
)


_EVENTSETORCHESTRATORADDRESSES = _descriptor.Descriptor(
  name='EventSetOrchestratorAddresses',
  full_name='injective.peggy.v1.EventSetOrchestratorAddresses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='injective.peggy.v1.EventSetOrchestratorAddresses.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventSetOrchestratorAddresses.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator_eth_address', full_name='injective.peggy.v1.EventSetOrchestratorAddresses.operator_eth_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=996,
)


_EVENTVALSETCONFIRM = _descriptor.Descriptor(
  name='EventValsetConfirm',
  full_name='injective.peggy.v1.EventValsetConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.EventValsetConfirm.valset_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventValsetConfirm.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1070,
)


_EVENTSENDTOETH = _descriptor.Descriptor(
  name='EventSendToEth',
  full_name='injective.peggy.v1.EventSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outgoing_tx_id', full_name='injective.peggy.v1.EventSendToEth.outgoing_tx_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.peggy.v1.EventSendToEth.sender', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='injective.peggy.v1.EventSendToEth.receiver', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.EventSendToEth.amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_fee', full_name='injective.peggy.v1.EventSendToEth.bridge_fee', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1281,
)


_EVENTCONFIRMBATCH = _descriptor.Descriptor(
  name='EventConfirmBatch',
  full_name='injective.peggy.v1.EventConfirmBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.EventConfirmBatch.batch_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventConfirmBatch.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1353,
)


_EVENTATTESTATIONVOTE = _descriptor.Descriptor(
  name='EventAttestationVote',
  full_name='injective.peggy.v1.EventAttestationVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventAttestationVote.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventAttestationVote.attestation_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voter', full_name='injective.peggy.v1.EventAttestationVote.voter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1437,
)


_EVENTDEPOSITCLAIM = _descriptor.Descriptor(
  name='EventDepositClaim',
  full_name='injective.peggy.v1.EventDepositClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventDepositClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventDepositClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventDepositClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_sender', full_name='injective.peggy.v1.EventDepositClaim.ethereum_sender', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_receiver', full_name='injective.peggy.v1.EventDepositClaim.cosmos_receiver', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.EventDepositClaim.token_contract', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.EventDepositClaim.amount', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventDepositClaim.orchestrator_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.peggy.v1.EventDepositClaim.data', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1708,
)


_EVENTWITHDRAWCLAIM = _descriptor.Descriptor(
  name='EventWithdrawClaim',
  full_name='injective.peggy.v1.EventWithdrawClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventWithdrawClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventWithdrawClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventWithdrawClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.EventWithdrawClaim.batch_nonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.EventWithdrawClaim.token_contract', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventWithdrawClaim.orchestrator_address', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1873,
)


_EVENTERC20DEPLOYEDCLAIM = _descriptor.Descriptor(
  name='EventERC20DeployedClaim',
  full_name='injective.peggy.v1.EventERC20DeployedClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventERC20DeployedClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventERC20DeployedClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventERC20DeployedClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_denom', full_name='injective.peggy.v1.EventERC20DeployedClaim.cosmos_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.EventERC20DeployedClaim.token_contract', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='injective.peggy.v1.EventERC20DeployedClaim.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.peggy.v1.EventERC20DeployedClaim.symbol', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective.peggy.v1.EventERC20DeployedClaim.decimals', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventERC20DeployedClaim.orchestrator_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=2092,
)


_EVENTVALSETUPDATECLAIM = _descriptor.Descriptor(
  name='EventValsetUpdateClaim',
  full_name='injective.peggy.v1.EventValsetUpdateClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventValsetUpdateClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventValsetUpdateClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventValsetUpdateClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.EventValsetUpdateClaim.valset_nonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_members', full_name='injective.peggy.v1.EventValsetUpdateClaim.valset_members', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_amount', full_name='injective.peggy.v1.EventValsetUpdateClaim.reward_amount', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_token', full_name='injective.peggy.v1.EventValsetUpdateClaim.reward_token', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventValsetUpdateClaim.orchestrator_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2095,
  serialized_end=2392,
)


_EVENTCANCELSENDTOETH = _descriptor.Descriptor(
  name='EventCancelSendToEth',
  full_name='injective.peggy.v1.EventCancelSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outgoing_tx_id', full_name='injective.peggy.v1.EventCancelSendToEth.outgoing_tx_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2394,
  serialized_end=2440,
)


_EVENTSUBMITBADSIGNATUREEVIDENCE = _descriptor.Descriptor(
  name='EventSubmitBadSignatureEvidence',
  full_name='injective.peggy.v1.EventSubmitBadSignatureEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bad_eth_signature', full_name='injective.peggy.v1.EventSubmitBadSignatureEvidence.bad_eth_signature', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bad_eth_signature_subject', full_name='injective.peggy.v1.EventSubmitBadSignatureEvidence.bad_eth_signature_subject', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2442,
  serialized_end=2537,
)

_EVENTATTESTATIONOBSERVED.fields_by_name['attestation_type'].enum_type = injective_dot_peggy_dot_v1_dot_attestation__pb2._CLAIMTYPE
_EVENTVALSETUPDATEREQUEST.fields_by_name['valset_members'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._BRIDGEVALIDATOR
_EVENTVALSETUPDATECLAIM.fields_by_name['valset_members'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._BRIDGEVALIDATOR
DESCRIPTOR.message_types_by_name['EventAttestationObserved'] = _EVENTATTESTATIONOBSERVED
DESCRIPTOR.message_types_by_name['EventBridgeWithdrawCanceled'] = _EVENTBRIDGEWITHDRAWCANCELED
DESCRIPTOR.message_types_by_name['EventOutgoingBatch'] = _EVENTOUTGOINGBATCH
DESCRIPTOR.message_types_by_name['EventOutgoingBatchCanceled'] = _EVENTOUTGOINGBATCHCANCELED
DESCRIPTOR.message_types_by_name['EventValsetUpdateRequest'] = _EVENTVALSETUPDATEREQUEST
DESCRIPTOR.message_types_by_name['EventSetOrchestratorAddresses'] = _EVENTSETORCHESTRATORADDRESSES
DESCRIPTOR.message_types_by_name['EventValsetConfirm'] = _EVENTVALSETCONFIRM
DESCRIPTOR.message_types_by_name['EventSendToEth'] = _EVENTSENDTOETH
DESCRIPTOR.message_types_by_name['EventConfirmBatch'] = _EVENTCONFIRMBATCH
DESCRIPTOR.message_types_by_name['EventAttestationVote'] = _EVENTATTESTATIONVOTE
DESCRIPTOR.message_types_by_name['EventDepositClaim'] = _EVENTDEPOSITCLAIM
DESCRIPTOR.message_types_by_name['EventWithdrawClaim'] = _EVENTWITHDRAWCLAIM
DESCRIPTOR.message_types_by_name['EventERC20DeployedClaim'] = _EVENTERC20DEPLOYEDCLAIM
DESCRIPTOR.message_types_by_name['EventValsetUpdateClaim'] = _EVENTVALSETUPDATECLAIM
DESCRIPTOR.message_types_by_name['EventCancelSendToEth'] = _EVENTCANCELSENDTOETH
DESCRIPTOR.message_types_by_name['EventSubmitBadSignatureEvidence'] = _EVENTSUBMITBADSIGNATUREEVIDENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventAttestationObserved = _reflection.GeneratedProtocolMessageType('EventAttestationObserved', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTESTATIONOBSERVED,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventAttestationObserved)
  })
_sym_db.RegisterMessage(EventAttestationObserved)

EventBridgeWithdrawCanceled = _reflection.GeneratedProtocolMessageType('EventBridgeWithdrawCanceled', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBRIDGEWITHDRAWCANCELED,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventBridgeWithdrawCanceled)
  })
_sym_db.RegisterMessage(EventBridgeWithdrawCanceled)

EventOutgoingBatch = _reflection.GeneratedProtocolMessageType('EventOutgoingBatch', (_message.Message,), {
  'DESCRIPTOR' : _EVENTOUTGOINGBATCH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventOutgoingBatch)
  })
_sym_db.RegisterMessage(EventOutgoingBatch)

EventOutgoingBatchCanceled = _reflection.GeneratedProtocolMessageType('EventOutgoingBatchCanceled', (_message.Message,), {
  'DESCRIPTOR' : _EVENTOUTGOINGBATCHCANCELED,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventOutgoingBatchCanceled)
  })
_sym_db.RegisterMessage(EventOutgoingBatchCanceled)

EventValsetUpdateRequest = _reflection.GeneratedProtocolMessageType('EventValsetUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVALSETUPDATEREQUEST,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventValsetUpdateRequest)
  })
_sym_db.RegisterMessage(EventValsetUpdateRequest)

EventSetOrchestratorAddresses = _reflection.GeneratedProtocolMessageType('EventSetOrchestratorAddresses', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSETORCHESTRATORADDRESSES,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventSetOrchestratorAddresses)
  })
_sym_db.RegisterMessage(EventSetOrchestratorAddresses)

EventValsetConfirm = _reflection.GeneratedProtocolMessageType('EventValsetConfirm', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVALSETCONFIRM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventValsetConfirm)
  })
_sym_db.RegisterMessage(EventValsetConfirm)

EventSendToEth = _reflection.GeneratedProtocolMessageType('EventSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSENDTOETH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventSendToEth)
  })
_sym_db.RegisterMessage(EventSendToEth)

EventConfirmBatch = _reflection.GeneratedProtocolMessageType('EventConfirmBatch', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCONFIRMBATCH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventConfirmBatch)
  })
_sym_db.RegisterMessage(EventConfirmBatch)

EventAttestationVote = _reflection.GeneratedProtocolMessageType('EventAttestationVote', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTESTATIONVOTE,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventAttestationVote)
  })
_sym_db.RegisterMessage(EventAttestationVote)

EventDepositClaim = _reflection.GeneratedProtocolMessageType('EventDepositClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDEPOSITCLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventDepositClaim)
  })
_sym_db.RegisterMessage(EventDepositClaim)

EventWithdrawClaim = _reflection.GeneratedProtocolMessageType('EventWithdrawClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTWITHDRAWCLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventWithdrawClaim)
  })
_sym_db.RegisterMessage(EventWithdrawClaim)

EventERC20DeployedClaim = _reflection.GeneratedProtocolMessageType('EventERC20DeployedClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTERC20DEPLOYEDCLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventERC20DeployedClaim)
  })
_sym_db.RegisterMessage(EventERC20DeployedClaim)

EventValsetUpdateClaim = _reflection.GeneratedProtocolMessageType('EventValsetUpdateClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVALSETUPDATECLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventValsetUpdateClaim)
  })
_sym_db.RegisterMessage(EventValsetUpdateClaim)

EventCancelSendToEth = _reflection.GeneratedProtocolMessageType('EventCancelSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELSENDTOETH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventCancelSendToEth)
  })
_sym_db.RegisterMessage(EventCancelSendToEth)

EventSubmitBadSignatureEvidence = _reflection.GeneratedProtocolMessageType('EventSubmitBadSignatureEvidence', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBMITBADSIGNATUREEVIDENCE,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventSubmitBadSignatureEvidence)
  })
_sym_db.RegisterMessage(EventSubmitBadSignatureEvidence)


DESCRIPTOR._options = None
_EVENTVALSETUPDATEREQUEST.fields_by_name['reward_amount']._options = None
_EVENTSENDTOETH.fields_by_name['amount']._options = None
_EVENTSENDTOETH.fields_by_name['bridge_fee']._options = None
_EVENTDEPOSITCLAIM.fields_by_name['amount']._options = None
_EVENTVALSETUPDATECLAIM.fields_by_name['reward_amount']._options = None
# @@protoc_insertion_point(module_scope)
