# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/p2p/conn.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/p2p/conn.proto',
  package='tendermint.p2p',
  syntax='proto3',
  serialized_options=b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19tendermint/p2p/conn.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto\"\x0c\n\nPacketPing\"\x0c\n\nPacketPong\"R\n\tPacketMsg\x12!\n\nchannel_id\x18\x01 \x01(\x05\x42\r\xe2\xde\x1f\tChannelID\x12\x14\n\x03\x65of\x18\x02 \x01(\x08\x42\x07\xe2\xde\x1f\x03\x45OF\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xa6\x01\n\x06Packet\x12\x31\n\x0bpacket_ping\x18\x01 \x01(\x0b\x32\x1a.tendermint.p2p.PacketPingH\x00\x12\x31\n\x0bpacket_pong\x18\x02 \x01(\x0b\x32\x1a.tendermint.p2p.PacketPongH\x00\x12/\n\npacket_msg\x18\x03 \x01(\x0b\x32\x19.tendermint.p2p.PacketMsgH\x00\x42\x05\n\x03sum\"R\n\x0e\x41uthSigMessage\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\x42\x37Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,tendermint_dot_crypto_dot_keys__pb2.DESCRIPTOR,])




_PACKETPING = _descriptor.Descriptor(
  name='PacketPing',
  full_name='tendermint.p2p.PacketPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=109,
)


_PACKETPONG = _descriptor.Descriptor(
  name='PacketPong',
  full_name='tendermint.p2p.PacketPong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=123,
)


_PACKETMSG = _descriptor.Descriptor(
  name='PacketMsg',
  full_name='tendermint.p2p.PacketMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='tendermint.p2p.PacketMsg.channel_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tChannelID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eof', full_name='tendermint.p2p.PacketMsg.eof', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\003EOF', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='tendermint.p2p.PacketMsg.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=207,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='tendermint.p2p.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet_ping', full_name='tendermint.p2p.Packet.packet_ping', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_pong', full_name='tendermint.p2p.Packet.packet_pong', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_msg', full_name='tendermint.p2p.Packet.packet_msg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.p2p.Packet.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=210,
  serialized_end=376,
)


_AUTHSIGMESSAGE = _descriptor.Descriptor(
  name='AuthSigMessage',
  full_name='tendermint.p2p.AuthSigMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='tendermint.p2p.AuthSigMessage.pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sig', full_name='tendermint.p2p.AuthSigMessage.sig', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=460,
)

_PACKET.fields_by_name['packet_ping'].message_type = _PACKETPING
_PACKET.fields_by_name['packet_pong'].message_type = _PACKETPONG
_PACKET.fields_by_name['packet_msg'].message_type = _PACKETMSG
_PACKET.oneofs_by_name['sum'].fields.append(
  _PACKET.fields_by_name['packet_ping'])
_PACKET.fields_by_name['packet_ping'].containing_oneof = _PACKET.oneofs_by_name['sum']
_PACKET.oneofs_by_name['sum'].fields.append(
  _PACKET.fields_by_name['packet_pong'])
_PACKET.fields_by_name['packet_pong'].containing_oneof = _PACKET.oneofs_by_name['sum']
_PACKET.oneofs_by_name['sum'].fields.append(
  _PACKET.fields_by_name['packet_msg'])
_PACKET.fields_by_name['packet_msg'].containing_oneof = _PACKET.oneofs_by_name['sum']
_AUTHSIGMESSAGE.fields_by_name['pub_key'].message_type = tendermint_dot_crypto_dot_keys__pb2._PUBLICKEY
DESCRIPTOR.message_types_by_name['PacketPing'] = _PACKETPING
DESCRIPTOR.message_types_by_name['PacketPong'] = _PACKETPONG
DESCRIPTOR.message_types_by_name['PacketMsg'] = _PACKETMSG
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['AuthSigMessage'] = _AUTHSIGMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PacketPing = _reflection.GeneratedProtocolMessageType('PacketPing', (_message.Message,), {
  'DESCRIPTOR' : _PACKETPING,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PacketPing)
  })
_sym_db.RegisterMessage(PacketPing)

PacketPong = _reflection.GeneratedProtocolMessageType('PacketPong', (_message.Message,), {
  'DESCRIPTOR' : _PACKETPONG,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PacketPong)
  })
_sym_db.RegisterMessage(PacketPong)

PacketMsg = _reflection.GeneratedProtocolMessageType('PacketMsg', (_message.Message,), {
  'DESCRIPTOR' : _PACKETMSG,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PacketMsg)
  })
_sym_db.RegisterMessage(PacketMsg)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {
  'DESCRIPTOR' : _PACKET,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.Packet)
  })
_sym_db.RegisterMessage(Packet)

AuthSigMessage = _reflection.GeneratedProtocolMessageType('AuthSigMessage', (_message.Message,), {
  'DESCRIPTOR' : _AUTHSIGMESSAGE,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.AuthSigMessage)
  })
_sym_db.RegisterMessage(AuthSigMessage)


DESCRIPTOR._options = None
_PACKETMSG.fields_by_name['channel_id']._options = None
_PACKETMSG.fields_by_name['eof']._options = None
_AUTHSIGMESSAGE.fields_by_name['pub_key']._options = None
# @@protoc_insertion_point(module_scope)
