# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmwasm/wasm/v1/query.proto',
  package='cosmwasm.wasm.v1',
  syntax='proto3',
  serialized_options=b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\250\342\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x63osmwasm/wasm/v1/query.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"+\n\x18QueryContractInfoRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"w\n\x19QueryContractInfoResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x43\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\x0c\xd0\xde\x1f\x01\xc8\xde\x1f\x00\xea\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"j\n\x1bQueryContractHistoryRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9e\x01\n\x1cQueryContractHistoryResponse\x12\x41\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.cosmwasm.wasm.v1.ContractCodeHistoryEntryB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"j\n\x1bQueryContractsByCodeRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"n\n\x1cQueryContractsByCodeResponse\x12\x11\n\tcontracts\x18\x01 \x03(\t\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"k\n\x1cQueryAllContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8b\x01\n\x1dQueryAllContractStateResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"C\n\x1cQueryRawContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\nquery_data\x18\x02 \x01(\x0c\"-\n\x1dQueryRawContractStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"]\n\x1eQuerySmartContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12*\n\nquery_data\x18\x02 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"G\n\x1fQuerySmartContractStateResponse\x12$\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"#\n\x10QueryCodeRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\"\xeb\x01\n\x10\x43odeInfoResponse\x12!\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\x10\xe2\xde\x1f\x06\x43odeID\xea\xde\x1f\x02id\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12K\n\tdata_hash\x18\x03 \x01(\x0c\x42\x38\xfa\xde\x1f\x34github.com/tendermint/tendermint/libs/bytes.HexBytes\x12\x44\n\x16instantiate_permission\x18\x06 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"r\n\x11QueryCodeResponse\x12?\n\tcode_info\x18\x01 \x01(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\x08\xd0\xde\x1f\x01\xea\xde\x1f\x00\x12\x16\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61ta:\x04\xe8\xa0\x1f\x01\"O\n\x11QueryCodesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8f\x01\n\x12QueryCodesResponse\x12<\n\ncode_infos\x18\x01 \x03(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"U\n\x17QueryPinnedCodesRequest\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"z\n\x18QueryPinnedCodesResponse\x12!\n\x08\x63ode_ids\x18\x01 \x03(\x04\x42\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x43odeIDs\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x89\x0b\n\x05Query\x12\x95\x01\n\x0c\x43ontractInfo\x12*.cosmwasm.wasm.v1.QueryContractInfoRequest\x1a+.cosmwasm.wasm.v1.QueryContractInfoResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmwasm/wasm/v1/contract/{address}\x12\xa6\x01\n\x0f\x43ontractHistory\x12-.cosmwasm.wasm.v1.QueryContractHistoryRequest\x1a..cosmwasm.wasm.v1.QueryContractHistoryResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmwasm/wasm/v1/contract/{address}/history\x12\xa4\x01\n\x0f\x43ontractsByCode\x12-.cosmwasm.wasm.v1.QueryContractsByCodeRequest\x1a..cosmwasm.wasm.v1.QueryContractsByCodeResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/code/{code_id}/contracts\x12\xa7\x01\n\x10\x41llContractState\x12..cosmwasm.wasm.v1.QueryAllContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryAllContractStateResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/contract/{address}/state\x12\xb2\x01\n\x10RawContractState\x12..cosmwasm.wasm.v1.QueryRawContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryRawContractStateResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}\x12\xba\x01\n\x12SmartContractState\x12\x30.cosmwasm.wasm.v1.QuerySmartContractStateRequest\x1a\x31.cosmwasm.wasm.v1.QuerySmartContractStateResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}\x12y\n\x04\x43ode\x12\".cosmwasm.wasm.v1.QueryCodeRequest\x1a#.cosmwasm.wasm.v1.QueryCodeResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmwasm/wasm/v1/code/{code_id}\x12r\n\x05\x43odes\x12#.cosmwasm.wasm.v1.QueryCodesRequest\x1a$.cosmwasm.wasm.v1.QueryCodesResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmwasm/wasm/v1/code\x12\x8c\x01\n\x0bPinnedCodes\x12).cosmwasm.wasm.v1.QueryPinnedCodesRequest\x1a*.cosmwasm.wasm.v1.QueryPinnedCodesResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmwasm/wasm/v1/codes/pinnedB0Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmwasm_dot_wasm_dot_v1_dot_types__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2.DESCRIPTOR,])




_QUERYCONTRACTINFOREQUEST = _descriptor.Descriptor(
  name='QueryContractInfoRequest',
  full_name='cosmwasm.wasm.v1.QueryContractInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryContractInfoRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=219,
)


_QUERYCONTRACTINFORESPONSE = _descriptor.Descriptor(
  name='QueryContractInfoResponse',
  full_name='cosmwasm.wasm.v1.QueryContractInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryContractInfoResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_info', full_name='cosmwasm.wasm.v1.QueryContractInfoResponse.contract_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\320\336\037\001\310\336\037\000\352\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=340,
)


_QUERYCONTRACTHISTORYREQUEST = _descriptor.Descriptor(
  name='QueryContractHistoryRequest',
  full_name='cosmwasm.wasm.v1.QueryContractHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryContractHistoryRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractHistoryRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=448,
)


_QUERYCONTRACTHISTORYRESPONSE = _descriptor.Descriptor(
  name='QueryContractHistoryResponse',
  full_name='cosmwasm.wasm.v1.QueryContractHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='cosmwasm.wasm.v1.QueryContractHistoryResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractHistoryResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=609,
)


_QUERYCONTRACTSBYCODEREQUEST = _descriptor.Descriptor(
  name='QueryContractsByCodeRequest',
  full_name='cosmwasm.wasm.v1.QueryContractsByCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_id', full_name='cosmwasm.wasm.v1.QueryContractsByCodeRequest.code_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractsByCodeRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=717,
)


_QUERYCONTRACTSBYCODERESPONSE = _descriptor.Descriptor(
  name='QueryContractsByCodeResponse',
  full_name='cosmwasm.wasm.v1.QueryContractsByCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contracts', full_name='cosmwasm.wasm.v1.QueryContractsByCodeResponse.contracts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractsByCodeResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=829,
)


_QUERYALLCONTRACTSTATEREQUEST = _descriptor.Descriptor(
  name='QueryAllContractStateRequest',
  full_name='cosmwasm.wasm.v1.QueryAllContractStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryAllContractStateRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryAllContractStateRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=938,
)


_QUERYALLCONTRACTSTATERESPONSE = _descriptor.Descriptor(
  name='QueryAllContractStateResponse',
  full_name='cosmwasm.wasm.v1.QueryAllContractStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='cosmwasm.wasm.v1.QueryAllContractStateResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryAllContractStateResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=1080,
)


_QUERYRAWCONTRACTSTATEREQUEST = _descriptor.Descriptor(
  name='QueryRawContractStateRequest',
  full_name='cosmwasm.wasm.v1.QueryRawContractStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryRawContractStateRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_data', full_name='cosmwasm.wasm.v1.QueryRawContractStateRequest.query_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1149,
)


_QUERYRAWCONTRACTSTATERESPONSE = _descriptor.Descriptor(
  name='QueryRawContractStateResponse',
  full_name='cosmwasm.wasm.v1.QueryRawContractStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.QueryRawContractStateResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1196,
)


_QUERYSMARTCONTRACTSTATEREQUEST = _descriptor.Descriptor(
  name='QuerySmartContractStateRequest',
  full_name='cosmwasm.wasm.v1.QuerySmartContractStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QuerySmartContractStateRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_data', full_name='cosmwasm.wasm.v1.QuerySmartContractStateRequest.query_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\037\022RawContractMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1291,
)


_QUERYSMARTCONTRACTSTATERESPONSE = _descriptor.Descriptor(
  name='QuerySmartContractStateResponse',
  full_name='cosmwasm.wasm.v1.QuerySmartContractStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.QuerySmartContractStateResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\037\022RawContractMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1364,
)


_QUERYCODEREQUEST = _descriptor.Descriptor(
  name='QueryCodeRequest',
  full_name='cosmwasm.wasm.v1.QueryCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_id', full_name='cosmwasm.wasm.v1.QueryCodeRequest.code_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1401,
)


_CODEINFORESPONSE = _descriptor.Descriptor(
  name='CodeInfoResponse',
  full_name='cosmwasm.wasm.v1.CodeInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_id', full_name='cosmwasm.wasm.v1.CodeInfoResponse.code_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\006CodeID\352\336\037\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator', full_name='cosmwasm.wasm.v1.CodeInfoResponse.creator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='cosmwasm.wasm.v1.CodeInfoResponse.data_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\0374github.com/tendermint/tendermint/libs/bytes.HexBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instantiate_permission', full_name='cosmwasm.wasm.v1.CodeInfoResponse.instantiate_permission', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1639,
)


_QUERYCODERESPONSE = _descriptor.Descriptor(
  name='QueryCodeResponse',
  full_name='cosmwasm.wasm.v1.QueryCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_info', full_name='cosmwasm.wasm.v1.QueryCodeResponse.code_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\320\336\037\001\352\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.QueryCodeResponse.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\352\336\037\004data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1755,
)


_QUERYCODESREQUEST = _descriptor.Descriptor(
  name='QueryCodesRequest',
  full_name='cosmwasm.wasm.v1.QueryCodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryCodesRequest.pagination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1836,
)


_QUERYCODESRESPONSE = _descriptor.Descriptor(
  name='QueryCodesResponse',
  full_name='cosmwasm.wasm.v1.QueryCodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_infos', full_name='cosmwasm.wasm.v1.QueryCodesResponse.code_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryCodesResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1839,
  serialized_end=1982,
)


_QUERYPINNEDCODESREQUEST = _descriptor.Descriptor(
  name='QueryPinnedCodesRequest',
  full_name='cosmwasm.wasm.v1.QueryPinnedCodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryPinnedCodesRequest.pagination', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1984,
  serialized_end=2069,
)


_QUERYPINNEDCODESRESPONSE = _descriptor.Descriptor(
  name='QueryPinnedCodesResponse',
  full_name='cosmwasm.wasm.v1.QueryPinnedCodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_ids', full_name='cosmwasm.wasm.v1.QueryPinnedCodesResponse.code_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\342\336\037\007CodeIDs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryPinnedCodesResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2071,
  serialized_end=2193,
)

_QUERYCONTRACTINFORESPONSE.fields_by_name['contract_info'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._CONTRACTINFO
_QUERYCONTRACTHISTORYREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYCONTRACTHISTORYRESPONSE.fields_by_name['entries'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._CONTRACTCODEHISTORYENTRY
_QUERYCONTRACTHISTORYRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYCONTRACTSBYCODEREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYCONTRACTSBYCODERESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYALLCONTRACTSTATEREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYALLCONTRACTSTATERESPONSE.fields_by_name['models'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._MODEL
_QUERYALLCONTRACTSTATERESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_CODEINFORESPONSE.fields_by_name['instantiate_permission'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._ACCESSCONFIG
_QUERYCODERESPONSE.fields_by_name['code_info'].message_type = _CODEINFORESPONSE
_QUERYCODESREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYCODESRESPONSE.fields_by_name['code_infos'].message_type = _CODEINFORESPONSE
_QUERYCODESRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYPINNEDCODESREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYPINNEDCODESRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
DESCRIPTOR.message_types_by_name['QueryContractInfoRequest'] = _QUERYCONTRACTINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryContractInfoResponse'] = _QUERYCONTRACTINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryContractHistoryRequest'] = _QUERYCONTRACTHISTORYREQUEST
DESCRIPTOR.message_types_by_name['QueryContractHistoryResponse'] = _QUERYCONTRACTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['QueryContractsByCodeRequest'] = _QUERYCONTRACTSBYCODEREQUEST
DESCRIPTOR.message_types_by_name['QueryContractsByCodeResponse'] = _QUERYCONTRACTSBYCODERESPONSE
DESCRIPTOR.message_types_by_name['QueryAllContractStateRequest'] = _QUERYALLCONTRACTSTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryAllContractStateResponse'] = _QUERYALLCONTRACTSTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryRawContractStateRequest'] = _QUERYRAWCONTRACTSTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryRawContractStateResponse'] = _QUERYRAWCONTRACTSTATERESPONSE
DESCRIPTOR.message_types_by_name['QuerySmartContractStateRequest'] = _QUERYSMARTCONTRACTSTATEREQUEST
DESCRIPTOR.message_types_by_name['QuerySmartContractStateResponse'] = _QUERYSMARTCONTRACTSTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryCodeRequest'] = _QUERYCODEREQUEST
DESCRIPTOR.message_types_by_name['CodeInfoResponse'] = _CODEINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryCodeResponse'] = _QUERYCODERESPONSE
DESCRIPTOR.message_types_by_name['QueryCodesRequest'] = _QUERYCODESREQUEST
DESCRIPTOR.message_types_by_name['QueryCodesResponse'] = _QUERYCODESRESPONSE
DESCRIPTOR.message_types_by_name['QueryPinnedCodesRequest'] = _QUERYPINNEDCODESREQUEST
DESCRIPTOR.message_types_by_name['QueryPinnedCodesResponse'] = _QUERYPINNEDCODESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryContractInfoRequest = _reflection.GeneratedProtocolMessageType('QueryContractInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTINFOREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractInfoRequest)
  })
_sym_db.RegisterMessage(QueryContractInfoRequest)

QueryContractInfoResponse = _reflection.GeneratedProtocolMessageType('QueryContractInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTINFORESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractInfoResponse)
  })
_sym_db.RegisterMessage(QueryContractInfoResponse)

QueryContractHistoryRequest = _reflection.GeneratedProtocolMessageType('QueryContractHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTHISTORYREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractHistoryRequest)
  })
_sym_db.RegisterMessage(QueryContractHistoryRequest)

QueryContractHistoryResponse = _reflection.GeneratedProtocolMessageType('QueryContractHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTHISTORYRESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractHistoryResponse)
  })
_sym_db.RegisterMessage(QueryContractHistoryResponse)

QueryContractsByCodeRequest = _reflection.GeneratedProtocolMessageType('QueryContractsByCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTSBYCODEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractsByCodeRequest)
  })
_sym_db.RegisterMessage(QueryContractsByCodeRequest)

QueryContractsByCodeResponse = _reflection.GeneratedProtocolMessageType('QueryContractsByCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTSBYCODERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractsByCodeResponse)
  })
_sym_db.RegisterMessage(QueryContractsByCodeResponse)

QueryAllContractStateRequest = _reflection.GeneratedProtocolMessageType('QueryAllContractStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLCONTRACTSTATEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryAllContractStateRequest)
  })
_sym_db.RegisterMessage(QueryAllContractStateRequest)

QueryAllContractStateResponse = _reflection.GeneratedProtocolMessageType('QueryAllContractStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLCONTRACTSTATERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryAllContractStateResponse)
  })
_sym_db.RegisterMessage(QueryAllContractStateResponse)

QueryRawContractStateRequest = _reflection.GeneratedProtocolMessageType('QueryRawContractStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWCONTRACTSTATEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryRawContractStateRequest)
  })
_sym_db.RegisterMessage(QueryRawContractStateRequest)

QueryRawContractStateResponse = _reflection.GeneratedProtocolMessageType('QueryRawContractStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWCONTRACTSTATERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryRawContractStateResponse)
  })
_sym_db.RegisterMessage(QueryRawContractStateResponse)

QuerySmartContractStateRequest = _reflection.GeneratedProtocolMessageType('QuerySmartContractStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSMARTCONTRACTSTATEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QuerySmartContractStateRequest)
  })
_sym_db.RegisterMessage(QuerySmartContractStateRequest)

QuerySmartContractStateResponse = _reflection.GeneratedProtocolMessageType('QuerySmartContractStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSMARTCONTRACTSTATERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QuerySmartContractStateResponse)
  })
_sym_db.RegisterMessage(QuerySmartContractStateResponse)

QueryCodeRequest = _reflection.GeneratedProtocolMessageType('QueryCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodeRequest)
  })
_sym_db.RegisterMessage(QueryCodeRequest)

CodeInfoResponse = _reflection.GeneratedProtocolMessageType('CodeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CODEINFORESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.CodeInfoResponse)
  })
_sym_db.RegisterMessage(CodeInfoResponse)

QueryCodeResponse = _reflection.GeneratedProtocolMessageType('QueryCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodeResponse)
  })
_sym_db.RegisterMessage(QueryCodeResponse)

QueryCodesRequest = _reflection.GeneratedProtocolMessageType('QueryCodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODESREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodesRequest)
  })
_sym_db.RegisterMessage(QueryCodesRequest)

QueryCodesResponse = _reflection.GeneratedProtocolMessageType('QueryCodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODESRESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodesResponse)
  })
_sym_db.RegisterMessage(QueryCodesResponse)

QueryPinnedCodesRequest = _reflection.GeneratedProtocolMessageType('QueryPinnedCodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPINNEDCODESREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryPinnedCodesRequest)
  })
_sym_db.RegisterMessage(QueryPinnedCodesRequest)

QueryPinnedCodesResponse = _reflection.GeneratedProtocolMessageType('QueryPinnedCodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPINNEDCODESRESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryPinnedCodesResponse)
  })
_sym_db.RegisterMessage(QueryPinnedCodesResponse)


DESCRIPTOR._options = None
_QUERYCONTRACTINFORESPONSE.fields_by_name['contract_info']._options = None
_QUERYCONTRACTINFORESPONSE._options = None
_QUERYCONTRACTHISTORYRESPONSE.fields_by_name['entries']._options = None
_QUERYALLCONTRACTSTATERESPONSE.fields_by_name['models']._options = None
_QUERYSMARTCONTRACTSTATEREQUEST.fields_by_name['query_data']._options = None
_QUERYSMARTCONTRACTSTATERESPONSE.fields_by_name['data']._options = None
_CODEINFORESPONSE.fields_by_name['code_id']._options = None
_CODEINFORESPONSE.fields_by_name['data_hash']._options = None
_CODEINFORESPONSE.fields_by_name['instantiate_permission']._options = None
_CODEINFORESPONSE._options = None
_QUERYCODERESPONSE.fields_by_name['code_info']._options = None
_QUERYCODERESPONSE.fields_by_name['data']._options = None
_QUERYCODERESPONSE._options = None
_QUERYCODESRESPONSE.fields_by_name['code_infos']._options = None
_QUERYPINNEDCODESRESPONSE.fields_by_name['code_ids']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='cosmwasm.wasm.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2196,
  serialized_end=3613,
  methods=[
  _descriptor.MethodDescriptor(
    name='ContractInfo',
    full_name='cosmwasm.wasm.v1.Query.ContractInfo',
    index=0,
    containing_service=None,
    input_type=_QUERYCONTRACTINFOREQUEST,
    output_type=_QUERYCONTRACTINFORESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/cosmwasm/wasm/v1/contract/{address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ContractHistory',
    full_name='cosmwasm.wasm.v1.Query.ContractHistory',
    index=1,
    containing_service=None,
    input_type=_QUERYCONTRACTHISTORYREQUEST,
    output_type=_QUERYCONTRACTHISTORYRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/cosmwasm/wasm/v1/contract/{address}/history',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ContractsByCode',
    full_name='cosmwasm.wasm.v1.Query.ContractsByCode',
    index=2,
    containing_service=None,
    input_type=_QUERYCONTRACTSBYCODEREQUEST,
    output_type=_QUERYCONTRACTSBYCODERESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/cosmwasm/wasm/v1/code/{code_id}/contracts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AllContractState',
    full_name='cosmwasm.wasm.v1.Query.AllContractState',
    index=3,
    containing_service=None,
    input_type=_QUERYALLCONTRACTSTATEREQUEST,
    output_type=_QUERYALLCONTRACTSTATERESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/cosmwasm/wasm/v1/contract/{address}/state',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RawContractState',
    full_name='cosmwasm.wasm.v1.Query.RawContractState',
    index=4,
    containing_service=None,
    input_type=_QUERYRAWCONTRACTSTATEREQUEST,
    output_type=_QUERYRAWCONTRACTSTATERESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SmartContractState',
    full_name='cosmwasm.wasm.v1.Query.SmartContractState',
    index=5,
    containing_service=None,
    input_type=_QUERYSMARTCONTRACTSTATEREQUEST,
    output_type=_QUERYSMARTCONTRACTSTATERESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Code',
    full_name='cosmwasm.wasm.v1.Query.Code',
    index=6,
    containing_service=None,
    input_type=_QUERYCODEREQUEST,
    output_type=_QUERYCODERESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /cosmwasm/wasm/v1/code/{code_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Codes',
    full_name='cosmwasm.wasm.v1.Query.Codes',
    index=7,
    containing_service=None,
    input_type=_QUERYCODESREQUEST,
    output_type=_QUERYCODESRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/cosmwasm/wasm/v1/code',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PinnedCodes',
    full_name='cosmwasm.wasm.v1.Query.PinnedCodes',
    index=8,
    containing_service=None,
    input_type=_QUERYPINNEDCODESREQUEST,
    output_type=_QUERYPINNEDCODESRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/cosmwasm/wasm/v1/codes/pinned',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)
