# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/types/v1beta1/account.proto',
  package='injective.types.v1beta1',
  syntax='proto3',
  serialized_options=b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/types/v1beta1/account.proto\x12\x17injective.types.v1beta1\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\xce\x01\n\nEthAccount\x12S\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:\"base_account\"\x12\'\n\tcode_hash\x18\x02 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"code_hash\":B\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xd2\xb4-2github.com/cosmos/cosmos-sdk/x/auth/types.AccountIB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3'
  ,
  dependencies=[cosmos_dot_auth_dot_v1beta1_dot_auth__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_ETHACCOUNT = _descriptor.Descriptor(
  name='EthAccount',
  full_name='injective.types.v1beta1.EthAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_account', full_name='injective.types.v1beta1.EthAccount.base_account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\320\336\037\001\362\336\037\023yaml:\"base_account\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_hash', full_name='injective.types.v1beta1.EthAccount.code_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"code_hash\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000\230\240\037\000\350\240\037\000\322\264-2github.com/cosmos/cosmos-sdk/x/auth/types.AccountI',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=354,
)

_ETHACCOUNT.fields_by_name['base_account'].message_type = cosmos_dot_auth_dot_v1beta1_dot_auth__pb2._BASEACCOUNT
DESCRIPTOR.message_types_by_name['EthAccount'] = _ETHACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EthAccount = _reflection.GeneratedProtocolMessageType('EthAccount', (_message.Message,), {
  'DESCRIPTOR' : _ETHACCOUNT,
  '__module__' : 'injective.types.v1beta1.account_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.EthAccount)
  })
_sym_db.RegisterMessage(EthAccount)


DESCRIPTOR._options = None
_ETHACCOUNT.fields_by_name['base_account']._options = None
_ETHACCOUNT.fields_by_name['code_hash']._options = None
_ETHACCOUNT._options = None
# @@protoc_insertion_point(module_scope)
