# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/privval/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/privval/types.proto',
  package='tendermint.privval',
  syntax='proto3',
  serialized_options=b'Z9github.com/tendermint/tendermint/proto/tendermint/privval',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etendermint/privval/types.proto\x12\x12tendermint.privval\x1a\x1ctendermint/crypto/keys.proto\x1a\x1ctendermint/types/types.proto\x1a\x14gogoproto/gogo.proto\"6\n\x11RemoteSignerError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"!\n\rPubKeyRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\"{\n\x0ePubKeyResponse\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"I\n\x0fSignVoteRequest\x12$\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.Vote\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"v\n\x12SignedVoteResponse\x12*\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.VoteB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"U\n\x13SignProposalRequest\x12,\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.Proposal\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x82\x01\n\x16SignedProposalResponse\x12\x32\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xa6\x04\n\x07Message\x12<\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32!.tendermint.privval.PubKeyRequestH\x00\x12>\n\x10pub_key_response\x18\x02 \x01(\x0b\x32\".tendermint.privval.PubKeyResponseH\x00\x12@\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32#.tendermint.privval.SignVoteRequestH\x00\x12\x46\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32&.tendermint.privval.SignedVoteResponseH\x00\x12H\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32\'.tendermint.privval.SignProposalRequestH\x00\x12N\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32*.tendermint.privval.SignedProposalResponseH\x00\x12\x37\n\x0cping_request\x18\x07 \x01(\x0b\x32\x1f.tendermint.privval.PingRequestH\x00\x12\x39\n\rping_response\x18\x08 \x01(\x0b\x32 .tendermint.privval.PingResponseH\x00\x42\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42;Z9github.com/tendermint/tendermint/proto/tendermint/privvalb\x06proto3'
  ,
  dependencies=[tendermint_dot_crypto_dot_keys__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])

_ERRORS = _descriptor.EnumDescriptor(
  name='Errors',
  full_name='tendermint.privval.Errors',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERRORS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_UNEXPECTED_RESPONSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_NO_CONNECTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_CONNECTION_TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_READ_TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_WRITE_TIMEOUT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1352,
  serialized_end=1520,
)
_sym_db.RegisterEnumDescriptor(_ERRORS)

Errors = enum_type_wrapper.EnumTypeWrapper(_ERRORS)
ERRORS_UNKNOWN = 0
ERRORS_UNEXPECTED_RESPONSE = 1
ERRORS_NO_CONNECTION = 2
ERRORS_CONNECTION_TIMEOUT = 3
ERRORS_READ_TIMEOUT = 4
ERRORS_WRITE_TIMEOUT = 5



_REMOTESIGNERERROR = _descriptor.Descriptor(
  name='RemoteSignerError',
  full_name='tendermint.privval.RemoteSignerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='tendermint.privval.RemoteSignerError.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='tendermint.privval.RemoteSignerError.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=190,
)


_PUBKEYREQUEST = _descriptor.Descriptor(
  name='PubKeyRequest',
  full_name='tendermint.privval.PubKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.privval.PubKeyRequest.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=225,
)


_PUBKEYRESPONSE = _descriptor.Descriptor(
  name='PubKeyResponse',
  full_name='tendermint.privval.PubKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='tendermint.privval.PubKeyResponse.pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tendermint.privval.PubKeyResponse.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=350,
)


_SIGNVOTEREQUEST = _descriptor.Descriptor(
  name='SignVoteRequest',
  full_name='tendermint.privval.SignVoteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vote', full_name='tendermint.privval.SignVoteRequest.vote', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.privval.SignVoteRequest.chain_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=425,
)


_SIGNEDVOTERESPONSE = _descriptor.Descriptor(
  name='SignedVoteResponse',
  full_name='tendermint.privval.SignedVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vote', full_name='tendermint.privval.SignedVoteResponse.vote', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tendermint.privval.SignedVoteResponse.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=545,
)


_SIGNPROPOSALREQUEST = _descriptor.Descriptor(
  name='SignProposalRequest',
  full_name='tendermint.privval.SignProposalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='tendermint.privval.SignProposalRequest.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.privval.SignProposalRequest.chain_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=632,
)


_SIGNEDPROPOSALRESPONSE = _descriptor.Descriptor(
  name='SignedProposalResponse',
  full_name='tendermint.privval.SignedProposalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='tendermint.privval.SignedProposalResponse.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tendermint.privval.SignedProposalResponse.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=765,
)


_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='tendermint.privval.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=780,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='tendermint.privval.PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=796,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.privval.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key_request', full_name='tendermint.privval.Message.pub_key_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pub_key_response', full_name='tendermint.privval.Message.pub_key_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_vote_request', full_name='tendermint.privval.Message.sign_vote_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_vote_response', full_name='tendermint.privval.Message.signed_vote_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_proposal_request', full_name='tendermint.privval.Message.sign_proposal_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_proposal_response', full_name='tendermint.privval.Message.signed_proposal_response', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping_request', full_name='tendermint.privval.Message.ping_request', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping_response', full_name='tendermint.privval.Message.ping_response', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.privval.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=799,
  serialized_end=1349,
)

_PUBKEYRESPONSE.fields_by_name['pub_key'].message_type = tendermint_dot_crypto_dot_keys__pb2._PUBLICKEY
_PUBKEYRESPONSE.fields_by_name['error'].message_type = _REMOTESIGNERERROR
_SIGNVOTEREQUEST.fields_by_name['vote'].message_type = tendermint_dot_types_dot_types__pb2._VOTE
_SIGNEDVOTERESPONSE.fields_by_name['vote'].message_type = tendermint_dot_types_dot_types__pb2._VOTE
_SIGNEDVOTERESPONSE.fields_by_name['error'].message_type = _REMOTESIGNERERROR
_SIGNPROPOSALREQUEST.fields_by_name['proposal'].message_type = tendermint_dot_types_dot_types__pb2._PROPOSAL
_SIGNEDPROPOSALRESPONSE.fields_by_name['proposal'].message_type = tendermint_dot_types_dot_types__pb2._PROPOSAL
_SIGNEDPROPOSALRESPONSE.fields_by_name['error'].message_type = _REMOTESIGNERERROR
_MESSAGE.fields_by_name['pub_key_request'].message_type = _PUBKEYREQUEST
_MESSAGE.fields_by_name['pub_key_response'].message_type = _PUBKEYRESPONSE
_MESSAGE.fields_by_name['sign_vote_request'].message_type = _SIGNVOTEREQUEST
_MESSAGE.fields_by_name['signed_vote_response'].message_type = _SIGNEDVOTERESPONSE
_MESSAGE.fields_by_name['sign_proposal_request'].message_type = _SIGNPROPOSALREQUEST
_MESSAGE.fields_by_name['signed_proposal_response'].message_type = _SIGNEDPROPOSALRESPONSE
_MESSAGE.fields_by_name['ping_request'].message_type = _PINGREQUEST
_MESSAGE.fields_by_name['ping_response'].message_type = _PINGRESPONSE
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['pub_key_request'])
_MESSAGE.fields_by_name['pub_key_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['pub_key_response'])
_MESSAGE.fields_by_name['pub_key_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['sign_vote_request'])
_MESSAGE.fields_by_name['sign_vote_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['signed_vote_response'])
_MESSAGE.fields_by_name['signed_vote_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['sign_proposal_request'])
_MESSAGE.fields_by_name['sign_proposal_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['signed_proposal_response'])
_MESSAGE.fields_by_name['signed_proposal_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['ping_request'])
_MESSAGE.fields_by_name['ping_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['ping_response'])
_MESSAGE.fields_by_name['ping_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['RemoteSignerError'] = _REMOTESIGNERERROR
DESCRIPTOR.message_types_by_name['PubKeyRequest'] = _PUBKEYREQUEST
DESCRIPTOR.message_types_by_name['PubKeyResponse'] = _PUBKEYRESPONSE
DESCRIPTOR.message_types_by_name['SignVoteRequest'] = _SIGNVOTEREQUEST
DESCRIPTOR.message_types_by_name['SignedVoteResponse'] = _SIGNEDVOTERESPONSE
DESCRIPTOR.message_types_by_name['SignProposalRequest'] = _SIGNPROPOSALREQUEST
DESCRIPTOR.message_types_by_name['SignedProposalResponse'] = _SIGNEDPROPOSALRESPONSE
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.enum_types_by_name['Errors'] = _ERRORS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RemoteSignerError = _reflection.GeneratedProtocolMessageType('RemoteSignerError', (_message.Message,), {
  'DESCRIPTOR' : _REMOTESIGNERERROR,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.RemoteSignerError)
  })
_sym_db.RegisterMessage(RemoteSignerError)

PubKeyRequest = _reflection.GeneratedProtocolMessageType('PubKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEYREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PubKeyRequest)
  })
_sym_db.RegisterMessage(PubKeyRequest)

PubKeyResponse = _reflection.GeneratedProtocolMessageType('PubKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEYRESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PubKeyResponse)
  })
_sym_db.RegisterMessage(PubKeyResponse)

SignVoteRequest = _reflection.GeneratedProtocolMessageType('SignVoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNVOTEREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignVoteRequest)
  })
_sym_db.RegisterMessage(SignVoteRequest)

SignedVoteResponse = _reflection.GeneratedProtocolMessageType('SignedVoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNEDVOTERESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignedVoteResponse)
  })
_sym_db.RegisterMessage(SignedVoteResponse)

SignProposalRequest = _reflection.GeneratedProtocolMessageType('SignProposalRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNPROPOSALREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignProposalRequest)
  })
_sym_db.RegisterMessage(SignProposalRequest)

SignedProposalResponse = _reflection.GeneratedProtocolMessageType('SignedProposalResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNEDPROPOSALRESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignedProposalResponse)
  })
_sym_db.RegisterMessage(SignedProposalResponse)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
_PUBKEYRESPONSE.fields_by_name['pub_key']._options = None
_SIGNEDVOTERESPONSE.fields_by_name['vote']._options = None
_SIGNEDPROPOSALRESPONSE.fields_by_name['proposal']._options = None
# @@protoc_insertion_point(module_scope)
