# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.ocr.v1beta1 import genesis_pb2 as injective_dot_ocr_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/ocr/v1beta1/query.proto',
  package='injective.ocr.v1beta1',
  syntax='proto3',
  serialized_options=b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!injective/ocr/v1beta1/query.proto\x12\x15injective.ocr.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a#injective/ocr/v1beta1/genesis.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\")\n\x16QueryFeedConfigRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\x92\x01\n\x17QueryFeedConfigResponse\x12?\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfo\x12\x36\n\x0b\x66\x65\x65\x64_config\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\"-\n\x1aQueryFeedConfigInfoRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\x9d\x01\n\x1bQueryFeedConfigInfoResponse\x12?\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfo\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"*\n\x17QueryLatestRoundRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"f\n\x18QueryLatestRoundResponse\x12\x17\n\x0flatest_round_id\x18\x01 \x01(\x04\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"8\n%QueryLatestTransmissionDetailsRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\xb1\x01\n&QueryLatestTransmissionDetailsResponse\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\x12\x31\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"-\n\x16QueryOwedAmountRequest\x12\x13\n\x0btransmitter\x18\x01 \x01(\t\"J\n\x17QueryOwedAmountResponse\x12/\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"N\n\x18QueryModuleStateResponse\x12\x32\n\x05state\x18\x01 \x01(\x0b\x32#.injective.ocr.v1beta1.GenesisState2\xbb\t\n\x05Query\x12\x86\x01\n\x06Params\x12).injective.ocr.v1beta1.QueryParamsRequest\x1a*.injective.ocr.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/chainlink/ocr/v1beta1/params\x12\xa1\x01\n\nFeedConfig\x12-.injective.ocr.v1beta1.QueryFeedConfigRequest\x1a..injective.ocr.v1beta1.QueryFeedConfigResponse\"4\x82\xd3\xe4\x93\x02.\x12,/chainlink/ocr/v1beta1/feed_config/{feed_id}\x12\xb2\x01\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x31.injective.ocr.v1beta1.QueryFeedConfigInfoRequest\x1a\x32.injective.ocr.v1beta1.QueryFeedConfigInfoResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/chainlink/ocr/v1beta1/feed_config_info/{feed_id}\x12\xa5\x01\n\x0bLatestRound\x12..injective.ocr.v1beta1.QueryLatestRoundRequest\x1a/.injective.ocr.v1beta1.QueryLatestRoundResponse\"5\x82\xd3\xe4\x93\x02/\x12-/chainlink/ocr/v1beta1/latest_round/{feed_id}\x12\xde\x01\n\x19LatestTransmissionDetails\x12<.injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest\x1a=.injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse\"D\x82\xd3\xe4\x93\x02>\x12</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}\x12\xa5\x01\n\nOwedAmount\x12-.injective.ocr.v1beta1.QueryOwedAmountRequest\x1a..injective.ocr.v1beta1.QueryOwedAmountResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/chainlink/ocr/v1beta1/owed_amount/{transmitter}\x12\x9e\x01\n\x0eOcrModuleState\x12..injective.ocr.v1beta1.QueryModuleStateRequest\x1a/.injective.ocr.v1beta1.QueryModuleStateResponse\"+\x82\xd3\xe4\x93\x02%\x12#/chainlink/ocr/v1beta1/module_stateBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_ocr_dot_v1beta1_dot_ocr__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_ocr_dot_v1beta1_dot_genesis__pb2.DESCRIPTOR,])




_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='injective.ocr.v1beta1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=234,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='injective.ocr.v1beta1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.ocr.v1beta1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=310,
)


_QUERYFEEDCONFIGREQUEST = _descriptor.Descriptor(
  name='QueryFeedConfigRequest',
  full_name='injective.ocr.v1beta1.QueryFeedConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryFeedConfigRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=353,
)


_QUERYFEEDCONFIGRESPONSE = _descriptor.Descriptor(
  name='QueryFeedConfigResponse',
  full_name='injective.ocr.v1beta1.QueryFeedConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_config_info', full_name='injective.ocr.v1beta1.QueryFeedConfigResponse.feed_config_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_config', full_name='injective.ocr.v1beta1.QueryFeedConfigResponse.feed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=502,
)


_QUERYFEEDCONFIGINFOREQUEST = _descriptor.Descriptor(
  name='QueryFeedConfigInfoRequest',
  full_name='injective.ocr.v1beta1.QueryFeedConfigInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryFeedConfigInfoRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=549,
)


_QUERYFEEDCONFIGINFORESPONSE = _descriptor.Descriptor(
  name='QueryFeedConfigInfoResponse',
  full_name='injective.ocr.v1beta1.QueryFeedConfigInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_config_info', full_name='injective.ocr.v1beta1.QueryFeedConfigInfoResponse.feed_config_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.QueryFeedConfigInfoResponse.epoch_and_round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=709,
)


_QUERYLATESTROUNDREQUEST = _descriptor.Descriptor(
  name='QueryLatestRoundRequest',
  full_name='injective.ocr.v1beta1.QueryLatestRoundRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryLatestRoundRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=753,
)


_QUERYLATESTROUNDRESPONSE = _descriptor.Descriptor(
  name='QueryLatestRoundResponse',
  full_name='injective.ocr.v1beta1.QueryLatestRoundResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latest_round_id', full_name='injective.ocr.v1beta1.QueryLatestRoundResponse.latest_round_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.ocr.v1beta1.QueryLatestRoundResponse.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=857,
)


_QUERYLATESTTRANSMISSIONDETAILSREQUEST = _descriptor.Descriptor(
  name='QueryLatestTransmissionDetailsRequest',
  full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=915,
)


_QUERYLATESTTRANSMISSIONDETAILSRESPONSE = _descriptor.Descriptor(
  name='QueryLatestTransmissionDetailsResponse',
  full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse.config_digest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse.epoch_and_round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=918,
  serialized_end=1095,
)


_QUERYOWEDAMOUNTREQUEST = _descriptor.Descriptor(
  name='QueryOwedAmountRequest',
  full_name='injective.ocr.v1beta1.QueryOwedAmountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.QueryOwedAmountRequest.transmitter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1142,
)


_QUERYOWEDAMOUNTRESPONSE = _descriptor.Descriptor(
  name='QueryOwedAmountResponse',
  full_name='injective.ocr.v1beta1.QueryOwedAmountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.QueryOwedAmountResponse.amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1218,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.ocr.v1beta1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1220,
  serialized_end=1245,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.ocr.v1beta1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.ocr.v1beta1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1325,
)

_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._PARAMS
_QUERYFEEDCONFIGRESPONSE.fields_by_name['feed_config_info'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIGINFO
_QUERYFEEDCONFIGRESPONSE.fields_by_name['feed_config'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIG
_QUERYFEEDCONFIGINFORESPONSE.fields_by_name['feed_config_info'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIGINFO
_QUERYFEEDCONFIGINFORESPONSE.fields_by_name['epoch_and_round'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._EPOCHANDROUND
_QUERYLATESTROUNDRESPONSE.fields_by_name['data'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._TRANSMISSION
_QUERYLATESTTRANSMISSIONDETAILSRESPONSE.fields_by_name['epoch_and_round'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._EPOCHANDROUND
_QUERYLATESTTRANSMISSIONDETAILSRESPONSE.fields_by_name['data'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._TRANSMISSION
_QUERYOWEDAMOUNTRESPONSE.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_ocr_dot_v1beta1_dot_genesis__pb2._GENESISSTATE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeedConfigRequest'] = _QUERYFEEDCONFIGREQUEST
DESCRIPTOR.message_types_by_name['QueryFeedConfigResponse'] = _QUERYFEEDCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeedConfigInfoRequest'] = _QUERYFEEDCONFIGINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryFeedConfigInfoResponse'] = _QUERYFEEDCONFIGINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryLatestRoundRequest'] = _QUERYLATESTROUNDREQUEST
DESCRIPTOR.message_types_by_name['QueryLatestRoundResponse'] = _QUERYLATESTROUNDRESPONSE
DESCRIPTOR.message_types_by_name['QueryLatestTransmissionDetailsRequest'] = _QUERYLATESTTRANSMISSIONDETAILSREQUEST
DESCRIPTOR.message_types_by_name['QueryLatestTransmissionDetailsResponse'] = _QUERYLATESTTRANSMISSIONDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['QueryOwedAmountRequest'] = _QUERYOWEDAMOUNTREQUEST
DESCRIPTOR.message_types_by_name['QueryOwedAmountResponse'] = _QUERYOWEDAMOUNTRESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryFeedConfigRequest = _reflection.GeneratedProtocolMessageType('QueryFeedConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigRequest)
  })
_sym_db.RegisterMessage(QueryFeedConfigRequest)

QueryFeedConfigResponse = _reflection.GeneratedProtocolMessageType('QueryFeedConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigResponse)
  })
_sym_db.RegisterMessage(QueryFeedConfigResponse)

QueryFeedConfigInfoRequest = _reflection.GeneratedProtocolMessageType('QueryFeedConfigInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGINFOREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigInfoRequest)
  })
_sym_db.RegisterMessage(QueryFeedConfigInfoRequest)

QueryFeedConfigInfoResponse = _reflection.GeneratedProtocolMessageType('QueryFeedConfigInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGINFORESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigInfoResponse)
  })
_sym_db.RegisterMessage(QueryFeedConfigInfoResponse)

QueryLatestRoundRequest = _reflection.GeneratedProtocolMessageType('QueryLatestRoundRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTROUNDREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestRoundRequest)
  })
_sym_db.RegisterMessage(QueryLatestRoundRequest)

QueryLatestRoundResponse = _reflection.GeneratedProtocolMessageType('QueryLatestRoundResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTROUNDRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestRoundResponse)
  })
_sym_db.RegisterMessage(QueryLatestRoundResponse)

QueryLatestTransmissionDetailsRequest = _reflection.GeneratedProtocolMessageType('QueryLatestTransmissionDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTTRANSMISSIONDETAILSREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest)
  })
_sym_db.RegisterMessage(QueryLatestTransmissionDetailsRequest)

QueryLatestTransmissionDetailsResponse = _reflection.GeneratedProtocolMessageType('QueryLatestTransmissionDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTTRANSMISSIONDETAILSRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse)
  })
_sym_db.RegisterMessage(QueryLatestTransmissionDetailsResponse)

QueryOwedAmountRequest = _reflection.GeneratedProtocolMessageType('QueryOwedAmountRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOWEDAMOUNTREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryOwedAmountRequest)
  })
_sym_db.RegisterMessage(QueryOwedAmountRequest)

QueryOwedAmountResponse = _reflection.GeneratedProtocolMessageType('QueryOwedAmountResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOWEDAMOUNTRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryOwedAmountResponse)
  })
_sym_db.RegisterMessage(QueryOwedAmountResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)


DESCRIPTOR._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYOWEDAMOUNTRESPONSE.fields_by_name['amount']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.ocr.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1328,
  serialized_end=2539,
  methods=[
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='injective.ocr.v1beta1.Query.Params',
    index=0,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/chainlink/ocr/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeedConfig',
    full_name='injective.ocr.v1beta1.Query.FeedConfig',
    index=1,
    containing_service=None,
    input_type=_QUERYFEEDCONFIGREQUEST,
    output_type=_QUERYFEEDCONFIGRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/chainlink/ocr/v1beta1/feed_config/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeedConfigInfo',
    full_name='injective.ocr.v1beta1.Query.FeedConfigInfo',
    index=2,
    containing_service=None,
    input_type=_QUERYFEEDCONFIGINFOREQUEST,
    output_type=_QUERYFEEDCONFIGINFORESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/chainlink/ocr/v1beta1/feed_config_info/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestRound',
    full_name='injective.ocr.v1beta1.Query.LatestRound',
    index=3,
    containing_service=None,
    input_type=_QUERYLATESTROUNDREQUEST,
    output_type=_QUERYLATESTROUNDRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/chainlink/ocr/v1beta1/latest_round/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestTransmissionDetails',
    full_name='injective.ocr.v1beta1.Query.LatestTransmissionDetails',
    index=4,
    containing_service=None,
    input_type=_QUERYLATESTTRANSMISSIONDETAILSREQUEST,
    output_type=_QUERYLATESTTRANSMISSIONDETAILSRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OwedAmount',
    full_name='injective.ocr.v1beta1.Query.OwedAmount',
    index=5,
    containing_service=None,
    input_type=_QUERYOWEDAMOUNTREQUEST,
    output_type=_QUERYOWEDAMOUNTRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/chainlink/ocr/v1beta1/owed_amount/{transmitter}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OcrModuleState',
    full_name='injective.ocr.v1beta1.Query.OcrModuleState',
    index=6,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/chainlink/ocr/v1beta1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)
