# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/ocr/v1beta1/genesis.proto',
  package='injective.ocr.v1beta1',
  syntax='proto3',
  serialized_options=b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#injective/ocr/v1beta1/genesis.proto\x12\x15injective.ocr.v1beta1\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xed\x04\n\x0cGenesisState\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x37\n\x0c\x66\x65\x65\x64_configs\x18\x02 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\x12I\n\x17latest_epoch_and_rounds\x18\x03 \x03(\x0b\x32(.injective.ocr.v1beta1.FeedEpochAndRound\x12\x43\n\x12\x66\x65\x65\x64_transmissions\x18\x04 \x03(\x0b\x32\'.injective.ocr.v1beta1.FeedTransmission\x12X\n\x1blatest_aggregator_round_ids\x18\x05 \x03(\x0b\x32\x33.injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs\x12\x37\n\x0creward_pools\x18\x06 \x03(\x0b\x32!.injective.ocr.v1beta1.RewardPool\x12\x42\n\x17\x66\x65\x65\x64_observation_counts\x18\x07 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCounts\x12\x43\n\x18\x66\x65\x65\x64_transmission_counts\x18\x08 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCounts\x12\x43\n\x12pending_payeeships\x18\t \x03(\x0b\x32\'.injective.ocr.v1beta1.PendingPayeeship\"^\n\x10\x46\x65\x65\x64Transmission\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x39\n\x0ctransmission\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"c\n\x11\x46\x65\x65\x64\x45pochAndRound\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"L\n\x1c\x46\x65\x65\x64LatestAggregatorRoundIDs\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61ggregator_round_id\x18\x02 \x01(\x04\"N\n\nRewardPool\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12/\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"K\n\nFeedCounts\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12,\n\x06\x63ounts\x18\x02 \x03(\x0b\x32\x1c.injective.ocr.v1beta1.Count\"\'\n\x05\x43ount\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"P\n\x10PendingPayeeship\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x16\n\x0eproposed_payee\x18\x03 \x01(\tBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3'
  ,
  dependencies=[injective_dot_ocr_dot_v1beta1_dot_ocr__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='injective.ocr.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.ocr.v1beta1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_configs', full_name='injective.ocr.v1beta1.GenesisState.feed_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_epoch_and_rounds', full_name='injective.ocr.v1beta1.GenesisState.latest_epoch_and_rounds', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_transmissions', full_name='injective.ocr.v1beta1.GenesisState.feed_transmissions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_aggregator_round_ids', full_name='injective.ocr.v1beta1.GenesisState.latest_aggregator_round_ids', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_pools', full_name='injective.ocr.v1beta1.GenesisState.reward_pools', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_observation_counts', full_name='injective.ocr.v1beta1.GenesisState.feed_observation_counts', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_transmission_counts', full_name='injective.ocr.v1beta1.GenesisState.feed_transmission_counts', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_payeeships', full_name='injective.ocr.v1beta1.GenesisState.pending_payeeships', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=771,
)


_FEEDTRANSMISSION = _descriptor.Descriptor(
  name='FeedTransmission',
  full_name='injective.ocr.v1beta1.FeedTransmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedTransmission.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmission', full_name='injective.ocr.v1beta1.FeedTransmission.transmission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=867,
)


_FEEDEPOCHANDROUND = _descriptor.Descriptor(
  name='FeedEpochAndRound',
  full_name='injective.ocr.v1beta1.FeedEpochAndRound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedEpochAndRound.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.FeedEpochAndRound.epoch_and_round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=968,
)


_FEEDLATESTAGGREGATORROUNDIDS = _descriptor.Descriptor(
  name='FeedLatestAggregatorRoundIDs',
  full_name='injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregator_round_id', full_name='injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs.aggregator_round_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1046,
)


_REWARDPOOL = _descriptor.Descriptor(
  name='RewardPool',
  full_name='injective.ocr.v1beta1.RewardPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.RewardPool.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.RewardPool.amount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1126,
)


_FEEDCOUNTS = _descriptor.Descriptor(
  name='FeedCounts',
  full_name='injective.ocr.v1beta1.FeedCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedCounts.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counts', full_name='injective.ocr.v1beta1.FeedCounts.counts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1203,
)


_COUNT = _descriptor.Descriptor(
  name='Count',
  full_name='injective.ocr.v1beta1.Count',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.ocr.v1beta1.Count.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='injective.ocr.v1beta1.Count.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1244,
)


_PENDINGPAYEESHIP = _descriptor.Descriptor(
  name='PendingPayeeship',
  full_name='injective.ocr.v1beta1.PendingPayeeship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.PendingPayeeship.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.PendingPayeeship.transmitter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposed_payee', full_name='injective.ocr.v1beta1.PendingPayeeship.proposed_payee', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1246,
  serialized_end=1326,
)

_GENESISSTATE.fields_by_name['params'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._PARAMS
_GENESISSTATE.fields_by_name['feed_configs'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIG
_GENESISSTATE.fields_by_name['latest_epoch_and_rounds'].message_type = _FEEDEPOCHANDROUND
_GENESISSTATE.fields_by_name['feed_transmissions'].message_type = _FEEDTRANSMISSION
_GENESISSTATE.fields_by_name['latest_aggregator_round_ids'].message_type = _FEEDLATESTAGGREGATORROUNDIDS
_GENESISSTATE.fields_by_name['reward_pools'].message_type = _REWARDPOOL
_GENESISSTATE.fields_by_name['feed_observation_counts'].message_type = _FEEDCOUNTS
_GENESISSTATE.fields_by_name['feed_transmission_counts'].message_type = _FEEDCOUNTS
_GENESISSTATE.fields_by_name['pending_payeeships'].message_type = _PENDINGPAYEESHIP
_FEEDTRANSMISSION.fields_by_name['transmission'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._TRANSMISSION
_FEEDEPOCHANDROUND.fields_by_name['epoch_and_round'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._EPOCHANDROUND
_REWARDPOOL.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_FEEDCOUNTS.fields_by_name['counts'].message_type = _COUNT
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
DESCRIPTOR.message_types_by_name['FeedTransmission'] = _FEEDTRANSMISSION
DESCRIPTOR.message_types_by_name['FeedEpochAndRound'] = _FEEDEPOCHANDROUND
DESCRIPTOR.message_types_by_name['FeedLatestAggregatorRoundIDs'] = _FEEDLATESTAGGREGATORROUNDIDS
DESCRIPTOR.message_types_by_name['RewardPool'] = _REWARDPOOL
DESCRIPTOR.message_types_by_name['FeedCounts'] = _FEEDCOUNTS
DESCRIPTOR.message_types_by_name['Count'] = _COUNT
DESCRIPTOR.message_types_by_name['PendingPayeeship'] = _PENDINGPAYEESHIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

FeedTransmission = _reflection.GeneratedProtocolMessageType('FeedTransmission', (_message.Message,), {
  'DESCRIPTOR' : _FEEDTRANSMISSION,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedTransmission)
  })
_sym_db.RegisterMessage(FeedTransmission)

FeedEpochAndRound = _reflection.GeneratedProtocolMessageType('FeedEpochAndRound', (_message.Message,), {
  'DESCRIPTOR' : _FEEDEPOCHANDROUND,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedEpochAndRound)
  })
_sym_db.RegisterMessage(FeedEpochAndRound)

FeedLatestAggregatorRoundIDs = _reflection.GeneratedProtocolMessageType('FeedLatestAggregatorRoundIDs', (_message.Message,), {
  'DESCRIPTOR' : _FEEDLATESTAGGREGATORROUNDIDS,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs)
  })
_sym_db.RegisterMessage(FeedLatestAggregatorRoundIDs)

RewardPool = _reflection.GeneratedProtocolMessageType('RewardPool', (_message.Message,), {
  'DESCRIPTOR' : _REWARDPOOL,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.RewardPool)
  })
_sym_db.RegisterMessage(RewardPool)

FeedCounts = _reflection.GeneratedProtocolMessageType('FeedCounts', (_message.Message,), {
  'DESCRIPTOR' : _FEEDCOUNTS,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedCounts)
  })
_sym_db.RegisterMessage(FeedCounts)

Count = _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
  'DESCRIPTOR' : _COUNT,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.Count)
  })
_sym_db.RegisterMessage(Count)

PendingPayeeship = _reflection.GeneratedProtocolMessageType('PendingPayeeship', (_message.Message,), {
  'DESCRIPTOR' : _PENDINGPAYEESHIP,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.PendingPayeeship)
  })
_sym_db.RegisterMessage(PendingPayeeship)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_REWARDPOOL.fields_by_name['amount']._options = None
# @@protoc_insertion_point(module_scope)
