# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_auction_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_auction_rpc.proto',
  package='injective_auction_rpc',
  syntax='proto3',
  serialized_options=b'Z\030/injective_auction_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$exchange/injective_auction_rpc.proto\x12\x15injective_auction_rpc\"\x1f\n\x0e\x41uctionRequest\x12\r\n\x05round\x18\x01 \x01(\x12\"l\n\x0f\x41uctionResponse\x12/\n\x07\x61uction\x18\x01 \x01(\x0b\x32\x1e.injective_auction_rpc.Auction\x12(\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x1a.injective_auction_rpc.Bid\"\x9c\x01\n\x07\x41uction\x12\x0e\n\x06winner\x18\x01 \x01(\t\x12+\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32\x1b.injective_auction_rpc.Coin\x12\x1a\n\x12winning_bid_amount\x18\x03 \x01(\t\x12\r\n\x05round\x18\x04 \x01(\x04\x12\x15\n\rend_timestamp\x18\x05 \x01(\x12\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"8\n\x03\x42id\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\x11\n\x0f\x41uctionsRequest\"D\n\x10\x41uctionsResponse\x12\x30\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\x1e.injective_auction_rpc.Auction\"\x13\n\x11StreamBidsRequest\"Z\n\x12StreamBidsResponse\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12\x12\n\nbid_amount\x18\x02 \x01(\t\x12\r\n\x05round\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\x12\x32\xb9\x02\n\x13InjectiveAuctionRPC\x12`\n\x0f\x41uctionEndpoint\x12%.injective_auction_rpc.AuctionRequest\x1a&.injective_auction_rpc.AuctionResponse\x12[\n\x08\x41uctions\x12&.injective_auction_rpc.AuctionsRequest\x1a\'.injective_auction_rpc.AuctionsResponse\x12\x63\n\nStreamBids\x12(.injective_auction_rpc.StreamBidsRequest\x1a).injective_auction_rpc.StreamBidsResponse0\x01\x42\x1aZ\x18/injective_auction_rpcpbb\x06proto3'
)




_AUCTIONREQUEST = _descriptor.Descriptor(
  name='AuctionRequest',
  full_name='injective_auction_rpc.AuctionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='injective_auction_rpc.AuctionRequest.round', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=94,
)


_AUCTIONRESPONSE = _descriptor.Descriptor(
  name='AuctionResponse',
  full_name='injective_auction_rpc.AuctionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auction', full_name='injective_auction_rpc.AuctionResponse.auction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bids', full_name='injective_auction_rpc.AuctionResponse.bids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=204,
)


_AUCTION = _descriptor.Descriptor(
  name='Auction',
  full_name='injective_auction_rpc.Auction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='winner', full_name='injective_auction_rpc.Auction.winner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basket', full_name='injective_auction_rpc.Auction.basket', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='winning_bid_amount', full_name='injective_auction_rpc.Auction.winning_bid_amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective_auction_rpc.Auction.round', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='injective_auction_rpc.Auction.end_timestamp', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_auction_rpc.Auction.updated_at', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=363,
)


_COIN = _descriptor.Descriptor(
  name='Coin',
  full_name='injective_auction_rpc.Coin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_auction_rpc.Coin.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_auction_rpc.Coin.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=402,
)


_BID = _descriptor.Descriptor(
  name='Bid',
  full_name='injective_auction_rpc.Bid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidder', full_name='injective_auction_rpc.Bid.bidder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_auction_rpc.Bid.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_auction_rpc.Bid.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=460,
)


_AUCTIONSREQUEST = _descriptor.Descriptor(
  name='AuctionsRequest',
  full_name='injective_auction_rpc.AuctionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=479,
)


_AUCTIONSRESPONSE = _descriptor.Descriptor(
  name='AuctionsResponse',
  full_name='injective_auction_rpc.AuctionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auctions', full_name='injective_auction_rpc.AuctionsResponse.auctions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=549,
)


_STREAMBIDSREQUEST = _descriptor.Descriptor(
  name='StreamBidsRequest',
  full_name='injective_auction_rpc.StreamBidsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=570,
)


_STREAMBIDSRESPONSE = _descriptor.Descriptor(
  name='StreamBidsResponse',
  full_name='injective_auction_rpc.StreamBidsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidder', full_name='injective_auction_rpc.StreamBidsResponse.bidder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bid_amount', full_name='injective_auction_rpc.StreamBidsResponse.bid_amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective_auction_rpc.StreamBidsResponse.round', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_auction_rpc.StreamBidsResponse.timestamp', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=662,
)

_AUCTIONRESPONSE.fields_by_name['auction'].message_type = _AUCTION
_AUCTIONRESPONSE.fields_by_name['bids'].message_type = _BID
_AUCTION.fields_by_name['basket'].message_type = _COIN
_AUCTIONSRESPONSE.fields_by_name['auctions'].message_type = _AUCTION
DESCRIPTOR.message_types_by_name['AuctionRequest'] = _AUCTIONREQUEST
DESCRIPTOR.message_types_by_name['AuctionResponse'] = _AUCTIONRESPONSE
DESCRIPTOR.message_types_by_name['Auction'] = _AUCTION
DESCRIPTOR.message_types_by_name['Coin'] = _COIN
DESCRIPTOR.message_types_by_name['Bid'] = _BID
DESCRIPTOR.message_types_by_name['AuctionsRequest'] = _AUCTIONSREQUEST
DESCRIPTOR.message_types_by_name['AuctionsResponse'] = _AUCTIONSRESPONSE
DESCRIPTOR.message_types_by_name['StreamBidsRequest'] = _STREAMBIDSREQUEST
DESCRIPTOR.message_types_by_name['StreamBidsResponse'] = _STREAMBIDSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuctionRequest = _reflection.GeneratedProtocolMessageType('AuctionRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONREQUEST,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionRequest)
  })
_sym_db.RegisterMessage(AuctionRequest)

AuctionResponse = _reflection.GeneratedProtocolMessageType('AuctionResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONRESPONSE,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionResponse)
  })
_sym_db.RegisterMessage(AuctionResponse)

Auction = _reflection.GeneratedProtocolMessageType('Auction', (_message.Message,), {
  'DESCRIPTOR' : _AUCTION,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.Auction)
  })
_sym_db.RegisterMessage(Auction)

Coin = _reflection.GeneratedProtocolMessageType('Coin', (_message.Message,), {
  'DESCRIPTOR' : _COIN,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.Coin)
  })
_sym_db.RegisterMessage(Coin)

Bid = _reflection.GeneratedProtocolMessageType('Bid', (_message.Message,), {
  'DESCRIPTOR' : _BID,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.Bid)
  })
_sym_db.RegisterMessage(Bid)

AuctionsRequest = _reflection.GeneratedProtocolMessageType('AuctionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONSREQUEST,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionsRequest)
  })
_sym_db.RegisterMessage(AuctionsRequest)

AuctionsResponse = _reflection.GeneratedProtocolMessageType('AuctionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONSRESPONSE,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionsResponse)
  })
_sym_db.RegisterMessage(AuctionsResponse)

StreamBidsRequest = _reflection.GeneratedProtocolMessageType('StreamBidsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBIDSREQUEST,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.StreamBidsRequest)
  })
_sym_db.RegisterMessage(StreamBidsRequest)

StreamBidsResponse = _reflection.GeneratedProtocolMessageType('StreamBidsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBIDSRESPONSE,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.StreamBidsResponse)
  })
_sym_db.RegisterMessage(StreamBidsResponse)


DESCRIPTOR._options = None

_INJECTIVEAUCTIONRPC = _descriptor.ServiceDescriptor(
  name='InjectiveAuctionRPC',
  full_name='injective_auction_rpc.InjectiveAuctionRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=665,
  serialized_end=978,
  methods=[
  _descriptor.MethodDescriptor(
    name='AuctionEndpoint',
    full_name='injective_auction_rpc.InjectiveAuctionRPC.AuctionEndpoint',
    index=0,
    containing_service=None,
    input_type=_AUCTIONREQUEST,
    output_type=_AUCTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Auctions',
    full_name='injective_auction_rpc.InjectiveAuctionRPC.Auctions',
    index=1,
    containing_service=None,
    input_type=_AUCTIONSREQUEST,
    output_type=_AUCTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamBids',
    full_name='injective_auction_rpc.InjectiveAuctionRPC.StreamBids',
    index=2,
    containing_service=None,
    input_type=_STREAMBIDSREQUEST,
    output_type=_STREAMBIDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEAUCTIONRPC)

DESCRIPTOR.services_by_name['InjectiveAuctionRPC'] = _INJECTIVEAUCTIONRPC

# @@protoc_insertion_point(module_scope)
