# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_oracle_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_oracle_rpc.proto',
  package='injective_oracle_rpc',
  syntax='proto3',
  serialized_options=b'Z\027/injective_oracle_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#exchange/injective_oracle_rpc.proto\x12\x14injective_oracle_rpc\"\x13\n\x11OracleListRequest\"C\n\x12OracleListResponse\x12-\n\x07oracles\x18\x01 \x03(\x0b\x32\x1c.injective_oracle_rpc.Oracle\"g\n\x06Oracle\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x13\n\x0b\x62\x61se_symbol\x18\x02 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x03 \x01(\t\x12\x13\n\x0boracle_type\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\"k\n\x0cPriceRequest\x12\x13\n\x0b\x62\x61se_symbol\x18\x01 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x13\n\x0boracle_type\x18\x03 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x04 \x01(\r\"\x1e\n\rPriceResponse\x12\r\n\x05price\x18\x01 \x01(\t\"U\n\x13StreamPricesRequest\x12\x13\n\x0b\x62\x61se_symbol\x18\x01 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x13\n\x0boracle_type\x18\x03 \x01(\t\"8\n\x14StreamPricesResponse\x12\r\n\x05price\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\x32\xb0\x02\n\x12InjectiveOracleRPC\x12_\n\nOracleList\x12\'.injective_oracle_rpc.OracleListRequest\x1a(.injective_oracle_rpc.OracleListResponse\x12P\n\x05Price\x12\".injective_oracle_rpc.PriceRequest\x1a#.injective_oracle_rpc.PriceResponse\x12g\n\x0cStreamPrices\x12).injective_oracle_rpc.StreamPricesRequest\x1a*.injective_oracle_rpc.StreamPricesResponse0\x01\x42\x19Z\x17/injective_oracle_rpcpbb\x06proto3'
)




_ORACLELISTREQUEST = _descriptor.Descriptor(
  name='OracleListRequest',
  full_name='injective_oracle_rpc.OracleListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=80,
)


_ORACLELISTRESPONSE = _descriptor.Descriptor(
  name='OracleListResponse',
  full_name='injective_oracle_rpc.OracleListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracles', full_name='injective_oracle_rpc.OracleListResponse.oracles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=149,
)


_ORACLE = _descriptor.Descriptor(
  name='Oracle',
  full_name='injective_oracle_rpc.Oracle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective_oracle_rpc.Oracle.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_symbol', full_name='injective_oracle_rpc.Oracle.base_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_symbol', full_name='injective_oracle_rpc.Oracle.quote_symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_oracle_rpc.Oracle.oracle_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_oracle_rpc.Oracle.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=254,
)


_PRICEREQUEST = _descriptor.Descriptor(
  name='PriceRequest',
  full_name='injective_oracle_rpc.PriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_symbol', full_name='injective_oracle_rpc.PriceRequest.base_symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_symbol', full_name='injective_oracle_rpc.PriceRequest.quote_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_oracle_rpc.PriceRequest.oracle_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective_oracle_rpc.PriceRequest.oracle_scale_factor', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=363,
)


_PRICERESPONSE = _descriptor.Descriptor(
  name='PriceResponse',
  full_name='injective_oracle_rpc.PriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_oracle_rpc.PriceResponse.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=395,
)


_STREAMPRICESREQUEST = _descriptor.Descriptor(
  name='StreamPricesRequest',
  full_name='injective_oracle_rpc.StreamPricesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_symbol', full_name='injective_oracle_rpc.StreamPricesRequest.base_symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_symbol', full_name='injective_oracle_rpc.StreamPricesRequest.quote_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_oracle_rpc.StreamPricesRequest.oracle_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=482,
)


_STREAMPRICESRESPONSE = _descriptor.Descriptor(
  name='StreamPricesResponse',
  full_name='injective_oracle_rpc.StreamPricesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_oracle_rpc.StreamPricesResponse.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_oracle_rpc.StreamPricesResponse.timestamp', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=540,
)

_ORACLELISTRESPONSE.fields_by_name['oracles'].message_type = _ORACLE
DESCRIPTOR.message_types_by_name['OracleListRequest'] = _ORACLELISTREQUEST
DESCRIPTOR.message_types_by_name['OracleListResponse'] = _ORACLELISTRESPONSE
DESCRIPTOR.message_types_by_name['Oracle'] = _ORACLE
DESCRIPTOR.message_types_by_name['PriceRequest'] = _PRICEREQUEST
DESCRIPTOR.message_types_by_name['PriceResponse'] = _PRICERESPONSE
DESCRIPTOR.message_types_by_name['StreamPricesRequest'] = _STREAMPRICESREQUEST
DESCRIPTOR.message_types_by_name['StreamPricesResponse'] = _STREAMPRICESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OracleListRequest = _reflection.GeneratedProtocolMessageType('OracleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORACLELISTREQUEST,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.OracleListRequest)
  })
_sym_db.RegisterMessage(OracleListRequest)

OracleListResponse = _reflection.GeneratedProtocolMessageType('OracleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORACLELISTRESPONSE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.OracleListResponse)
  })
_sym_db.RegisterMessage(OracleListResponse)

Oracle = _reflection.GeneratedProtocolMessageType('Oracle', (_message.Message,), {
  'DESCRIPTOR' : _ORACLE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.Oracle)
  })
_sym_db.RegisterMessage(Oracle)

PriceRequest = _reflection.GeneratedProtocolMessageType('PriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRICEREQUEST,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.PriceRequest)
  })
_sym_db.RegisterMessage(PriceRequest)

PriceResponse = _reflection.GeneratedProtocolMessageType('PriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRICERESPONSE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.PriceResponse)
  })
_sym_db.RegisterMessage(PriceResponse)

StreamPricesRequest = _reflection.GeneratedProtocolMessageType('StreamPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPRICESREQUEST,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.StreamPricesRequest)
  })
_sym_db.RegisterMessage(StreamPricesRequest)

StreamPricesResponse = _reflection.GeneratedProtocolMessageType('StreamPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPRICESRESPONSE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.StreamPricesResponse)
  })
_sym_db.RegisterMessage(StreamPricesResponse)


DESCRIPTOR._options = None

_INJECTIVEORACLERPC = _descriptor.ServiceDescriptor(
  name='InjectiveOracleRPC',
  full_name='injective_oracle_rpc.InjectiveOracleRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=543,
  serialized_end=847,
  methods=[
  _descriptor.MethodDescriptor(
    name='OracleList',
    full_name='injective_oracle_rpc.InjectiveOracleRPC.OracleList',
    index=0,
    containing_service=None,
    input_type=_ORACLELISTREQUEST,
    output_type=_ORACLELISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Price',
    full_name='injective_oracle_rpc.InjectiveOracleRPC.Price',
    index=1,
    containing_service=None,
    input_type=_PRICEREQUEST,
    output_type=_PRICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamPrices',
    full_name='injective_oracle_rpc.InjectiveOracleRPC.StreamPrices',
    index=2,
    containing_service=None,
    input_type=_STREAMPRICESREQUEST,
    output_type=_STREAMPRICESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEORACLERPC)

DESCRIPTOR.services_by_name['InjectiveOracleRPC'] = _INJECTIVEORACLERPC

# @@protoc_insertion_point(module_scope)
