# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/insurance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/insurance/v1beta1/insurance.proto',
  package='injective.insurance.v1beta1',
  syntax='proto3',
  serialized_options=b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+injective/insurance/v1beta1/insurance.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x9b\x01\n\x06Params\x12\x8a\x01\n)default_redemption_notice_period_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB<\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x30yaml:\"default_redemption_notice_period_duration\":\x04\xe8\xa0\x1f\x01\"\xec\x03\n\rInsuranceFund\x12\x15\n\rdeposit_denom\x18\x01 \x01(\t\x12\"\n\x1ainsurance_pool_token_denom\x18\x02 \x01(\t\x12z\n!redemption_notice_period_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB4\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f(yaml:\"redemption_notice_period_duration\"\x12?\n\x07\x62\x61lance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x43\n\x0btotal_share\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x11\n\tmarket_id\x18\x06 \x01(\t\x12\x15\n\rmarket_ticker\x18\x07 \x01(\t\x12\x13\n\x0boracle_base\x18\x08 \x01(\t\x12\x14\n\x0coracle_quote\x18\t \x01(\t\x12\x39\n\x0boracle_type\x18\n \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\x0b \x01(\x03\"\xed\x01\n\x12RedemptionSchedule\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08marketId\x18\x02 \x01(\t\x12\x10\n\x08redeemer\x18\x03 \x01(\t\x12k\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB,\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f yaml:\"claimable_redemption_time\"\x12:\n\x11redemption_amount\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"T\n\x18\x45ventInsuranceFundUpdate\x12\x38\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFund\"[\n\x16\x45ventRequestRedemption\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionSchedule\"\x92\x01\n\x17\x45ventWithdrawRedemption\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionSchedule\x12\x34\n\x0bredeem_coin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x9b\x01\n\x0f\x45ventUnderwrite\x12\x13\n\x0bunderwriter\x18\x01 \x01(\t\x12\x10\n\x08marketId\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12/\n\x06shares\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x42QZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,])




_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.insurance.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_redemption_notice_period_duration', full_name='injective.insurance.v1beta1.Params.default_redemption_notice_period_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\230\337\037\001\310\336\037\000\362\336\0370yaml:\"default_redemption_notice_period_duration\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=390,
)


_INSURANCEFUND = _descriptor.Descriptor(
  name='InsuranceFund',
  full_name='injective.insurance.v1beta1.InsuranceFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit_denom', full_name='injective.insurance.v1beta1.InsuranceFund.deposit_denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insurance_pool_token_denom', full_name='injective.insurance.v1beta1.InsuranceFund.insurance_pool_token_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_notice_period_duration', full_name='injective.insurance.v1beta1.InsuranceFund.redemption_notice_period_duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\230\337\037\001\310\336\037\000\362\336\037(yaml:\"redemption_notice_period_duration\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='injective.insurance.v1beta1.InsuranceFund.balance', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_share', full_name='injective.insurance.v1beta1.InsuranceFund.total_share', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.InsuranceFund.market_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ticker', full_name='injective.insurance.v1beta1.InsuranceFund.market_ticker', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.insurance.v1beta1.InsuranceFund.oracle_base', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.insurance.v1beta1.InsuranceFund.oracle_quote', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.insurance.v1beta1.InsuranceFund.oracle_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective.insurance.v1beta1.InsuranceFund.expiry', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=885,
)


_REDEMPTIONSCHEDULE = _descriptor.Descriptor(
  name='RedemptionSchedule',
  full_name='injective.insurance.v1beta1.RedemptionSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='injective.insurance.v1beta1.RedemptionSchedule.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketId', full_name='injective.insurance.v1beta1.RedemptionSchedule.marketId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redeemer', full_name='injective.insurance.v1beta1.RedemptionSchedule.redeemer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claimable_redemption_time', full_name='injective.insurance.v1beta1.RedemptionSchedule.claimable_redemption_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\337\037\001\310\336\037\000\362\336\037 yaml:\"claimable_redemption_time\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_amount', full_name='injective.insurance.v1beta1.RedemptionSchedule.redemption_amount', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=1125,
)


_EVENTINSURANCEFUNDUPDATE = _descriptor.Descriptor(
  name='EventInsuranceFundUpdate',
  full_name='injective.insurance.v1beta1.EventInsuranceFundUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fund', full_name='injective.insurance.v1beta1.EventInsuranceFundUpdate.fund', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1211,
)


_EVENTREQUESTREDEMPTION = _descriptor.Descriptor(
  name='EventRequestRedemption',
  full_name='injective.insurance.v1beta1.EventRequestRedemption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.insurance.v1beta1.EventRequestRedemption.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1304,
)


_EVENTWITHDRAWREDEMPTION = _descriptor.Descriptor(
  name='EventWithdrawRedemption',
  full_name='injective.insurance.v1beta1.EventWithdrawRedemption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.insurance.v1beta1.EventWithdrawRedemption.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redeem_coin', full_name='injective.insurance.v1beta1.EventWithdrawRedemption.redeem_coin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1453,
)


_EVENTUNDERWRITE = _descriptor.Descriptor(
  name='EventUnderwrite',
  full_name='injective.insurance.v1beta1.EventUnderwrite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='underwriter', full_name='injective.insurance.v1beta1.EventUnderwrite.underwriter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketId', full_name='injective.insurance.v1beta1.EventUnderwrite.marketId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='injective.insurance.v1beta1.EventUnderwrite.deposit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shares', full_name='injective.insurance.v1beta1.EventUnderwrite.shares', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1611,
)

_PARAMS.fields_by_name['default_redemption_notice_period_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INSURANCEFUND.fields_by_name['redemption_notice_period_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INSURANCEFUND.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_REDEMPTIONSCHEDULE.fields_by_name['claimable_redemption_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REDEMPTIONSCHEDULE.fields_by_name['redemption_amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTINSURANCEFUNDUPDATE.fields_by_name['fund'].message_type = _INSURANCEFUND
_EVENTREQUESTREDEMPTION.fields_by_name['schedule'].message_type = _REDEMPTIONSCHEDULE
_EVENTWITHDRAWREDEMPTION.fields_by_name['schedule'].message_type = _REDEMPTIONSCHEDULE
_EVENTWITHDRAWREDEMPTION.fields_by_name['redeem_coin'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTUNDERWRITE.fields_by_name['deposit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTUNDERWRITE.fields_by_name['shares'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['InsuranceFund'] = _INSURANCEFUND
DESCRIPTOR.message_types_by_name['RedemptionSchedule'] = _REDEMPTIONSCHEDULE
DESCRIPTOR.message_types_by_name['EventInsuranceFundUpdate'] = _EVENTINSURANCEFUNDUPDATE
DESCRIPTOR.message_types_by_name['EventRequestRedemption'] = _EVENTREQUESTREDEMPTION
DESCRIPTOR.message_types_by_name['EventWithdrawRedemption'] = _EVENTWITHDRAWREDEMPTION
DESCRIPTOR.message_types_by_name['EventUnderwrite'] = _EVENTUNDERWRITE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

InsuranceFund = _reflection.GeneratedProtocolMessageType('InsuranceFund', (_message.Message,), {
  'DESCRIPTOR' : _INSURANCEFUND,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.InsuranceFund)
  })
_sym_db.RegisterMessage(InsuranceFund)

RedemptionSchedule = _reflection.GeneratedProtocolMessageType('RedemptionSchedule', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSCHEDULE,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.RedemptionSchedule)
  })
_sym_db.RegisterMessage(RedemptionSchedule)

EventInsuranceFundUpdate = _reflection.GeneratedProtocolMessageType('EventInsuranceFundUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTINSURANCEFUNDUPDATE,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventInsuranceFundUpdate)
  })
_sym_db.RegisterMessage(EventInsuranceFundUpdate)

EventRequestRedemption = _reflection.GeneratedProtocolMessageType('EventRequestRedemption', (_message.Message,), {
  'DESCRIPTOR' : _EVENTREQUESTREDEMPTION,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventRequestRedemption)
  })
_sym_db.RegisterMessage(EventRequestRedemption)

EventWithdrawRedemption = _reflection.GeneratedProtocolMessageType('EventWithdrawRedemption', (_message.Message,), {
  'DESCRIPTOR' : _EVENTWITHDRAWREDEMPTION,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventWithdrawRedemption)
  })
_sym_db.RegisterMessage(EventWithdrawRedemption)

EventUnderwrite = _reflection.GeneratedProtocolMessageType('EventUnderwrite', (_message.Message,), {
  'DESCRIPTOR' : _EVENTUNDERWRITE,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventUnderwrite)
  })
_sym_db.RegisterMessage(EventUnderwrite)


DESCRIPTOR._options = None
_PARAMS.fields_by_name['default_redemption_notice_period_duration']._options = None
_PARAMS._options = None
_INSURANCEFUND.fields_by_name['redemption_notice_period_duration']._options = None
_INSURANCEFUND.fields_by_name['balance']._options = None
_INSURANCEFUND.fields_by_name['total_share']._options = None
_REDEMPTIONSCHEDULE.fields_by_name['claimable_redemption_time']._options = None
_REDEMPTIONSCHEDULE.fields_by_name['redemption_amount']._options = None
_EVENTWITHDRAWREDEMPTION.fields_by_name['redeem_coin']._options = None
_EVENTUNDERWRITE.fields_by_name['deposit']._options = None
_EVENTUNDERWRITE.fields_by_name['shares']._options = None
# @@protoc_insertion_point(module_scope)
