# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/types/v1beta1/tx_response.proto',
  package='injective.types.v1beta1',
  syntax='proto3',
  serialized_options=b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)injective/types/v1beta1/tx_response.proto\x12\x17injective.types.v1beta1\"8\n\x18TxResponseGenericMessage\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"U\n\x0eTxResponseData\x12\x43\n\x08messages\x18\x01 \x03(\x0b\x32\x31.injective.types.v1beta1.TxResponseGenericMessageB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3'
)




_TXRESPONSEGENERICMESSAGE = _descriptor.Descriptor(
  name='TxResponseGenericMessage',
  full_name='injective.types.v1beta1.TxResponseGenericMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='injective.types.v1beta1.TxResponseGenericMessage.header', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.types.v1beta1.TxResponseGenericMessage.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=126,
)


_TXRESPONSEDATA = _descriptor.Descriptor(
  name='TxResponseData',
  full_name='injective.types.v1beta1.TxResponseData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='injective.types.v1beta1.TxResponseData.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=213,
)

_TXRESPONSEDATA.fields_by_name['messages'].message_type = _TXRESPONSEGENERICMESSAGE
DESCRIPTOR.message_types_by_name['TxResponseGenericMessage'] = _TXRESPONSEGENERICMESSAGE
DESCRIPTOR.message_types_by_name['TxResponseData'] = _TXRESPONSEDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TxResponseGenericMessage = _reflection.GeneratedProtocolMessageType('TxResponseGenericMessage', (_message.Message,), {
  'DESCRIPTOR' : _TXRESPONSEGENERICMESSAGE,
  '__module__' : 'injective.types.v1beta1.tx_response_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.TxResponseGenericMessage)
  })
_sym_db.RegisterMessage(TxResponseGenericMessage)

TxResponseData = _reflection.GeneratedProtocolMessageType('TxResponseData', (_message.Message,), {
  'DESCRIPTOR' : _TXRESPONSEDATA,
  '__module__' : 'injective.types.v1beta1.tx_response_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.TxResponseData)
  })
_sym_db.RegisterMessage(TxResponseData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
