# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v1/solomachine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/lightclients/solomachine/v1/solomachine.proto',
  package='ibc.lightclients.solomachine.v1',
  syntax='proto3',
  serialized_options=b'Z>github.com/cosmos/ibc-go/v2/modules/core/02-client/legacy/v100',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1ibc/lightclients/solomachine/v1/solomachine.proto\x12\x1fibc.lightclients.solomachine.v1\x1a\'ibc/core/connection/v1/connection.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\x8d\x02\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x33\n\x0f\x66rozen_sequence\x18\x02 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"frozen_sequence\"\x12\x64\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v1.ConsensusStateB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\"\x12K\n\x1b\x61llow_update_after_proposal\x18\x04 \x01(\x08\x42&\xf2\xde\x1f\"yaml:\"allow_update_after_proposal\":\x04\x88\xa0\x1f\x00\"\x7f\n\x0e\x43onsensusState\x12?\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x15\xf2\xde\x1f\x11yaml:\"public_key\"\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xc4\x01\n\x06Header\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12G\n\x0enew_public_key\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\xf2\xde\x1f\x15yaml:\"new_public_key\"\x12\x33\n\x0fnew_diversifier\x18\x05 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"\x97\x02\n\x0cMisbehaviour\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12\x62\n\rsignature_one\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v1.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_one\"\x12\x62\n\rsignature_two\x18\x04 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v1.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_two\":\x04\x88\xa0\x1f\x00\"\xa0\x01\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12R\n\tdata_type\x18\x02 \x01(\x0e\x32).ibc.lightclients.solomachine.v1.DataTypeB\x14\xf2\xde\x1f\x10yaml:\"data_type\"\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"f\n\x18TimestampedSignatureData\x12\x31\n\x0esignature_data\x18\x01 \x01(\x0c\x42\x19\xf2\xde\x1f\x15yaml:\"signature_data\"\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xad\x01\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12R\n\tdata_type\x18\x04 \x01(\x0e\x32).ibc.lightclients.solomachine.v1.DataTypeB\x14\xf2\xde\x1f\x10yaml:\"data_type\"\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"\x8a\x01\n\nHeaderData\x12\x41\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x16\xf2\xde\x1f\x12yaml:\"new_pub_key\"\x12\x33\n\x0fnew_diversifier\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"j\n\x0f\x43lientStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x43\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\":\x04\x88\xa0\x1f\x00\"s\n\x12\x43onsensusStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12I\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\":\x04\x88\xa0\x1f\x00\"d\n\x13\x43onnectionStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEnd:\x04\x88\xa0\x1f\x00\"U\n\x10\x43hannelStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.Channel:\x04\x88\xa0\x1f\x00\"8\n\x14PacketCommitmentData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x12\n\ncommitment\x18\x02 \x01(\x0c\"B\n\x19PacketAcknowledgementData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\"(\n\x18PacketReceiptAbsenceData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\"U\n\x14NextSequenceRecvData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12/\n\rnext_seq_recv\x18\x02 \x01(\x04\x42\x18\xf2\xde\x1f\x14yaml:\"next_seq_recv\"*\x8c\x04\n\x08\x44\x61taType\x12\x38\n#DATA_TYPE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12&\n\x16\x44\x41TA_TYPE_CLIENT_STATE\x10\x01\x1a\n\x8a\x9d \x06\x43LIENT\x12,\n\x19\x44\x41TA_TYPE_CONSENSUS_STATE\x10\x02\x1a\r\x8a\x9d \tCONSENSUS\x12.\n\x1a\x44\x41TA_TYPE_CONNECTION_STATE\x10\x03\x1a\x0e\x8a\x9d \nCONNECTION\x12(\n\x17\x44\x41TA_TYPE_CHANNEL_STATE\x10\x04\x1a\x0b\x8a\x9d \x07\x43HANNEL\x12\x35\n\x1b\x44\x41TA_TYPE_PACKET_COMMITMENT\x10\x05\x1a\x14\x8a\x9d \x10PACKETCOMMITMENT\x12?\n DATA_TYPE_PACKET_ACKNOWLEDGEMENT\x10\x06\x1a\x19\x8a\x9d \x15PACKETACKNOWLEDGEMENT\x12>\n DATA_TYPE_PACKET_RECEIPT_ABSENCE\x10\x07\x1a\x18\x8a\x9d \x14PACKETRECEIPTABSENCE\x12\x36\n\x1c\x44\x41TA_TYPE_NEXT_SEQUENCE_RECV\x10\x08\x1a\x14\x8a\x9d \x10NEXTSEQUENCERECV\x12 \n\x10\x44\x41TA_TYPE_HEADER\x10\t\x1a\n\x8a\x9d \x06HEADER\x1a\x04\x88\xa3\x1e\x00\x42@Z>github.com/cosmos/ibc-go/v2/modules/core/02-client/legacy/v100b\x06proto3'
  ,
  dependencies=[ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2.DESCRIPTOR,ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='ibc.lightclients.solomachine.v1.DataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_UNINITIALIZED_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \013UNSPECIFIED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CLIENT_STATE', index=1, number=1,
      serialized_options=b'\212\235 \006CLIENT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CONSENSUS_STATE', index=2, number=2,
      serialized_options=b'\212\235 \tCONSENSUS',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CONNECTION_STATE', index=3, number=3,
      serialized_options=b'\212\235 \nCONNECTION',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CHANNEL_STATE', index=4, number=4,
      serialized_options=b'\212\235 \007CHANNEL',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_PACKET_COMMITMENT', index=5, number=5,
      serialized_options=b'\212\235 \020PACKETCOMMITMENT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_PACKET_ACKNOWLEDGEMENT', index=6, number=6,
      serialized_options=b'\212\235 \025PACKETACKNOWLEDGEMENT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_PACKET_RECEIPT_ABSENCE', index=7, number=7,
      serialized_options=b'\212\235 \024PACKETRECEIPTABSENCE',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_NEXT_SEQUENCE_RECV', index=8, number=8,
      serialized_options=b'\212\235 \020NEXTSEQUENCERECV',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_HEADER', index=9, number=9,
      serialized_options=b'\212\235 \006HEADER',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=2347,
  serialized_end=2871,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE)

DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
DATA_TYPE_UNINITIALIZED_UNSPECIFIED = 0
DATA_TYPE_CLIENT_STATE = 1
DATA_TYPE_CONSENSUS_STATE = 2
DATA_TYPE_CONNECTION_STATE = 3
DATA_TYPE_CHANNEL_STATE = 4
DATA_TYPE_PACKET_COMMITMENT = 5
DATA_TYPE_PACKET_ACKNOWLEDGEMENT = 6
DATA_TYPE_PACKET_RECEIPT_ABSENCE = 7
DATA_TYPE_NEXT_SEQUENCE_RECV = 8
DATA_TYPE_HEADER = 9



_CLIENTSTATE = _descriptor.Descriptor(
  name='ClientState',
  full_name='ibc.lightclients.solomachine.v1.ClientState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.ClientState.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frozen_sequence', full_name='ibc.lightclients.solomachine.v1.ClientState.frozen_sequence', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"frozen_sequence\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_state', full_name='ibc.lightclients.solomachine.v1.ClientState.consensus_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"consensus_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_update_after_proposal', full_name='ibc.lightclients.solomachine.v1.ClientState.allow_update_after_proposal', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\"yaml:\"allow_update_after_proposal\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=481,
)


_CONSENSUSSTATE = _descriptor.Descriptor(
  name='ConsensusState',
  full_name='ibc.lightclients.solomachine.v1.ConsensusState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='ibc.lightclients.solomachine.v1.ConsensusState.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"public_key\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diversifier', full_name='ibc.lightclients.solomachine.v1.ConsensusState.diversifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.ConsensusState.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=610,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='ibc.lightclients.solomachine.v1.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.Header.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.Header.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='ibc.lightclients.solomachine.v1.Header.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_public_key', full_name='ibc.lightclients.solomachine.v1.Header.new_public_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"new_public_key\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_diversifier', full_name='ibc.lightclients.solomachine.v1.Header.new_diversifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"new_diversifier\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=809,
)


_MISBEHAVIOUR = _descriptor.Descriptor(
  name='Misbehaviour',
  full_name='ibc.lightclients.solomachine.v1.Misbehaviour',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.sequence', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_one', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.signature_one', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"signature_one\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_two', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.signature_two', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"signature_two\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=1091,
)


_SIGNATUREANDDATA = _descriptor.Descriptor(
  name='SignatureAndData',
  full_name='ibc.lightclients.solomachine.v1.SignatureAndData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"data_type\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1254,
)


_TIMESTAMPEDSIGNATUREDATA = _descriptor.Descriptor(
  name='TimestampedSignatureData',
  full_name='ibc.lightclients.solomachine.v1.TimestampedSignatureData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature_data', full_name='ibc.lightclients.solomachine.v1.TimestampedSignatureData.signature_data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"signature_data\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.TimestampedSignatureData.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1358,
)


_SIGNBYTES = _descriptor.Descriptor(
  name='SignBytes',
  full_name='ibc.lightclients.solomachine.v1.SignBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.SignBytes.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.SignBytes.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diversifier', full_name='ibc.lightclients.solomachine.v1.SignBytes.diversifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ibc.lightclients.solomachine.v1.SignBytes.data_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"data_type\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ibc.lightclients.solomachine.v1.SignBytes.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1534,
)


_HEADERDATA = _descriptor.Descriptor(
  name='HeaderData',
  full_name='ibc.lightclients.solomachine.v1.HeaderData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_pub_key', full_name='ibc.lightclients.solomachine.v1.HeaderData.new_pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\022yaml:\"new_pub_key\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_diversifier', full_name='ibc.lightclients.solomachine.v1.HeaderData.new_diversifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"new_diversifier\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1537,
  serialized_end=1675,
)


_CLIENTSTATEDATA = _descriptor.Descriptor(
  name='ClientStateData',
  full_name='ibc.lightclients.solomachine.v1.ClientStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ClientStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_state', full_name='ibc.lightclients.solomachine.v1.ClientStateData.client_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"client_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1783,
)


_CONSENSUSSTATEDATA = _descriptor.Descriptor(
  name='ConsensusStateData',
  full_name='ibc.lightclients.solomachine.v1.ConsensusStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ConsensusStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_state', full_name='ibc.lightclients.solomachine.v1.ConsensusStateData.consensus_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"consensus_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1785,
  serialized_end=1900,
)


_CONNECTIONSTATEDATA = _descriptor.Descriptor(
  name='ConnectionStateData',
  full_name='ibc.lightclients.solomachine.v1.ConnectionStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ConnectionStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='ibc.lightclients.solomachine.v1.ConnectionStateData.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2002,
)


_CHANNELSTATEDATA = _descriptor.Descriptor(
  name='ChannelStateData',
  full_name='ibc.lightclients.solomachine.v1.ChannelStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ChannelStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='ibc.lightclients.solomachine.v1.ChannelStateData.channel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2004,
  serialized_end=2089,
)


_PACKETCOMMITMENTDATA = _descriptor.Descriptor(
  name='PacketCommitmentData',
  full_name='ibc.lightclients.solomachine.v1.PacketCommitmentData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.PacketCommitmentData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='ibc.lightclients.solomachine.v1.PacketCommitmentData.commitment', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2147,
)


_PACKETACKNOWLEDGEMENTDATA = _descriptor.Descriptor(
  name='PacketAcknowledgementData',
  full_name='ibc.lightclients.solomachine.v1.PacketAcknowledgementData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.PacketAcknowledgementData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acknowledgement', full_name='ibc.lightclients.solomachine.v1.PacketAcknowledgementData.acknowledgement', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2149,
  serialized_end=2215,
)


_PACKETRECEIPTABSENCEDATA = _descriptor.Descriptor(
  name='PacketReceiptAbsenceData',
  full_name='ibc.lightclients.solomachine.v1.PacketReceiptAbsenceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.PacketReceiptAbsenceData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2257,
)


_NEXTSEQUENCERECVDATA = _descriptor.Descriptor(
  name='NextSequenceRecvData',
  full_name='ibc.lightclients.solomachine.v1.NextSequenceRecvData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.NextSequenceRecvData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_seq_recv', full_name='ibc.lightclients.solomachine.v1.NextSequenceRecvData.next_seq_recv', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"next_seq_recv\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2344,
)

_CLIENTSTATE.fields_by_name['consensus_state'].message_type = _CONSENSUSSTATE
_CONSENSUSSTATE.fields_by_name['public_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_HEADER.fields_by_name['new_public_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MISBEHAVIOUR.fields_by_name['signature_one'].message_type = _SIGNATUREANDDATA
_MISBEHAVIOUR.fields_by_name['signature_two'].message_type = _SIGNATUREANDDATA
_SIGNATUREANDDATA.fields_by_name['data_type'].enum_type = _DATATYPE
_SIGNBYTES.fields_by_name['data_type'].enum_type = _DATATYPE
_HEADERDATA.fields_by_name['new_pub_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLIENTSTATEDATA.fields_by_name['client_state'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CONSENSUSSTATEDATA.fields_by_name['consensus_state'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CONNECTIONSTATEDATA.fields_by_name['connection'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._CONNECTIONEND
_CHANNELSTATEDATA.fields_by_name['channel'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._CHANNEL
DESCRIPTOR.message_types_by_name['ClientState'] = _CLIENTSTATE
DESCRIPTOR.message_types_by_name['ConsensusState'] = _CONSENSUSSTATE
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Misbehaviour'] = _MISBEHAVIOUR
DESCRIPTOR.message_types_by_name['SignatureAndData'] = _SIGNATUREANDDATA
DESCRIPTOR.message_types_by_name['TimestampedSignatureData'] = _TIMESTAMPEDSIGNATUREDATA
DESCRIPTOR.message_types_by_name['SignBytes'] = _SIGNBYTES
DESCRIPTOR.message_types_by_name['HeaderData'] = _HEADERDATA
DESCRIPTOR.message_types_by_name['ClientStateData'] = _CLIENTSTATEDATA
DESCRIPTOR.message_types_by_name['ConsensusStateData'] = _CONSENSUSSTATEDATA
DESCRIPTOR.message_types_by_name['ConnectionStateData'] = _CONNECTIONSTATEDATA
DESCRIPTOR.message_types_by_name['ChannelStateData'] = _CHANNELSTATEDATA
DESCRIPTOR.message_types_by_name['PacketCommitmentData'] = _PACKETCOMMITMENTDATA
DESCRIPTOR.message_types_by_name['PacketAcknowledgementData'] = _PACKETACKNOWLEDGEMENTDATA
DESCRIPTOR.message_types_by_name['PacketReceiptAbsenceData'] = _PACKETRECEIPTABSENCEDATA
DESCRIPTOR.message_types_by_name['NextSequenceRecvData'] = _NEXTSEQUENCERECVDATA
DESCRIPTOR.enum_types_by_name['DataType'] = _DATATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientState = _reflection.GeneratedProtocolMessageType('ClientState', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATE,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ClientState)
  })
_sym_db.RegisterMessage(ClientState)

ConsensusState = _reflection.GeneratedProtocolMessageType('ConsensusState', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSSTATE,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ConsensusState)
  })
_sym_db.RegisterMessage(ConsensusState)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.Header)
  })
_sym_db.RegisterMessage(Header)

Misbehaviour = _reflection.GeneratedProtocolMessageType('Misbehaviour', (_message.Message,), {
  'DESCRIPTOR' : _MISBEHAVIOUR,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.Misbehaviour)
  })
_sym_db.RegisterMessage(Misbehaviour)

SignatureAndData = _reflection.GeneratedProtocolMessageType('SignatureAndData', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATUREANDDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.SignatureAndData)
  })
_sym_db.RegisterMessage(SignatureAndData)

TimestampedSignatureData = _reflection.GeneratedProtocolMessageType('TimestampedSignatureData', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPEDSIGNATUREDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.TimestampedSignatureData)
  })
_sym_db.RegisterMessage(TimestampedSignatureData)

SignBytes = _reflection.GeneratedProtocolMessageType('SignBytes', (_message.Message,), {
  'DESCRIPTOR' : _SIGNBYTES,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.SignBytes)
  })
_sym_db.RegisterMessage(SignBytes)

HeaderData = _reflection.GeneratedProtocolMessageType('HeaderData', (_message.Message,), {
  'DESCRIPTOR' : _HEADERDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.HeaderData)
  })
_sym_db.RegisterMessage(HeaderData)

ClientStateData = _reflection.GeneratedProtocolMessageType('ClientStateData', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ClientStateData)
  })
_sym_db.RegisterMessage(ClientStateData)

ConsensusStateData = _reflection.GeneratedProtocolMessageType('ConsensusStateData', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ConsensusStateData)
  })
_sym_db.RegisterMessage(ConsensusStateData)

ConnectionStateData = _reflection.GeneratedProtocolMessageType('ConnectionStateData', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ConnectionStateData)
  })
_sym_db.RegisterMessage(ConnectionStateData)

ChannelStateData = _reflection.GeneratedProtocolMessageType('ChannelStateData', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ChannelStateData)
  })
_sym_db.RegisterMessage(ChannelStateData)

PacketCommitmentData = _reflection.GeneratedProtocolMessageType('PacketCommitmentData', (_message.Message,), {
  'DESCRIPTOR' : _PACKETCOMMITMENTDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.PacketCommitmentData)
  })
_sym_db.RegisterMessage(PacketCommitmentData)

PacketAcknowledgementData = _reflection.GeneratedProtocolMessageType('PacketAcknowledgementData', (_message.Message,), {
  'DESCRIPTOR' : _PACKETACKNOWLEDGEMENTDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.PacketAcknowledgementData)
  })
_sym_db.RegisterMessage(PacketAcknowledgementData)

PacketReceiptAbsenceData = _reflection.GeneratedProtocolMessageType('PacketReceiptAbsenceData', (_message.Message,), {
  'DESCRIPTOR' : _PACKETRECEIPTABSENCEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.PacketReceiptAbsenceData)
  })
_sym_db.RegisterMessage(PacketReceiptAbsenceData)

NextSequenceRecvData = _reflection.GeneratedProtocolMessageType('NextSequenceRecvData', (_message.Message,), {
  'DESCRIPTOR' : _NEXTSEQUENCERECVDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.NextSequenceRecvData)
  })
_sym_db.RegisterMessage(NextSequenceRecvData)


DESCRIPTOR._options = None
_DATATYPE._options = None
_DATATYPE.values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CLIENT_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CONSENSUS_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CONNECTION_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CHANNEL_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_HEADER"]._options = None
_CLIENTSTATE.fields_by_name['frozen_sequence']._options = None
_CLIENTSTATE.fields_by_name['consensus_state']._options = None
_CLIENTSTATE.fields_by_name['allow_update_after_proposal']._options = None
_CLIENTSTATE._options = None
_CONSENSUSSTATE.fields_by_name['public_key']._options = None
_CONSENSUSSTATE._options = None
_HEADER.fields_by_name['new_public_key']._options = None
_HEADER.fields_by_name['new_diversifier']._options = None
_HEADER._options = None
_MISBEHAVIOUR.fields_by_name['client_id']._options = None
_MISBEHAVIOUR.fields_by_name['signature_one']._options = None
_MISBEHAVIOUR.fields_by_name['signature_two']._options = None
_MISBEHAVIOUR._options = None
_SIGNATUREANDDATA.fields_by_name['data_type']._options = None
_SIGNATUREANDDATA._options = None
_TIMESTAMPEDSIGNATUREDATA.fields_by_name['signature_data']._options = None
_TIMESTAMPEDSIGNATUREDATA._options = None
_SIGNBYTES.fields_by_name['data_type']._options = None
_SIGNBYTES._options = None
_HEADERDATA.fields_by_name['new_pub_key']._options = None
_HEADERDATA.fields_by_name['new_diversifier']._options = None
_HEADERDATA._options = None
_CLIENTSTATEDATA.fields_by_name['client_state']._options = None
_CLIENTSTATEDATA._options = None
_CONSENSUSSTATEDATA.fields_by_name['consensus_state']._options = None
_CONSENSUSSTATEDATA._options = None
_CONNECTIONSTATEDATA._options = None
_CHANNELSTATEDATA._options = None
_NEXTSEQUENCERECVDATA.fields_by_name['next_seq_recv']._options = None
# @@protoc_insertion_point(module_scope)
