# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/authz.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&injective/exchange/v1beta1/authz.proto\x12\x1ainjective.exchange.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\"Y\n\x19\x43reateSpotLimitOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"Z\n\x1a\x43reateSpotMarketOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"_\n\x1f\x42\x61tchCreateSpotLimitOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"T\n\x14\x43\x61ncelSpotOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"Z\n\x1a\x42\x61tchCancelSpotOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"_\n\x1f\x43reateDerivativeLimitOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"`\n CreateDerivativeMarketOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"e\n%BatchCreateDerivativeLimitOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"Z\n\x1a\x43\x61ncelDerivativeOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"`\n BatchCancelDerivativeOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"t\n\x16\x42\x61tchUpdateOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x14\n\x0cspot_markets\x18\x02 \x03(\t\x12\x1a\n\x12\x64\x65rivative_markets\x18\x03 \x03(\t:\x11\xd2\xb4-\rAuthorizationBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,])




_CREATESPOTLIMITORDERAUTHZ = _descriptor.Descriptor(
  name='CreateSpotLimitOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateSpotLimitOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateSpotLimitOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateSpotLimitOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=186,
)


_CREATESPOTMARKETORDERAUTHZ = _descriptor.Descriptor(
  name='CreateSpotMarketOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateSpotMarketOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateSpotMarketOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateSpotMarketOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=278,
)


_BATCHCREATESPOTLIMITORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCreateSpotLimitOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=375,
)


_CANCELSPOTORDERAUTHZ = _descriptor.Descriptor(
  name='CancelSpotOrderAuthz',
  full_name='injective.exchange.v1beta1.CancelSpotOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CancelSpotOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CancelSpotOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=461,
)


_BATCHCANCELSPOTORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCancelSpotOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=553,
)


_CREATEDERIVATIVELIMITORDERAUTHZ = _descriptor.Descriptor(
  name='CreateDerivativeLimitOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=650,
)


_CREATEDERIVATIVEMARKETORDERAUTHZ = _descriptor.Descriptor(
  name='CreateDerivativeMarketOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=748,
)


_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCreateDerivativeLimitOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=851,
)


_CANCELDERIVATIVEORDERAUTHZ = _descriptor.Descriptor(
  name='CancelDerivativeOrderAuthz',
  full_name='injective.exchange.v1beta1.CancelDerivativeOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CancelDerivativeOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CancelDerivativeOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=943,
)


_BATCHCANCELDERIVATIVEORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCancelDerivativeOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1041,
)


_BATCHUPDATEORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchUpdateOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_markets', full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz.spot_markets', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_markets', full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz.derivative_markets', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1159,
)

DESCRIPTOR.message_types_by_name['CreateSpotLimitOrderAuthz'] = _CREATESPOTLIMITORDERAUTHZ
DESCRIPTOR.message_types_by_name['CreateSpotMarketOrderAuthz'] = _CREATESPOTMARKETORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCreateSpotLimitOrdersAuthz'] = _BATCHCREATESPOTLIMITORDERSAUTHZ
DESCRIPTOR.message_types_by_name['CancelSpotOrderAuthz'] = _CANCELSPOTORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCancelSpotOrdersAuthz'] = _BATCHCANCELSPOTORDERSAUTHZ
DESCRIPTOR.message_types_by_name['CreateDerivativeLimitOrderAuthz'] = _CREATEDERIVATIVELIMITORDERAUTHZ
DESCRIPTOR.message_types_by_name['CreateDerivativeMarketOrderAuthz'] = _CREATEDERIVATIVEMARKETORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCreateDerivativeLimitOrdersAuthz'] = _BATCHCREATEDERIVATIVELIMITORDERSAUTHZ
DESCRIPTOR.message_types_by_name['CancelDerivativeOrderAuthz'] = _CANCELDERIVATIVEORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCancelDerivativeOrdersAuthz'] = _BATCHCANCELDERIVATIVEORDERSAUTHZ
DESCRIPTOR.message_types_by_name['BatchUpdateOrdersAuthz'] = _BATCHUPDATEORDERSAUTHZ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSpotLimitOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateSpotLimitOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPOTLIMITORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateSpotLimitOrderAuthz)
  })
_sym_db.RegisterMessage(CreateSpotLimitOrderAuthz)

CreateSpotMarketOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateSpotMarketOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPOTMARKETORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateSpotMarketOrderAuthz)
  })
_sym_db.RegisterMessage(CreateSpotMarketOrderAuthz)

BatchCreateSpotLimitOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCreateSpotLimitOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCREATESPOTLIMITORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCreateSpotLimitOrdersAuthz)

CancelSpotOrderAuthz = _reflection.GeneratedProtocolMessageType('CancelSpotOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CANCELSPOTORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CancelSpotOrderAuthz)
  })
_sym_db.RegisterMessage(CancelSpotOrderAuthz)

BatchCancelSpotOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCancelSpotOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCANCELSPOTORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCancelSpotOrdersAuthz)

CreateDerivativeLimitOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateDerivativeLimitOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDERIVATIVELIMITORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz)
  })
_sym_db.RegisterMessage(CreateDerivativeLimitOrderAuthz)

CreateDerivativeMarketOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateDerivativeMarketOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDERIVATIVEMARKETORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz)
  })
_sym_db.RegisterMessage(CreateDerivativeMarketOrderAuthz)

BatchCreateDerivativeLimitOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCreateDerivativeLimitOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCREATEDERIVATIVELIMITORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCreateDerivativeLimitOrdersAuthz)

CancelDerivativeOrderAuthz = _reflection.GeneratedProtocolMessageType('CancelDerivativeOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CANCELDERIVATIVEORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CancelDerivativeOrderAuthz)
  })
_sym_db.RegisterMessage(CancelDerivativeOrderAuthz)

BatchCancelDerivativeOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCancelDerivativeOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCANCELDERIVATIVEORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCancelDerivativeOrdersAuthz)

BatchUpdateOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchUpdateOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHUPDATEORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchUpdateOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchUpdateOrdersAuthz)


DESCRIPTOR._options = None
_CREATESPOTLIMITORDERAUTHZ._options = None
_CREATESPOTMARKETORDERAUTHZ._options = None
_BATCHCREATESPOTLIMITORDERSAUTHZ._options = None
_CANCELSPOTORDERAUTHZ._options = None
_BATCHCANCELSPOTORDERSAUTHZ._options = None
_CREATEDERIVATIVELIMITORDERAUTHZ._options = None
_CREATEDERIVATIVEMARKETORDERAUTHZ._options = None
_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ._options = None
_CANCELDERIVATIVEORDERAUTHZ._options = None
_BATCHCANCELDERIVATIVEORDERSAUTHZ._options = None
_BATCHUPDATEORDERSAUTHZ._options = None
# @@protoc_insertion_point(module_scope)
