# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/blockchain/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/blockchain/types.proto',
  package='tendermint.blockchain',
  syntax='proto3',
  serialized_options=b'Z<github.com/tendermint/tendermint/proto/tendermint/blockchain',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!tendermint/blockchain/types.proto\x12\x15tendermint.blockchain\x1a\x1ctendermint/types/block.proto\"\x1e\n\x0c\x42lockRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"!\n\x0fNoBlockResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\"7\n\rBlockResponse\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.tendermint.types.Block\"\x0f\n\rStatusRequest\".\n\x0eStatusResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x03\"\xd5\x02\n\x07Message\x12<\n\rblock_request\x18\x01 \x01(\x0b\x32#.tendermint.blockchain.BlockRequestH\x00\x12\x43\n\x11no_block_response\x18\x02 \x01(\x0b\x32&.tendermint.blockchain.NoBlockResponseH\x00\x12>\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32$.tendermint.blockchain.BlockResponseH\x00\x12>\n\x0estatus_request\x18\x04 \x01(\x0b\x32$.tendermint.blockchain.StatusRequestH\x00\x12@\n\x0fstatus_response\x18\x05 \x01(\x0b\x32%.tendermint.blockchain.StatusResponseH\x00\x42\x05\n\x03sumB>Z<github.com/tendermint/tendermint/proto/tendermint/blockchainb\x06proto3'
  ,
  dependencies=[tendermint_dot_types_dot_block__pb2.DESCRIPTOR,])




_BLOCKREQUEST = _descriptor.Descriptor(
  name='BlockRequest',
  full_name='tendermint.blockchain.BlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.blockchain.BlockRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=120,
)


_NOBLOCKRESPONSE = _descriptor.Descriptor(
  name='NoBlockResponse',
  full_name='tendermint.blockchain.NoBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.blockchain.NoBlockResponse.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=155,
)


_BLOCKRESPONSE = _descriptor.Descriptor(
  name='BlockResponse',
  full_name='tendermint.blockchain.BlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='tendermint.blockchain.BlockResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=212,
)


_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='tendermint.blockchain.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=229,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='tendermint.blockchain.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.blockchain.StatusResponse.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='tendermint.blockchain.StatusResponse.base', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=277,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.blockchain.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_request', full_name='tendermint.blockchain.Message.block_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_block_response', full_name='tendermint.blockchain.Message.no_block_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_response', full_name='tendermint.blockchain.Message.block_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_request', full_name='tendermint.blockchain.Message.status_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_response', full_name='tendermint.blockchain.Message.status_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.blockchain.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=621,
)

_BLOCKRESPONSE.fields_by_name['block'].message_type = tendermint_dot_types_dot_block__pb2._BLOCK
_MESSAGE.fields_by_name['block_request'].message_type = _BLOCKREQUEST
_MESSAGE.fields_by_name['no_block_response'].message_type = _NOBLOCKRESPONSE
_MESSAGE.fields_by_name['block_response'].message_type = _BLOCKRESPONSE
_MESSAGE.fields_by_name['status_request'].message_type = _STATUSREQUEST
_MESSAGE.fields_by_name['status_response'].message_type = _STATUSRESPONSE
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['block_request'])
_MESSAGE.fields_by_name['block_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['no_block_response'])
_MESSAGE.fields_by_name['no_block_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['block_response'])
_MESSAGE.fields_by_name['block_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['status_request'])
_MESSAGE.fields_by_name['status_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['status_response'])
_MESSAGE.fields_by_name['status_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['BlockRequest'] = _BLOCKREQUEST
DESCRIPTOR.message_types_by_name['NoBlockResponse'] = _NOBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['BlockResponse'] = _BLOCKRESPONSE
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockRequest = _reflection.GeneratedProtocolMessageType('BlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKREQUEST,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.BlockRequest)
  })
_sym_db.RegisterMessage(BlockRequest)

NoBlockResponse = _reflection.GeneratedProtocolMessageType('NoBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOBLOCKRESPONSE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.NoBlockResponse)
  })
_sym_db.RegisterMessage(NoBlockResponse)

BlockResponse = _reflection.GeneratedProtocolMessageType('BlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKRESPONSE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.BlockResponse)
  })
_sym_db.RegisterMessage(BlockResponse)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATUSREQUEST,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.StatusRequest)
  })
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRESPONSE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.StatusResponse)
  })
_sym_db.RegisterMessage(StatusResponse)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
