# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/v1beta1/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from cosmos.tx.v1beta1 import tx_pb2 as cosmos_dot_tx_dot_v1beta1_dot_tx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/tx/v1beta1/service.proto',
  package='cosmos.tx.v1beta1',
  syntax='proto3',
  serialized_options=b'Z%github.com/cosmos/cosmos-sdk/types/tx\300\343\036\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63osmos/tx/v1beta1/service.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a\x1a\x63osmos/tx/v1beta1/tx.proto\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\"\x8e\x01\n\x12GetTxsEventRequest\x12\x0e\n\x06\x65vents\x18\x01 \x03(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12,\n\x08order_by\x18\x03 \x01(\x0e\x32\x1a.cosmos.tx.v1beta1.OrderBy\"\xb2\x01\n\x13GetTxsEventResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12:\n\x0ctx_responses\x18\x02 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"V\n\x12\x42roadcastTxRequest\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .cosmos.tx.v1beta1.BroadcastMode\"P\n\x13\x42roadcastTxResponse\x12\x39\n\x0btx_response\x18\x01 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"J\n\x0fSimulateRequest\x12%\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.TxB\x02\x18\x01\x12\x10\n\x08tx_bytes\x18\x02 \x01(\x0c\"y\n\x10SimulateResponse\x12\x33\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfo\x12\x30\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.Result\"\x1c\n\x0cGetTxRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"m\n\rGetTxResponse\x12!\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12\x39\n\x0btx_response\x18\x02 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"d\n\x16GetBlockWithTxsRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcf\x01\n\x17GetBlockWithTxsResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12+\n\x08\x62lock_id\x18\x02 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x17.tendermint.types.Block\x12;\n\npagination\x18\x04 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse*H\n\x07OrderBy\x12\x18\n\x14ORDER_BY_UNSPECIFIED\x10\x00\x12\x10\n\x0cORDER_BY_ASC\x10\x01\x12\x11\n\rORDER_BY_DESC\x10\x02*|\n\rBroadcastMode\x12\x1e\n\x1a\x42ROADCAST_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42ROADCAST_MODE_BLOCK\x10\x01\x12\x17\n\x13\x42ROADCAST_MODE_SYNC\x10\x02\x12\x18\n\x14\x42ROADCAST_MODE_ASYNC\x10\x03\x32\x92\x05\n\x07Service\x12{\n\x08Simulate\x12\".cosmos.tx.v1beta1.SimulateRequest\x1a#.cosmos.tx.v1beta1.SimulateResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/cosmos/tx/v1beta1/simulate:\x01*\x12q\n\x05GetTx\x12\x1f.cosmos.tx.v1beta1.GetTxRequest\x1a .cosmos.tx.v1beta1.GetTxResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/tx/v1beta1/txs/{hash}\x12\x7f\n\x0b\x42roadcastTx\x12%.cosmos.tx.v1beta1.BroadcastTxRequest\x1a&.cosmos.tx.v1beta1.BroadcastTxResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/cosmos/tx/v1beta1/txs:\x01*\x12|\n\x0bGetTxsEvent\x12%.cosmos.tx.v1beta1.GetTxsEventRequest\x1a&.cosmos.tx.v1beta1.GetTxsEventResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmos/tx/v1beta1/txs\x12\x97\x01\n\x0fGetBlockWithTxs\x12).cosmos.tx.v1beta1.GetBlockWithTxsRequest\x1a*.cosmos.tx.v1beta1.GetBlockWithTxsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/cosmos/tx/v1beta1/txs/block/{height}B+Z%github.com/cosmos/cosmos-sdk/types/tx\xc0\xe3\x1e\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2.DESCRIPTOR,cosmos_dot_tx_dot_v1beta1_dot_tx__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2.DESCRIPTOR,tendermint_dot_types_dot_block__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,])

_ORDERBY = _descriptor.EnumDescriptor(
  name='OrderBy',
  full_name='cosmos.tx.v1beta1.OrderBy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORDER_BY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_BY_ASC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_BY_DESC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1423,
  serialized_end=1495,
)
_sym_db.RegisterEnumDescriptor(_ORDERBY)

OrderBy = enum_type_wrapper.EnumTypeWrapper(_ORDERBY)
_BROADCASTMODE = _descriptor.EnumDescriptor(
  name='BroadcastMode',
  full_name='cosmos.tx.v1beta1.BroadcastMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_BLOCK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_SYNC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROADCAST_MODE_ASYNC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1497,
  serialized_end=1621,
)
_sym_db.RegisterEnumDescriptor(_BROADCASTMODE)

BroadcastMode = enum_type_wrapper.EnumTypeWrapper(_BROADCASTMODE)
ORDER_BY_UNSPECIFIED = 0
ORDER_BY_ASC = 1
ORDER_BY_DESC = 2
BROADCAST_MODE_UNSPECIFIED = 0
BROADCAST_MODE_BLOCK = 1
BROADCAST_MODE_SYNC = 2
BROADCAST_MODE_ASYNC = 3



_GETTXSEVENTREQUEST = _descriptor.Descriptor(
  name='GetTxsEventRequest',
  full_name='cosmos.tx.v1beta1.GetTxsEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='cosmos.tx.v1beta1.GetTxsEventRequest.events', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetTxsEventRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='cosmos.tx.v1beta1.GetTxsEventRequest.order_by', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=418,
)


_GETTXSEVENTRESPONSE = _descriptor.Descriptor(
  name='GetTxsEventResponse',
  full_name='cosmos.tx.v1beta1.GetTxsEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txs', full_name='cosmos.tx.v1beta1.GetTxsEventResponse.txs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_responses', full_name='cosmos.tx.v1beta1.GetTxsEventResponse.tx_responses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetTxsEventResponse.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=599,
)


_BROADCASTTXREQUEST = _descriptor.Descriptor(
  name='BroadcastTxRequest',
  full_name='cosmos.tx.v1beta1.BroadcastTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='cosmos.tx.v1beta1.BroadcastTxRequest.tx_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='cosmos.tx.v1beta1.BroadcastTxRequest.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=687,
)


_BROADCASTTXRESPONSE = _descriptor.Descriptor(
  name='BroadcastTxResponse',
  full_name='cosmos.tx.v1beta1.BroadcastTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_response', full_name='cosmos.tx.v1beta1.BroadcastTxResponse.tx_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=769,
)


_SIMULATEREQUEST = _descriptor.Descriptor(
  name='SimulateRequest',
  full_name='cosmos.tx.v1beta1.SimulateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.tx.v1beta1.SimulateRequest.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='cosmos.tx.v1beta1.SimulateRequest.tx_bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=845,
)


_SIMULATERESPONSE = _descriptor.Descriptor(
  name='SimulateResponse',
  full_name='cosmos.tx.v1beta1.SimulateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas_info', full_name='cosmos.tx.v1beta1.SimulateResponse.gas_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='cosmos.tx.v1beta1.SimulateResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=968,
)


_GETTXREQUEST = _descriptor.Descriptor(
  name='GetTxRequest',
  full_name='cosmos.tx.v1beta1.GetTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='cosmos.tx.v1beta1.GetTxRequest.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=998,
)


_GETTXRESPONSE = _descriptor.Descriptor(
  name='GetTxResponse',
  full_name='cosmos.tx.v1beta1.GetTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.tx.v1beta1.GetTxResponse.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_response', full_name='cosmos.tx.v1beta1.GetTxResponse.tx_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1109,
)


_GETBLOCKWITHTXSREQUEST = _descriptor.Descriptor(
  name='GetBlockWithTxsRequest',
  full_name='cosmos.tx.v1beta1.GetBlockWithTxsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.tx.v1beta1.GetBlockWithTxsRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetBlockWithTxsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1211,
)


_GETBLOCKWITHTXSRESPONSE = _descriptor.Descriptor(
  name='GetBlockWithTxsResponse',
  full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txs', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.txs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.block_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.block', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.tx.v1beta1.GetBlockWithTxsResponse.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1421,
)

_GETTXSEVENTREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_GETTXSEVENTREQUEST.fields_by_name['order_by'].enum_type = _ORDERBY
_GETTXSEVENTRESPONSE.fields_by_name['txs'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_GETTXSEVENTRESPONSE.fields_by_name['tx_responses'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._TXRESPONSE
_GETTXSEVENTRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_BROADCASTTXREQUEST.fields_by_name['mode'].enum_type = _BROADCASTMODE
_BROADCASTTXRESPONSE.fields_by_name['tx_response'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._TXRESPONSE
_SIMULATEREQUEST.fields_by_name['tx'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_SIMULATERESPONSE.fields_by_name['gas_info'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._GASINFO
_SIMULATERESPONSE.fields_by_name['result'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._RESULT
_GETTXRESPONSE.fields_by_name['tx'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_GETTXRESPONSE.fields_by_name['tx_response'].message_type = cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2._TXRESPONSE
_GETBLOCKWITHTXSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_GETBLOCKWITHTXSRESPONSE.fields_by_name['txs'].message_type = cosmos_dot_tx_dot_v1beta1_dot_tx__pb2._TX
_GETBLOCKWITHTXSRESPONSE.fields_by_name['block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_GETBLOCKWITHTXSRESPONSE.fields_by_name['block'].message_type = tendermint_dot_types_dot_block__pb2._BLOCK
_GETBLOCKWITHTXSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
DESCRIPTOR.message_types_by_name['GetTxsEventRequest'] = _GETTXSEVENTREQUEST
DESCRIPTOR.message_types_by_name['GetTxsEventResponse'] = _GETTXSEVENTRESPONSE
DESCRIPTOR.message_types_by_name['BroadcastTxRequest'] = _BROADCASTTXREQUEST
DESCRIPTOR.message_types_by_name['BroadcastTxResponse'] = _BROADCASTTXRESPONSE
DESCRIPTOR.message_types_by_name['SimulateRequest'] = _SIMULATEREQUEST
DESCRIPTOR.message_types_by_name['SimulateResponse'] = _SIMULATERESPONSE
DESCRIPTOR.message_types_by_name['GetTxRequest'] = _GETTXREQUEST
DESCRIPTOR.message_types_by_name['GetTxResponse'] = _GETTXRESPONSE
DESCRIPTOR.message_types_by_name['GetBlockWithTxsRequest'] = _GETBLOCKWITHTXSREQUEST
DESCRIPTOR.message_types_by_name['GetBlockWithTxsResponse'] = _GETBLOCKWITHTXSRESPONSE
DESCRIPTOR.enum_types_by_name['OrderBy'] = _ORDERBY
DESCRIPTOR.enum_types_by_name['BroadcastMode'] = _BROADCASTMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTxsEventRequest = _reflection.GeneratedProtocolMessageType('GetTxsEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSEVENTREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxsEventRequest)
  })
_sym_db.RegisterMessage(GetTxsEventRequest)

GetTxsEventResponse = _reflection.GeneratedProtocolMessageType('GetTxsEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSEVENTRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxsEventResponse)
  })
_sym_db.RegisterMessage(GetTxsEventResponse)

BroadcastTxRequest = _reflection.GeneratedProtocolMessageType('BroadcastTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTXREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.BroadcastTxRequest)
  })
_sym_db.RegisterMessage(BroadcastTxRequest)

BroadcastTxResponse = _reflection.GeneratedProtocolMessageType('BroadcastTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTXRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.BroadcastTxResponse)
  })
_sym_db.RegisterMessage(BroadcastTxResponse)

SimulateRequest = _reflection.GeneratedProtocolMessageType('SimulateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SimulateRequest)
  })
_sym_db.RegisterMessage(SimulateRequest)

SimulateResponse = _reflection.GeneratedProtocolMessageType('SimulateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATERESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SimulateResponse)
  })
_sym_db.RegisterMessage(SimulateResponse)

GetTxRequest = _reflection.GeneratedProtocolMessageType('GetTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxRequest)
  })
_sym_db.RegisterMessage(GetTxRequest)

GetTxResponse = _reflection.GeneratedProtocolMessageType('GetTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxResponse)
  })
_sym_db.RegisterMessage(GetTxResponse)

GetBlockWithTxsRequest = _reflection.GeneratedProtocolMessageType('GetBlockWithTxsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKWITHTXSREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetBlockWithTxsRequest)
  })
_sym_db.RegisterMessage(GetBlockWithTxsRequest)

GetBlockWithTxsResponse = _reflection.GeneratedProtocolMessageType('GetBlockWithTxsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKWITHTXSRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetBlockWithTxsResponse)
  })
_sym_db.RegisterMessage(GetBlockWithTxsResponse)


DESCRIPTOR._options = None
_SIMULATEREQUEST.fields_by_name['tx']._options = None

_SERVICE = _descriptor.ServiceDescriptor(
  name='Service',
  full_name='cosmos.tx.v1beta1.Service',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1624,
  serialized_end=2282,
  methods=[
  _descriptor.MethodDescriptor(
    name='Simulate',
    full_name='cosmos.tx.v1beta1.Service.Simulate',
    index=0,
    containing_service=None,
    input_type=_SIMULATEREQUEST,
    output_type=_SIMULATERESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\033/cosmos/tx/v1beta1/simulate:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTx',
    full_name='cosmos.tx.v1beta1.Service.GetTx',
    index=1,
    containing_service=None,
    input_type=_GETTXREQUEST,
    output_type=_GETTXRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/cosmos/tx/v1beta1/txs/{hash}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BroadcastTx',
    full_name='cosmos.tx.v1beta1.Service.BroadcastTx',
    index=2,
    containing_service=None,
    input_type=_BROADCASTTXREQUEST,
    output_type=_BROADCASTTXRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\026/cosmos/tx/v1beta1/txs:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxsEvent',
    full_name='cosmos.tx.v1beta1.Service.GetTxsEvent',
    index=3,
    containing_service=None,
    input_type=_GETTXSEVENTREQUEST,
    output_type=_GETTXSEVENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/cosmos/tx/v1beta1/txs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockWithTxs',
    full_name='cosmos.tx.v1beta1.Service.GetBlockWithTxs',
    index=4,
    containing_service=None,
    input_type=_GETBLOCKWITHTXSREQUEST,
    output_type=_GETBLOCKWITHTXSRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/cosmos/tx/v1beta1/txs/block/{height}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICE)

DESCRIPTOR.services_by_name['Service'] = _SERVICE

# @@protoc_insertion_point(module_scope)
