# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/rpc/grpc/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/rpc/grpc/types.proto',
  package='tendermint.rpc.grpc',
  syntax='proto3',
  serialized_options=b'Z2github.com/tendermint/tendermint/rpc/grpc;coregrpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ftendermint/rpc/grpc/types.proto\x12\x13tendermint.rpc.grpc\x1a\x1btendermint/abci/types.proto\"\r\n\x0bRequestPing\" \n\x12RequestBroadcastTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"\x0e\n\x0cResponsePing\"\x81\x01\n\x13ResponseBroadcastTx\x12\x32\n\x08\x63heck_tx\x18\x01 \x01(\x0b\x32 .tendermint.abci.ResponseCheckTx\x12\x36\n\ndeliver_tx\x18\x02 \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTx2\xbd\x01\n\x0c\x42roadcastAPI\x12K\n\x04Ping\x12 .tendermint.rpc.grpc.RequestPing\x1a!.tendermint.rpc.grpc.ResponsePing\x12`\n\x0b\x42roadcastTx\x12\'.tendermint.rpc.grpc.RequestBroadcastTx\x1a(.tendermint.rpc.grpc.ResponseBroadcastTxB4Z2github.com/tendermint/tendermint/rpc/grpc;coregrpcb\x06proto3'
  ,
  dependencies=[tendermint_dot_abci_dot_types__pb2.DESCRIPTOR,])




_REQUESTPING = _descriptor.Descriptor(
  name='RequestPing',
  full_name='tendermint.rpc.grpc.RequestPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=98,
)


_REQUESTBROADCASTTX = _descriptor.Descriptor(
  name='RequestBroadcastTx',
  full_name='tendermint.rpc.grpc.RequestBroadcastTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='tendermint.rpc.grpc.RequestBroadcastTx.tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=132,
)


_RESPONSEPING = _descriptor.Descriptor(
  name='ResponsePing',
  full_name='tendermint.rpc.grpc.ResponsePing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=148,
)


_RESPONSEBROADCASTTX = _descriptor.Descriptor(
  name='ResponseBroadcastTx',
  full_name='tendermint.rpc.grpc.ResponseBroadcastTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='check_tx', full_name='tendermint.rpc.grpc.ResponseBroadcastTx.check_tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deliver_tx', full_name='tendermint.rpc.grpc.ResponseBroadcastTx.deliver_tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=280,
)

_RESPONSEBROADCASTTX.fields_by_name['check_tx'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSECHECKTX
_RESPONSEBROADCASTTX.fields_by_name['deliver_tx'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name['RequestPing'] = _REQUESTPING
DESCRIPTOR.message_types_by_name['RequestBroadcastTx'] = _REQUESTBROADCASTTX
DESCRIPTOR.message_types_by_name['ResponsePing'] = _RESPONSEPING
DESCRIPTOR.message_types_by_name['ResponseBroadcastTx'] = _RESPONSEBROADCASTTX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestPing = _reflection.GeneratedProtocolMessageType('RequestPing', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPING,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.RequestPing)
  })
_sym_db.RegisterMessage(RequestPing)

RequestBroadcastTx = _reflection.GeneratedProtocolMessageType('RequestBroadcastTx', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBROADCASTTX,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.RequestBroadcastTx)
  })
_sym_db.RegisterMessage(RequestBroadcastTx)

ResponsePing = _reflection.GeneratedProtocolMessageType('ResponsePing', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEPING,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.ResponsePing)
  })
_sym_db.RegisterMessage(ResponsePing)

ResponseBroadcastTx = _reflection.GeneratedProtocolMessageType('ResponseBroadcastTx', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEBROADCASTTX,
  '__module__' : 'tendermint.rpc.grpc.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.rpc.grpc.ResponseBroadcastTx)
  })
_sym_db.RegisterMessage(ResponseBroadcastTx)


DESCRIPTOR._options = None

_BROADCASTAPI = _descriptor.ServiceDescriptor(
  name='BroadcastAPI',
  full_name='tendermint.rpc.grpc.BroadcastAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=283,
  serialized_end=472,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='tendermint.rpc.grpc.BroadcastAPI.Ping',
    index=0,
    containing_service=None,
    input_type=_REQUESTPING,
    output_type=_RESPONSEPING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BroadcastTx',
    full_name='tendermint.rpc.grpc.BroadcastAPI.BroadcastTx',
    index=1,
    containing_service=None,
    input_type=_REQUESTBROADCASTTX,
    output_type=_RESPONSEBROADCASTTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROADCASTAPI)

DESCRIPTOR.services_by_name['BroadcastAPI'] = _BROADCASTAPI

# @@protoc_insertion_point(module_scope)
