# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/staking/v1beta1/query.proto',
  package='cosmos.staking.v1beta1',
  syntax='proto3',
  serialized_options=b'Z,github.com/cosmos/cosmos-sdk/x/staking/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"cosmos/staking/v1beta1/query.proto\x12\x16\x63osmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto\"d\n\x16QueryValidatorsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x17QueryValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"/\n\x15QueryValidatorRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\"T\n\x16QueryValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\"v\n QueryValidatorDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xc7\x01\n!QueryValidatorDelegationsResponse\x12\x65\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x1b\xc8\xde\x1f\x00\xaa\xdf\x1f\x13\x44\x65legationResponses\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n)QueryValidatorUnbondingDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb9\x01\n*QueryValidatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"R\n\x16QueryDelegationRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"b\n\x17QueryDelegationResponse\x12G\n\x13\x64\x65legation_response\x18\x01 \x01(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponse\"[\n\x1fQueryUnbondingDelegationRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"e\n QueryUnbondingDelegationResponse\x12\x41\n\x06unbond\x18\x01 \x01(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\"\x80\x01\n QueryDelegatorDelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb0\x01\n!QueryDelegatorDelegationsResponse\x12N\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb9\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xb1\x01\n\x19QueryRedelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x1a\n\x12src_validator_addr\x18\x02 \x01(\t\x12\x1a\n\x12\x64st_validator_addr\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xad\x01\n\x1aQueryRedelegationsResponse\x12R\n\x16redelegation_responses\x18\x01 \x03(\x0b\x32,.cosmos.staking.v1beta1.RedelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n\x1fQueryDelegatorValidatorsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x9c\x01\n QueryDelegatorValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x1eQueryDelegatorValidatorRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"]\n\x1fQueryDelegatorValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\",\n\x1aQueryHistoricalInfoRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"S\n\x1bQueryHistoricalInfoResponse\x12\x34\n\x04hist\x18\x01 \x01(\x0b\x32&.cosmos.staking.v1beta1.HistoricalInfo\"\x12\n\x10QueryPoolRequest\"E\n\x11QueryPoolResponse\x12\x30\n\x04pool\x18\x01 \x01(\x0b\x32\x1c.cosmos.staking.v1beta1.PoolB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"K\n\x13QueryParamsResponse\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x32\xea\x15\n\x05Query\x12\x99\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/cosmos/staking/v1beta1/validators\x12\xa7\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd4\x01\n\x14ValidatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xf9\x01\n\x1dValidatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xc7\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse\"X\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xf7\x01\n\x13UnbondingDelegation\x12\x37.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a\x38.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse\"m\x82\xd3\xe4\x93\x02g\x12\x65/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xc9\x01\n\x14\x44\x65legatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xf9\x01\n\x1d\x44\x65legatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc1\x01\n\rRedelegations\x12\x31.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a\x32.cosmos.staking.v1beta1.QueryRedelegationsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd0\x01\n\x13\x44\x65legatorValidators\x12\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a\x38.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xde\x01\n\x12\x44\x65legatorValidator\x12\x36.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\xb3\x01\n\x0eHistoricalInfo\x12\x32.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a\x33.cosmos.staking.v1beta1.QueryHistoricalInfoResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/staking/v1beta1/historical_info/{height}\x12\x81\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x89\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3'
  ,
  dependencies=[cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,cosmos_dot_staking_dot_v1beta1_dot_staking__pb2.DESCRIPTOR,])




_QUERYVALIDATORSREQUEST = _descriptor.Descriptor(
  name='QueryValidatorsRequest',
  full_name='cosmos.staking.v1beta1.QueryValidatorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='cosmos.staking.v1beta1.QueryValidatorsRequest.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryValidatorsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=296,
)


_QUERYVALIDATORSRESPONSE = _descriptor.Descriptor(
  name='QueryValidatorsResponse',
  full_name='cosmos.staking.v1beta1.QueryValidatorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validators', full_name='cosmos.staking.v1beta1.QueryValidatorsResponse.validators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryValidatorsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=446,
)


_QUERYVALIDATORREQUEST = _descriptor.Descriptor(
  name='QueryValidatorRequest',
  full_name='cosmos.staking.v1beta1.QueryValidatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_addr', full_name='cosmos.staking.v1beta1.QueryValidatorRequest.validator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=495,
)


_QUERYVALIDATORRESPONSE = _descriptor.Descriptor(
  name='QueryValidatorResponse',
  full_name='cosmos.staking.v1beta1.QueryValidatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='cosmos.staking.v1beta1.QueryValidatorResponse.validator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=581,
)


_QUERYVALIDATORDELEGATIONSREQUEST = _descriptor.Descriptor(
  name='QueryValidatorDelegationsRequest',
  full_name='cosmos.staking.v1beta1.QueryValidatorDelegationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_addr', full_name='cosmos.staking.v1beta1.QueryValidatorDelegationsRequest.validator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryValidatorDelegationsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=701,
)


_QUERYVALIDATORDELEGATIONSRESPONSE = _descriptor.Descriptor(
  name='QueryValidatorDelegationsResponse',
  full_name='cosmos.staking.v1beta1.QueryValidatorDelegationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegation_responses', full_name='cosmos.staking.v1beta1.QueryValidatorDelegationsResponse.delegation_responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037\023DelegationResponses', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryValidatorDelegationsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=903,
)


_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST = _descriptor.Descriptor(
  name='QueryValidatorUnbondingDelegationsRequest',
  full_name='cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_addr', full_name='cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest.validator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=1032,
)


_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE = _descriptor.Descriptor(
  name='QueryValidatorUnbondingDelegationsResponse',
  full_name='cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unbonding_responses', full_name='cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse.unbonding_responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1220,
)


_QUERYDELEGATIONREQUEST = _descriptor.Descriptor(
  name='QueryDelegationRequest',
  full_name='cosmos.staking.v1beta1.QueryDelegationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryDelegationRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_addr', full_name='cosmos.staking.v1beta1.QueryDelegationRequest.validator_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1304,
)


_QUERYDELEGATIONRESPONSE = _descriptor.Descriptor(
  name='QueryDelegationResponse',
  full_name='cosmos.staking.v1beta1.QueryDelegationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegation_response', full_name='cosmos.staking.v1beta1.QueryDelegationResponse.delegation_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1306,
  serialized_end=1404,
)


_QUERYUNBONDINGDELEGATIONREQUEST = _descriptor.Descriptor(
  name='QueryUnbondingDelegationRequest',
  full_name='cosmos.staking.v1beta1.QueryUnbondingDelegationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryUnbondingDelegationRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_addr', full_name='cosmos.staking.v1beta1.QueryUnbondingDelegationRequest.validator_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1406,
  serialized_end=1497,
)


_QUERYUNBONDINGDELEGATIONRESPONSE = _descriptor.Descriptor(
  name='QueryUnbondingDelegationResponse',
  full_name='cosmos.staking.v1beta1.QueryUnbondingDelegationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unbond', full_name='cosmos.staking.v1beta1.QueryUnbondingDelegationResponse.unbond', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1499,
  serialized_end=1600,
)


_QUERYDELEGATORDELEGATIONSREQUEST = _descriptor.Descriptor(
  name='QueryDelegatorDelegationsRequest',
  full_name='cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1603,
  serialized_end=1731,
)


_QUERYDELEGATORDELEGATIONSRESPONSE = _descriptor.Descriptor(
  name='QueryDelegatorDelegationsResponse',
  full_name='cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegation_responses', full_name='cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse.delegation_responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1734,
  serialized_end=1910,
)


_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST = _descriptor.Descriptor(
  name='QueryDelegatorUnbondingDelegationsRequest',
  full_name='cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1913,
  serialized_end=2050,
)


_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE = _descriptor.Descriptor(
  name='QueryDelegatorUnbondingDelegationsResponse',
  full_name='cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unbonding_responses', full_name='cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse.unbonding_responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2238,
)


_QUERYREDELEGATIONSREQUEST = _descriptor.Descriptor(
  name='QueryRedelegationsRequest',
  full_name='cosmos.staking.v1beta1.QueryRedelegationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryRedelegationsRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_validator_addr', full_name='cosmos.staking.v1beta1.QueryRedelegationsRequest.src_validator_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_validator_addr', full_name='cosmos.staking.v1beta1.QueryRedelegationsRequest.dst_validator_addr', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryRedelegationsRequest.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2241,
  serialized_end=2418,
)


_QUERYREDELEGATIONSRESPONSE = _descriptor.Descriptor(
  name='QueryRedelegationsResponse',
  full_name='cosmos.staking.v1beta1.QueryRedelegationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redelegation_responses', full_name='cosmos.staking.v1beta1.QueryRedelegationsResponse.redelegation_responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryRedelegationsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2421,
  serialized_end=2594,
)


_QUERYDELEGATORVALIDATORSREQUEST = _descriptor.Descriptor(
  name='QueryDelegatorValidatorsRequest',
  full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2596,
  serialized_end=2723,
)


_QUERYDELEGATORVALIDATORSRESPONSE = _descriptor.Descriptor(
  name='QueryDelegatorValidatorsResponse',
  full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validators', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse.validators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2882,
)


_QUERYDELEGATORVALIDATORREQUEST = _descriptor.Descriptor(
  name='QueryDelegatorValidatorRequest',
  full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_addr', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorRequest.delegator_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_addr', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorRequest.validator_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2884,
  serialized_end=2974,
)


_QUERYDELEGATORVALIDATORRESPONSE = _descriptor.Descriptor(
  name='QueryDelegatorValidatorResponse',
  full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='cosmos.staking.v1beta1.QueryDelegatorValidatorResponse.validator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2976,
  serialized_end=3069,
)


_QUERYHISTORICALINFOREQUEST = _descriptor.Descriptor(
  name='QueryHistoricalInfoRequest',
  full_name='cosmos.staking.v1beta1.QueryHistoricalInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='cosmos.staking.v1beta1.QueryHistoricalInfoRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3071,
  serialized_end=3115,
)


_QUERYHISTORICALINFORESPONSE = _descriptor.Descriptor(
  name='QueryHistoricalInfoResponse',
  full_name='cosmos.staking.v1beta1.QueryHistoricalInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hist', full_name='cosmos.staking.v1beta1.QueryHistoricalInfoResponse.hist', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3117,
  serialized_end=3200,
)


_QUERYPOOLREQUEST = _descriptor.Descriptor(
  name='QueryPoolRequest',
  full_name='cosmos.staking.v1beta1.QueryPoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3202,
  serialized_end=3220,
)


_QUERYPOOLRESPONSE = _descriptor.Descriptor(
  name='QueryPoolResponse',
  full_name='cosmos.staking.v1beta1.QueryPoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pool', full_name='cosmos.staking.v1beta1.QueryPoolResponse.pool', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3222,
  serialized_end=3291,
)


_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='cosmos.staking.v1beta1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3293,
  serialized_end=3313,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='cosmos.staking.v1beta1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='cosmos.staking.v1beta1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3315,
  serialized_end=3390,
)

_QUERYVALIDATORSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYVALIDATORSRESPONSE.fields_by_name['validators'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._VALIDATOR
_QUERYVALIDATORSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYVALIDATORRESPONSE.fields_by_name['validator'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._VALIDATOR
_QUERYVALIDATORDELEGATIONSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._DELEGATIONRESPONSE
_QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._UNBONDINGDELEGATION
_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYDELEGATIONRESPONSE.fields_by_name['delegation_response'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._DELEGATIONRESPONSE
_QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._UNBONDINGDELEGATION
_QUERYDELEGATORDELEGATIONSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._DELEGATIONRESPONSE
_QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._UNBONDINGDELEGATION
_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYREDELEGATIONSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._REDELEGATIONRESPONSE
_QUERYREDELEGATIONSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYDELEGATORVALIDATORSREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._VALIDATOR
_QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._VALIDATOR
_QUERYHISTORICALINFORESPONSE.fields_by_name['hist'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._HISTORICALINFO
_QUERYPOOLRESPONSE.fields_by_name['pool'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._POOL
_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = cosmos_dot_staking_dot_v1beta1_dot_staking__pb2._PARAMS
DESCRIPTOR.message_types_by_name['QueryValidatorsRequest'] = _QUERYVALIDATORSREQUEST
DESCRIPTOR.message_types_by_name['QueryValidatorsResponse'] = _QUERYVALIDATORSRESPONSE
DESCRIPTOR.message_types_by_name['QueryValidatorRequest'] = _QUERYVALIDATORREQUEST
DESCRIPTOR.message_types_by_name['QueryValidatorResponse'] = _QUERYVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name['QueryValidatorDelegationsRequest'] = _QUERYVALIDATORDELEGATIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryValidatorDelegationsResponse'] = _QUERYVALIDATORDELEGATIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryValidatorUnbondingDelegationsRequest'] = _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryValidatorUnbondingDelegationsResponse'] = _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegationRequest'] = _QUERYDELEGATIONREQUEST
DESCRIPTOR.message_types_by_name['QueryDelegationResponse'] = _QUERYDELEGATIONRESPONSE
DESCRIPTOR.message_types_by_name['QueryUnbondingDelegationRequest'] = _QUERYUNBONDINGDELEGATIONREQUEST
DESCRIPTOR.message_types_by_name['QueryUnbondingDelegationResponse'] = _QUERYUNBONDINGDELEGATIONRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegatorDelegationsRequest'] = _QUERYDELEGATORDELEGATIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryDelegatorDelegationsResponse'] = _QUERYDELEGATORDELEGATIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegatorUnbondingDelegationsRequest'] = _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryDelegatorUnbondingDelegationsResponse'] = _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryRedelegationsRequest'] = _QUERYREDELEGATIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryRedelegationsResponse'] = _QUERYREDELEGATIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorsRequest'] = _QUERYDELEGATORVALIDATORSREQUEST
DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorsResponse'] = _QUERYDELEGATORVALIDATORSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorRequest'] = _QUERYDELEGATORVALIDATORREQUEST
DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorResponse'] = _QUERYDELEGATORVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name['QueryHistoricalInfoRequest'] = _QUERYHISTORICALINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryHistoricalInfoResponse'] = _QUERYHISTORICALINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryPoolRequest'] = _QUERYPOOLREQUEST
DESCRIPTOR.message_types_by_name['QueryPoolResponse'] = _QUERYPOOLRESPONSE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryValidatorsRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorsRequest)
  })
_sym_db.RegisterMessage(QueryValidatorsRequest)

QueryValidatorsResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorsResponse)
  })
_sym_db.RegisterMessage(QueryValidatorsResponse)

QueryValidatorRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorRequest)
  })
_sym_db.RegisterMessage(QueryValidatorRequest)

QueryValidatorResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorResponse)
  })
_sym_db.RegisterMessage(QueryValidatorResponse)

QueryValidatorDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryValidatorDelegationsRequest)

QueryValidatorDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryValidatorDelegationsResponse)

QueryValidatorUnbondingDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorUnbondingDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryValidatorUnbondingDelegationsRequest)

QueryValidatorUnbondingDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorUnbondingDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryValidatorUnbondingDelegationsResponse)

QueryDelegationRequest = _reflection.GeneratedProtocolMessageType('QueryDelegationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATIONREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegationRequest)
  })
_sym_db.RegisterMessage(QueryDelegationRequest)

QueryDelegationResponse = _reflection.GeneratedProtocolMessageType('QueryDelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATIONRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegationResponse)
  })
_sym_db.RegisterMessage(QueryDelegationResponse)

QueryUnbondingDelegationRequest = _reflection.GeneratedProtocolMessageType('QueryUnbondingDelegationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYUNBONDINGDELEGATIONREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryUnbondingDelegationRequest)
  })
_sym_db.RegisterMessage(QueryUnbondingDelegationRequest)

QueryUnbondingDelegationResponse = _reflection.GeneratedProtocolMessageType('QueryUnbondingDelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYUNBONDINGDELEGATIONRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryUnbondingDelegationResponse)
  })
_sym_db.RegisterMessage(QueryUnbondingDelegationResponse)

QueryDelegatorDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorDelegationsRequest)

QueryDelegatorDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorDelegationsResponse)

QueryDelegatorUnbondingDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorUnbondingDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorUnbondingDelegationsRequest)

QueryDelegatorUnbondingDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorUnbondingDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorUnbondingDelegationsResponse)

QueryRedelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryRedelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryRedelegationsRequest)
  })
_sym_db.RegisterMessage(QueryRedelegationsRequest)

QueryRedelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryRedelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryRedelegationsResponse)
  })
_sym_db.RegisterMessage(QueryRedelegationsResponse)

QueryDelegatorValidatorsRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorsRequest)

QueryDelegatorValidatorsResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorsResponse)

QueryDelegatorValidatorRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorRequest)

QueryDelegatorValidatorResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorResponse)

QueryHistoricalInfoRequest = _reflection.GeneratedProtocolMessageType('QueryHistoricalInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALINFOREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryHistoricalInfoRequest)
  })
_sym_db.RegisterMessage(QueryHistoricalInfoRequest)

QueryHistoricalInfoResponse = _reflection.GeneratedProtocolMessageType('QueryHistoricalInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALINFORESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryHistoricalInfoResponse)
  })
_sym_db.RegisterMessage(QueryHistoricalInfoResponse)

QueryPoolRequest = _reflection.GeneratedProtocolMessageType('QueryPoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryPoolRequest)
  })
_sym_db.RegisterMessage(QueryPoolRequest)

QueryPoolResponse = _reflection.GeneratedProtocolMessageType('QueryPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryPoolResponse)
  })
_sym_db.RegisterMessage(QueryPoolResponse)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)


DESCRIPTOR._options = None
_QUERYVALIDATORSRESPONSE.fields_by_name['validators']._options = None
_QUERYVALIDATORRESPONSE.fields_by_name['validator']._options = None
_QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
_QUERYDELEGATIONREQUEST._options = None
_QUERYUNBONDINGDELEGATIONREQUEST._options = None
_QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._options = None
_QUERYDELEGATORDELEGATIONSREQUEST._options = None
_QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._options = None
_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
_QUERYREDELEGATIONSREQUEST._options = None
_QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._options = None
_QUERYDELEGATORVALIDATORSREQUEST._options = None
_QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._options = None
_QUERYDELEGATORVALIDATORREQUEST._options = None
_QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._options = None
_QUERYPOOLRESPONSE.fields_by_name['pool']._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='cosmos.staking.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3393,
  serialized_end=6187,
  methods=[
  _descriptor.MethodDescriptor(
    name='Validators',
    full_name='cosmos.staking.v1beta1.Query.Validators',
    index=0,
    containing_service=None,
    input_type=_QUERYVALIDATORSREQUEST,
    output_type=_QUERYVALIDATORSRESPONSE,
    serialized_options=b'\202\323\344\223\002$\022\"/cosmos/staking/v1beta1/validators',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Validator',
    full_name='cosmos.staking.v1beta1.Query.Validator',
    index=1,
    containing_service=None,
    input_type=_QUERYVALIDATORREQUEST,
    output_type=_QUERYVALIDATORRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/cosmos/staking/v1beta1/validators/{validator_addr}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidatorDelegations',
    full_name='cosmos.staking.v1beta1.Query.ValidatorDelegations',
    index=2,
    containing_service=None,
    input_type=_QUERYVALIDATORDELEGATIONSREQUEST,
    output_type=_QUERYVALIDATORDELEGATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidatorUnbondingDelegations',
    full_name='cosmos.staking.v1beta1.Query.ValidatorUnbondingDelegations',
    index=3,
    containing_service=None,
    input_type=_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST,
    output_type=_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002K\022I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delegation',
    full_name='cosmos.staking.v1beta1.Query.Delegation',
    index=4,
    containing_service=None,
    input_type=_QUERYDELEGATIONREQUEST,
    output_type=_QUERYDELEGATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002R\022P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnbondingDelegation',
    full_name='cosmos.staking.v1beta1.Query.UnbondingDelegation',
    index=5,
    containing_service=None,
    input_type=_QUERYUNBONDINGDELEGATIONREQUEST,
    output_type=_QUERYUNBONDINGDELEGATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002g\022e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DelegatorDelegations',
    full_name='cosmos.staking.v1beta1.Query.DelegatorDelegations',
    index=6,
    containing_service=None,
    input_type=_QUERYDELEGATORDELEGATIONSREQUEST,
    output_type=_QUERYDELEGATORDELEGATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/staking/v1beta1/delegations/{delegator_addr}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DelegatorUnbondingDelegations',
    full_name='cosmos.staking.v1beta1.Query.DelegatorUnbondingDelegations',
    index=7,
    containing_service=None,
    input_type=_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST,
    output_type=_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002K\022I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Redelegations',
    full_name='cosmos.staking.v1beta1.Query.Redelegations',
    index=8,
    containing_service=None,
    input_type=_QUERYREDELEGATIONSREQUEST,
    output_type=_QUERYREDELEGATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DelegatorValidators',
    full_name='cosmos.staking.v1beta1.Query.DelegatorValidators',
    index=9,
    containing_service=None,
    input_type=_QUERYDELEGATORVALIDATORSREQUEST,
    output_type=_QUERYDELEGATORVALIDATORSRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DelegatorValidator',
    full_name='cosmos.staking.v1beta1.Query.DelegatorValidator',
    index=10,
    containing_service=None,
    input_type=_QUERYDELEGATORVALIDATORREQUEST,
    output_type=_QUERYDELEGATORVALIDATORRESPONSE,
    serialized_options=b'\202\323\344\223\002Q\022O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HistoricalInfo',
    full_name='cosmos.staking.v1beta1.Query.HistoricalInfo',
    index=11,
    containing_service=None,
    input_type=_QUERYHISTORICALINFOREQUEST,
    output_type=_QUERYHISTORICALINFORESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/cosmos/staking/v1beta1/historical_info/{height}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Pool',
    full_name='cosmos.staking.v1beta1.Query.Pool',
    index=12,
    containing_service=None,
    input_type=_QUERYPOOLREQUEST,
    output_type=_QUERYPOOLRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/cosmos/staking/v1beta1/pool',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='cosmos.staking.v1beta1.Query.Params',
    index=13,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/cosmos/staking/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)
