# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/tx.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#injective/exchange/v1beta1/tx.proto\x12\x1ainjective.exchange.v1beta1\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\"n\n\nMsgDeposit\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x14\n\x12MsgDepositResponse\"o\n\x0bMsgWithdraw\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x15\n\x13MsgWithdrawResponse\"o\n\x17MsgCreateSpotLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"?\n\x1fMsgCreateSpotLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"v\n\x1dMsgBatchCreateSpotLimitOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12;\n\x06orders\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"G\n%MsgBatchCreateSpotLimitOrdersResponse\x12\x14\n\x0corder_hashes\x18\x01 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8c\x02\n\x1aMsgInstantSpotMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x12\n\nbase_denom\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12K\n\x13min_price_tick_size\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"$\n\"MsgInstantSpotMarketLaunchResponse\"\xb0\x05\n\x1fMsgInstantPerpetualMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x06 \x01(\r\x12\x39\n\x0boracle_type\x18\x07 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x46\n\x0emaker_fee_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14initial_margin_ratio\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\")\n\'MsgInstantPerpetualMarketLaunchResponse\"\xe4\x04\n#MsgInstantBinaryOptionsMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x15\n\roracle_symbol\x18\x03 \x01(\t\x12\x17\n\x0foracle_provider\x18\x04 \x01(\t\x12\x39\n\x0boracle_type\x18\x05 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x06 \x01(\r\x12\x46\n\x0emaker_fee_rate\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1c\n\x14\x65xpiration_timestamp\x18\t \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\n \x01(\x03\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x13\n\x0bquote_denom\x18\x0c \x01(\t\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"-\n+MsgInstantBinaryOptionsMarketLaunchResponse\"\xc4\x05\n#MsgInstantExpiryFuturesMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x0e\n\x06\x65xpiry\x18\x08 \x01(\x03\x12\x46\n\x0emaker_fee_rate\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14initial_margin_ratio\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"-\n+MsgInstantExpiryFuturesMarketLaunchResponse\"p\n\x18MsgCreateSpotMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"@\n MsgCreateSpotMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"w\n\x1dMsgCreateDerivativeLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"E\n%MsgCreateDerivativeLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"z\n MsgCreateBinaryOptionsLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"H\n(MsgCreateBinaryOptionsLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"~\n#MsgBatchCreateDerivativeLimitOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x41\n\x06orders\x18\x02 \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"M\n+MsgBatchCreateDerivativeLimitOrdersResponse\x12\x14\n\x0corder_hashes\x18\x01 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"h\n\x12MsgCancelSpotOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t:\x04\x88\xa0\x1f\x00\"\x1c\n\x1aMsgCancelSpotOrderResponse\"k\n\x18MsgBatchCancelSpotOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"=\n MsgBatchCancelSpotOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"t\n!MsgBatchCancelBinaryOptionsOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"F\n)MsgBatchCancelBinaryOptionsOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xbc\x05\n\x14MsgBatchUpdateOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12%\n\x1dspot_market_ids_to_cancel_all\x18\x03 \x03(\t\x12+\n#derivative_market_ids_to_cancel_all\x18\x04 \x03(\t\x12J\n\x15spot_orders_to_cancel\x18\x05 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12P\n\x1b\x64\x65rivative_orders_to_cancel\x18\x06 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12J\n\x15spot_orders_to_create\x18\x07 \x03(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x01\x12V\n\x1b\x64\x65rivative_orders_to_create\x18\x08 \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01\x12T\n\x1f\x62inary_options_orders_to_cancel\x18\t \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12/\n\'binary_options_market_ids_to_cancel_all\x18\n \x03(\t\x12Z\n\x1f\x62inary_options_orders_to_create\x18\x0b \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01:\x04\x88\xa0\x1f\x00\"\xf0\x01\n\x1cMsgBatchUpdateOrdersResponse\x12\x1b\n\x13spot_cancel_success\x18\x01 \x03(\x08\x12!\n\x19\x64\x65rivative_cancel_success\x18\x02 \x03(\x08\x12\x19\n\x11spot_order_hashes\x18\x03 \x03(\t\x12\x1f\n\x17\x64\x65rivative_order_hashes\x18\x04 \x03(\t\x12%\n\x1d\x62inary_options_cancel_success\x18\x05 \x03(\x08\x12#\n\x1b\x62inary_options_order_hashes\x18\x06 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"x\n\x1eMsgCreateDerivativeMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"F\n&MsgCreateDerivativeMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"{\n!MsgCreateBinaryOptionsMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"I\n)MsgCreateBinaryOptionsMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x82\x01\n\x18MsgCancelDerivativeOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x12\n\norder_mask\x18\x05 \x01(\x05:\x04\x88\xa0\x1f\x00\"\"\n MsgCancelDerivativeOrderResponse\"\x85\x01\n\x1bMsgCancelBinaryOptionsOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x12\n\norder_mask\x18\x05 \x01(\x05:\x04\x88\xa0\x1f\x00\"%\n#MsgCancelBinaryOptionsOrderResponse\"]\n\tOrderData\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x12\n\norder_hash\x18\x03 \x01(\t\x12\x12\n\norder_mask\x18\x04 \x01(\x05\"q\n\x1eMsgBatchCancelDerivativeOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"C\n&MsgBatchCancelDerivativeOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x99\x01\n\x15MsgSubaccountTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dMsgSubaccountTransferResponse\"\x97\x01\n\x13MsgExternalTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x1d\n\x1bMsgExternalTransferResponse\"\x92\x01\n\x14MsgLiquidatePosition\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12@\n\x05order\x18\x04 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01\"\x1e\n\x1cMsgLiquidatePositionResponse\"\xbf\x01\n\x19MsgIncreasePositionMargin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\t\x12>\n\x06\x61mount\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"#\n!MsgIncreasePositionMarginResponse\"\xb0\x02\n\x07MsgExec\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12_\n\nbank_funds\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x1e\n\x16\x64\x65posits_subaccount_id\x18\x03 \x01(\t\x12\x62\n\rdeposit_funds\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x18\n\x10\x63ontract_address\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x11\n\x0fMsgExecResponse\"\x97\x04\n\x1dSpotMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12K\n\x13min_price_tick_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16min_quantity_tick_size\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x38\n\x06status\x18\t \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x86\x01\n\x16\x45xchangeEnableProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12>\n\x0c\x65xchangeType\x18\x03 \x01(\x0e\x32(.injective.exchange.v1beta1.ExchangeType:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x91\x08\n!BatchExchangeModificationProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x65\n\"spot_market_param_update_proposals\x18\x03 \x03(\x0b\x32\x39.injective.exchange.v1beta1.SpotMarketParamUpdateProposal\x12q\n(derivative_market_param_update_proposals\x18\x04 \x03(\x0b\x32?.injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal\x12Z\n\x1cspot_market_launch_proposals\x18\x05 \x03(\x0b\x32\x34.injective.exchange.v1beta1.SpotMarketLaunchProposal\x12\x64\n!perpetual_market_launch_proposals\x18\x06 \x03(\x0b\x32\x39.injective.exchange.v1beta1.PerpetualMarketLaunchProposal\x12m\n&expiry_futures_market_launch_proposals\x18\x07 \x03(\x0b\x32=.injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal\x12p\n\'trading_reward_campaign_update_proposal\x18\x08 \x01(\x0b\x32?.injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal\x12m\n&binary_options_market_launch_proposals\x18\t \x03(\x0b\x32=.injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal\x12q\n%binary_options_param_update_proposals\x18\n \x03(\x0b\x32\x42.injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal\x12_\n\x1e\x64\x65nom_decimals_update_proposal\x18\x0b \x01(\x0b\x32\x37.injective.exchange.v1beta1.UpdateDenomDecimalsProposal:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xae\x03\n\x18SpotMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x12\n\nbase_denom\x18\x04 \x01(\t\x12\x13\n\x0bquote_denom\x18\x05 \x01(\t\x12K\n\x13min_price_tick_size\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xc2\x05\n\x1dPerpetualMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12\x13\n\x0boracle_base\x18\x05 \x01(\t\x12\x14\n\x0coracle_quote\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x39\n\x0boracle_type\x18\x08 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12L\n\x14initial_margin_ratio\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xf6\x04\n!BinaryOptionsMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x15\n\roracle_symbol\x18\x04 \x01(\t\x12\x17\n\x0foracle_provider\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x1c\n\x14\x65xpiration_timestamp\x18\x08 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\t \x01(\x03\x12\r\n\x05\x61\x64min\x18\n \x01(\t\x12\x13\n\x0bquote_denom\x18\x0b \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd6\x05\n!ExpiryFuturesMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12\x13\n\x0boracle_base\x18\x05 \x01(\t\x12\x14\n\x0coracle_quote\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x39\n\x0boracle_type\x18\x08 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\t \x01(\x03\x12L\n\x14initial_margin_ratio\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x98\x07\n#DerivativeMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12L\n\x14initial_margin_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12P\n\x18maintenance_margin_ratio\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0emaker_fee_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16relayer_fee_share_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12K\n\x13min_price_tick_size\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16min_quantity_tick_size\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12J\n\x12HourlyInterestRate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12L\n\x14HourlyFundingRateCap\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x38\n\x06status\x18\r \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12?\n\roracle_params\x18\x0e \x01(\x0b\x32(.injective.exchange.v1beta1.OracleParams:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xab\x01\n\x1eMarketForcedSettlementProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12H\n\x10settlement_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8e\x01\n\x1bUpdateDenomDecimalsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x0e\x64\x65nom_decimals\x18\x03 \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimals:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"0\n\rDenomDecimals\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x02 \x01(\x04\"\xfe\x05\n&BinaryOptionsMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12K\n\x13min_price_tick_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16min_quantity_tick_size\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x1c\n\x14\x65xpiration_timestamp\x18\t \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\n \x01(\x03\x12H\n\x10settlement_price\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\r\n\x05\x61\x64min\x18\x0c \x01(\t\x12\x38\n\x06status\x18\r \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12G\n\roracle_params\x18\x0e \x01(\x0b\x32\x30.injective.exchange.v1beta1.ProviderOracleParams:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x90\x01\n\x14ProviderOracleParams\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x03 \x01(\r\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\x91\x01\n\x0cOracleParams\x12\x13\n\x0boracle_base\x18\x01 \x01(\t\x12\x14\n\x0coracle_quote\x18\x02 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x03 \x01(\r\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\xf0\x01\n#TradingRewardCampaignLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\rcampaign_info\x18\x03 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12M\n\x15\x63\x61mpaign_reward_pools\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd1\x02\n#TradingRewardCampaignUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\rcampaign_info\x18\x03 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12W\n\x1f\x63\x61mpaign_reward_pools_additions\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12U\n\x1d\x63\x61mpaign_reward_pools_updates\x18\x05 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"p\n\x11RewardPointUpdate\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x42\n\nnew_points\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xc5\x01\n(TradingRewardPendingPointsUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16pending_pool_timestamp\x18\x03 \x01(\x03\x12K\n\x14reward_point_updates\x18\x04 \x03(\x0b\x32-.injective.exchange.v1beta1.RewardPointUpdate:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x86\x01\n\x13\x46\x65\x65\x44iscountProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x08schedule\x18\x03 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x9b\x01\n\x1f\x42\x61tchCommunityPoolSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12J\n\tproposals\x18\x03 \x03(\x0b\x32\x37.cosmos.distribution.v1beta1.CommunityPoolSpendProposal:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n\x10MsgRewardsOptOut\x12\x0e\n\x06sender\x18\x01 \x01(\t\"\x1a\n\x18MsgRewardsOptOutResponse\"\x86\x02\n!MsgAdminUpdateBinaryOptionsMarket\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12H\n\x10settlement_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x1c\n\x14\x65xpiration_timestamp\x18\x04 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\x05 \x01(\x03\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\"+\n)MsgAdminUpdateBinaryOptionsMarketResponse*x\n\x0c\x45xchangeType\x12\x32\n\x14\x45XCHANGE_UNSPECIFIED\x10\x00\x1a\x18\x8a\x9d \x14\x45XCHANGE_UNSPECIFIED\x12\x12\n\x04SPOT\x10\x01\x1a\x08\x8a\x9d \x04SPOT\x12 \n\x0b\x44\x45RIVATIVES\x10\x02\x1a\x0f\x8a\x9d \x0b\x44\x45RIVATIVES2\xd9\x1f\n\x03Msg\x12\x61\n\x07\x44\x65posit\x12&.injective.exchange.v1beta1.MsgDeposit\x1a..injective.exchange.v1beta1.MsgDepositResponse\x12\x64\n\x08Withdraw\x12\'.injective.exchange.v1beta1.MsgWithdraw\x1a/.injective.exchange.v1beta1.MsgWithdrawResponse\x12\x91\x01\n\x17InstantSpotMarketLaunch\x12\x36.injective.exchange.v1beta1.MsgInstantSpotMarketLaunch\x1a>.injective.exchange.v1beta1.MsgInstantSpotMarketLaunchResponse\x12\xa0\x01\n\x1cInstantPerpetualMarketLaunch\x12;.injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch\x1a\x43.injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunchResponse\x12\xac\x01\n InstantExpiryFuturesMarketLaunch\x12?.injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch\x1aG.injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunchResponse\x12\x88\x01\n\x14\x43reateSpotLimitOrder\x12\x33.injective.exchange.v1beta1.MsgCreateSpotLimitOrder\x1a;.injective.exchange.v1beta1.MsgCreateSpotLimitOrderResponse\x12\x9a\x01\n\x1a\x42\x61tchCreateSpotLimitOrders\x12\x39.injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders\x1a\x41.injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrdersResponse\x12\x8b\x01\n\x15\x43reateSpotMarketOrder\x12\x34.injective.exchange.v1beta1.MsgCreateSpotMarketOrder\x1a<.injective.exchange.v1beta1.MsgCreateSpotMarketOrderResponse\x12y\n\x0f\x43\x61ncelSpotOrder\x12..injective.exchange.v1beta1.MsgCancelSpotOrder\x1a\x36.injective.exchange.v1beta1.MsgCancelSpotOrderResponse\x12\x8b\x01\n\x15\x42\x61tchCancelSpotOrders\x12\x34.injective.exchange.v1beta1.MsgBatchCancelSpotOrders\x1a<.injective.exchange.v1beta1.MsgBatchCancelSpotOrdersResponse\x12\x7f\n\x11\x42\x61tchUpdateOrders\x12\x30.injective.exchange.v1beta1.MsgBatchUpdateOrders\x1a\x38.injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse\x12X\n\x04\x45xec\x12#.injective.exchange.v1beta1.MsgExec\x1a+.injective.exchange.v1beta1.MsgExecResponse\x12\x9a\x01\n\x1a\x43reateDerivativeLimitOrder\x12\x39.injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder\x1a\x41.injective.exchange.v1beta1.MsgCreateDerivativeLimitOrderResponse\x12\xac\x01\n BatchCreateDerivativeLimitOrders\x12?.injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders\x1aG.injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrdersResponse\x12\x9d\x01\n\x1b\x43reateDerivativeMarketOrder\x12:.injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder\x1a\x42.injective.exchange.v1beta1.MsgCreateDerivativeMarketOrderResponse\x12\x8b\x01\n\x15\x43\x61ncelDerivativeOrder\x12\x34.injective.exchange.v1beta1.MsgCancelDerivativeOrder\x1a<.injective.exchange.v1beta1.MsgCancelDerivativeOrderResponse\x12\x9d\x01\n\x1b\x42\x61tchCancelDerivativeOrders\x12:.injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders\x1a\x42.injective.exchange.v1beta1.MsgBatchCancelDerivativeOrdersResponse\x12\xac\x01\n InstantBinaryOptionsMarketLaunch\x12?.injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch\x1aG.injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunchResponse\x12\xa3\x01\n\x1d\x43reateBinaryOptionsLimitOrder\x12<.injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder\x1a\x44.injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrderResponse\x12\xa6\x01\n\x1e\x43reateBinaryOptionsMarketOrder\x12=.injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder\x1a\x45.injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrderResponse\x12\x94\x01\n\x18\x43\x61ncelBinaryOptionsOrder\x12\x37.injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder\x1a?.injective.exchange.v1beta1.MsgCancelBinaryOptionsOrderResponse\x12\xa6\x01\n\x1e\x42\x61tchCancelBinaryOptionsOrders\x12=.injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders\x1a\x45.injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrdersResponse\x12\x82\x01\n\x12SubaccountTransfer\x12\x31.injective.exchange.v1beta1.MsgSubaccountTransfer\x1a\x39.injective.exchange.v1beta1.MsgSubaccountTransferResponse\x12|\n\x10\x45xternalTransfer\x12/.injective.exchange.v1beta1.MsgExternalTransfer\x1a\x37.injective.exchange.v1beta1.MsgExternalTransferResponse\x12\x7f\n\x11LiquidatePosition\x12\x30.injective.exchange.v1beta1.MsgLiquidatePosition\x1a\x38.injective.exchange.v1beta1.MsgLiquidatePositionResponse\x12\x8e\x01\n\x16IncreasePositionMargin\x12\x35.injective.exchange.v1beta1.MsgIncreasePositionMargin\x1a=.injective.exchange.v1beta1.MsgIncreasePositionMarginResponse\x12s\n\rRewardsOptOut\x12,.injective.exchange.v1beta1.MsgRewardsOptOut\x1a\x34.injective.exchange.v1beta1.MsgRewardsOptOutResponse\x12\xa6\x01\n\x1e\x41\x64minUpdateBinaryOptionsMarket\x12=.injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket\x1a\x45.injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarketResponseBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2.DESCRIPTOR,])

_EXCHANGETYPE = _descriptor.EnumDescriptor(
  name='ExchangeType',
  full_name='injective.exchange.v1beta1.ExchangeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXCHANGE_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \024EXCHANGE_UNSPECIFIED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=1, number=1,
      serialized_options=b'\212\235 \004SPOT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DERIVATIVES', index=2, number=2,
      serialized_options=b'\212\235 \013DERIVATIVES',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15850,
  serialized_end=15970,
)
_sym_db.RegisterEnumDescriptor(_EXCHANGETYPE)

ExchangeType = enum_type_wrapper.EnumTypeWrapper(_EXCHANGETYPE)
EXCHANGE_UNSPECIFIED = 0
SPOT = 1
DERIVATIVES = 2



_MSGDEPOSIT = _descriptor.Descriptor(
  name='MsgDeposit',
  full_name='injective.exchange.v1beta1.MsgDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgDeposit.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgDeposit.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.MsgDeposit.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=361,
)


_MSGDEPOSITRESPONSE = _descriptor.Descriptor(
  name='MsgDepositResponse',
  full_name='injective.exchange.v1beta1.MsgDepositResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=383,
)


_MSGWITHDRAW = _descriptor.Descriptor(
  name='MsgWithdraw',
  full_name='injective.exchange.v1beta1.MsgWithdraw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgWithdraw.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgWithdraw.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.MsgWithdraw.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=496,
)


_MSGWITHDRAWRESPONSE = _descriptor.Descriptor(
  name='MsgWithdrawResponse',
  full_name='injective.exchange.v1beta1.MsgWithdrawResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=519,
)


_MSGCREATESPOTLIMITORDER = _descriptor.Descriptor(
  name='MsgCreateSpotLimitOrder',
  full_name='injective.exchange.v1beta1.MsgCreateSpotLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCreateSpotLimitOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgCreateSpotLimitOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=632,
)


_MSGCREATESPOTLIMITORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCreateSpotLimitOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCreateSpotLimitOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCreateSpotLimitOrderResponse.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=697,
)


_MSGBATCHCREATESPOTLIMITORDERS = _descriptor.Descriptor(
  name='MsgBatchCreateSpotLimitOrders',
  full_name='injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders.orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=817,
)


_MSGBATCHCREATESPOTLIMITORDERSRESPONSE = _descriptor.Descriptor(
  name='MsgBatchCreateSpotLimitOrdersResponse',
  full_name='injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hashes', full_name='injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrdersResponse.order_hashes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=890,
)


_MSGINSTANTSPOTMARKETLAUNCH = _descriptor.Descriptor(
  name='MsgInstantSpotMarketLaunch',
  full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_denom', full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch.base_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch.quote_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch.min_price_tick_size', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunch.min_quantity_tick_size', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=1161,
)


_MSGINSTANTSPOTMARKETLAUNCHRESPONSE = _descriptor.Descriptor(
  name='MsgInstantSpotMarketLaunchResponse',
  full_name='injective.exchange.v1beta1.MsgInstantSpotMarketLaunchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1199,
)


_MSGINSTANTPERPETUALMARKETLAUNCH = _descriptor.Descriptor(
  name='MsgInstantPerpetualMarketLaunch',
  full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.quote_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.oracle_base', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.oracle_quote', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.oracle_scale_factor', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.oracle_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.maker_fee_rate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.taker_fee_rate', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.initial_margin_ratio', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.maintenance_margin_ratio', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.min_price_tick_size', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch.min_quantity_tick_size', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1890,
)


_MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE = _descriptor.Descriptor(
  name='MsgInstantPerpetualMarketLaunchResponse',
  full_name='injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=1933,
)


_MSGINSTANTBINARYOPTIONSMARKETLAUNCH = _descriptor.Descriptor(
  name='MsgInstantBinaryOptionsMarketLaunch',
  full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_symbol', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.oracle_symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_provider', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.oracle_provider', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.oracle_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.oracle_scale_factor', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.maker_fee_rate', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.taker_fee_rate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.expiration_timestamp', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_timestamp', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.settlement_timestamp', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.admin', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.quote_denom', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.min_price_tick_size', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch.min_quantity_tick_size', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1936,
  serialized_end=2548,
)


_MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE = _descriptor.Descriptor(
  name='MsgInstantBinaryOptionsMarketLaunchResponse',
  full_name='injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2550,
  serialized_end=2595,
)


_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH = _descriptor.Descriptor(
  name='MsgInstantExpiryFuturesMarketLaunch',
  full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.quote_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.oracle_base', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.oracle_quote', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.oracle_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.oracle_scale_factor', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.expiry', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.maker_fee_rate', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.taker_fee_rate', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.initial_margin_ratio', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.maintenance_margin_ratio', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.min_price_tick_size', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch.min_quantity_tick_size', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2598,
  serialized_end=3306,
)


_MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE = _descriptor.Descriptor(
  name='MsgInstantExpiryFuturesMarketLaunchResponse',
  full_name='injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3308,
  serialized_end=3353,
)


_MSGCREATESPOTMARKETORDER = _descriptor.Descriptor(
  name='MsgCreateSpotMarketOrder',
  full_name='injective.exchange.v1beta1.MsgCreateSpotMarketOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCreateSpotMarketOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgCreateSpotMarketOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3355,
  serialized_end=3467,
)


_MSGCREATESPOTMARKETORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCreateSpotMarketOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCreateSpotMarketOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCreateSpotMarketOrderResponse.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3469,
  serialized_end=3533,
)


_MSGCREATEDERIVATIVELIMITORDER = _descriptor.Descriptor(
  name='MsgCreateDerivativeLimitOrder',
  full_name='injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3535,
  serialized_end=3654,
)


_MSGCREATEDERIVATIVELIMITORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCreateDerivativeLimitOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCreateDerivativeLimitOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCreateDerivativeLimitOrderResponse.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3656,
  serialized_end=3725,
)


_MSGCREATEBINARYOPTIONSLIMITORDER = _descriptor.Descriptor(
  name='MsgCreateBinaryOptionsLimitOrder',
  full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3727,
  serialized_end=3849,
)


_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCreateBinaryOptionsLimitOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrderResponse.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3851,
  serialized_end=3923,
)


_MSGBATCHCREATEDERIVATIVELIMITORDERS = _descriptor.Descriptor(
  name='MsgBatchCreateDerivativeLimitOrders',
  full_name='injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders.orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3925,
  serialized_end=4051,
)


_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE = _descriptor.Descriptor(
  name='MsgBatchCreateDerivativeLimitOrdersResponse',
  full_name='injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hashes', full_name='injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrdersResponse.order_hashes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4053,
  serialized_end=4130,
)


_MSGCANCELSPOTORDER = _descriptor.Descriptor(
  name='MsgCancelSpotOrder',
  full_name='injective.exchange.v1beta1.MsgCancelSpotOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCancelSpotOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MsgCancelSpotOrder.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgCancelSpotOrder.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCancelSpotOrder.order_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4132,
  serialized_end=4236,
)


_MSGCANCELSPOTORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCancelSpotOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCancelSpotOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4238,
  serialized_end=4266,
)


_MSGBATCHCANCELSPOTORDERS = _descriptor.Descriptor(
  name='MsgBatchCancelSpotOrders',
  full_name='injective.exchange.v1beta1.MsgBatchCancelSpotOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgBatchCancelSpotOrders.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.exchange.v1beta1.MsgBatchCancelSpotOrders.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4268,
  serialized_end=4375,
)


_MSGBATCHCANCELSPOTORDERSRESPONSE = _descriptor.Descriptor(
  name='MsgBatchCancelSpotOrdersResponse',
  full_name='injective.exchange.v1beta1.MsgBatchCancelSpotOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='injective.exchange.v1beta1.MsgBatchCancelSpotOrdersResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4377,
  serialized_end=4438,
)


_MSGBATCHCANCELBINARYOPTIONSORDERS = _descriptor.Descriptor(
  name='MsgBatchCancelBinaryOptionsOrders',
  full_name='injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4440,
  serialized_end=4556,
)


_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE = _descriptor.Descriptor(
  name='MsgBatchCancelBinaryOptionsOrdersResponse',
  full_name='injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrdersResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4558,
  serialized_end=4628,
)


_MSGBATCHUPDATEORDERS = _descriptor.Descriptor(
  name='MsgBatchUpdateOrders',
  full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_market_ids_to_cancel_all', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.spot_market_ids_to_cancel_all', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_market_ids_to_cancel_all', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.derivative_market_ids_to_cancel_all', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_orders_to_cancel', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.spot_orders_to_cancel', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_orders_to_cancel', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.derivative_orders_to_cancel', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_orders_to_create', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.spot_orders_to_create', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_orders_to_create', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.derivative_orders_to_create', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_orders_to_cancel', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.binary_options_orders_to_cancel', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_market_ids_to_cancel_all', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.binary_options_market_ids_to_cancel_all', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_orders_to_create', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrders.binary_options_orders_to_create', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4631,
  serialized_end=5331,
)


_MSGBATCHUPDATEORDERSRESPONSE = _descriptor.Descriptor(
  name='MsgBatchUpdateOrdersResponse',
  full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spot_cancel_success', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse.spot_cancel_success', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_cancel_success', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse.derivative_cancel_success', index=1,
      number=2, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_order_hashes', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse.spot_order_hashes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_order_hashes', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse.derivative_order_hashes', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_cancel_success', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse.binary_options_cancel_success', index=4,
      number=5, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_order_hashes', full_name='injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse.binary_options_order_hashes', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5334,
  serialized_end=5574,
)


_MSGCREATEDERIVATIVEMARKETORDER = _descriptor.Descriptor(
  name='MsgCreateDerivativeMarketOrder',
  full_name='injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5576,
  serialized_end=5696,
)


_MSGCREATEDERIVATIVEMARKETORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCreateDerivativeMarketOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCreateDerivativeMarketOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCreateDerivativeMarketOrderResponse.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5698,
  serialized_end=5768,
)


_MSGCREATEBINARYOPTIONSMARKETORDER = _descriptor.Descriptor(
  name='MsgCreateBinaryOptionsMarketOrder',
  full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5770,
  serialized_end=5893,
)


_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCreateBinaryOptionsMarketOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrderResponse.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5895,
  serialized_end=5968,
)


_MSGCANCELDERIVATIVEORDER = _descriptor.Descriptor(
  name='MsgCancelDerivativeOrder',
  full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrder.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrder.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrder.order_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_mask', full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrder.order_mask', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5971,
  serialized_end=6101,
)


_MSGCANCELDERIVATIVEORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCancelDerivativeOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCancelDerivativeOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6103,
  serialized_end=6137,
)


_MSGCANCELBINARYOPTIONSORDER = _descriptor.Descriptor(
  name='MsgCancelBinaryOptionsOrder',
  full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder.order_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_mask', full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder.order_mask', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6140,
  serialized_end=6273,
)


_MSGCANCELBINARYOPTIONSORDERRESPONSE = _descriptor.Descriptor(
  name='MsgCancelBinaryOptionsOrderResponse',
  full_name='injective.exchange.v1beta1.MsgCancelBinaryOptionsOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6275,
  serialized_end=6312,
)


_ORDERDATA = _descriptor.Descriptor(
  name='OrderData',
  full_name='injective.exchange.v1beta1.OrderData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.OrderData.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.OrderData.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.OrderData.order_hash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_mask', full_name='injective.exchange.v1beta1.OrderData.order_mask', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6314,
  serialized_end=6407,
)


_MSGBATCHCANCELDERIVATIVEORDERS = _descriptor.Descriptor(
  name='MsgBatchCancelDerivativeOrders',
  full_name='injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6409,
  serialized_end=6522,
)


_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE = _descriptor.Descriptor(
  name='MsgBatchCancelDerivativeOrdersResponse',
  full_name='injective.exchange.v1beta1.MsgBatchCancelDerivativeOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='injective.exchange.v1beta1.MsgBatchCancelDerivativeOrdersResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6524,
  serialized_end=6591,
)


_MSGSUBACCOUNTTRANSFER = _descriptor.Descriptor(
  name='MsgSubaccountTransfer',
  full_name='injective.exchange.v1beta1.MsgSubaccountTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgSubaccountTransfer.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_subaccount_id', full_name='injective.exchange.v1beta1.MsgSubaccountTransfer.source_subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_subaccount_id', full_name='injective.exchange.v1beta1.MsgSubaccountTransfer.destination_subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.MsgSubaccountTransfer.amount', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6594,
  serialized_end=6747,
)


_MSGSUBACCOUNTTRANSFERRESPONSE = _descriptor.Descriptor(
  name='MsgSubaccountTransferResponse',
  full_name='injective.exchange.v1beta1.MsgSubaccountTransferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6749,
  serialized_end=6780,
)


_MSGEXTERNALTRANSFER = _descriptor.Descriptor(
  name='MsgExternalTransfer',
  full_name='injective.exchange.v1beta1.MsgExternalTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgExternalTransfer.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_subaccount_id', full_name='injective.exchange.v1beta1.MsgExternalTransfer.source_subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_subaccount_id', full_name='injective.exchange.v1beta1.MsgExternalTransfer.destination_subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.MsgExternalTransfer.amount', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6783,
  serialized_end=6934,
)


_MSGEXTERNALTRANSFERRESPONSE = _descriptor.Descriptor(
  name='MsgExternalTransferResponse',
  full_name='injective.exchange.v1beta1.MsgExternalTransferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6936,
  serialized_end=6965,
)


_MSGLIQUIDATEPOSITION = _descriptor.Descriptor(
  name='MsgLiquidatePosition',
  full_name='injective.exchange.v1beta1.MsgLiquidatePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgLiquidatePosition.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.MsgLiquidatePosition.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MsgLiquidatePosition.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.MsgLiquidatePosition.order', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6968,
  serialized_end=7114,
)


_MSGLIQUIDATEPOSITIONRESPONSE = _descriptor.Descriptor(
  name='MsgLiquidatePositionResponse',
  full_name='injective.exchange.v1beta1.MsgLiquidatePositionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7116,
  serialized_end=7146,
)


_MSGINCREASEPOSITIONMARGIN = _descriptor.Descriptor(
  name='MsgIncreasePositionMargin',
  full_name='injective.exchange.v1beta1.MsgIncreasePositionMargin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgIncreasePositionMargin.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_subaccount_id', full_name='injective.exchange.v1beta1.MsgIncreasePositionMargin.source_subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_subaccount_id', full_name='injective.exchange.v1beta1.MsgIncreasePositionMargin.destination_subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MsgIncreasePositionMargin.market_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.MsgIncreasePositionMargin.amount', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7149,
  serialized_end=7340,
)


_MSGINCREASEPOSITIONMARGINRESPONSE = _descriptor.Descriptor(
  name='MsgIncreasePositionMarginResponse',
  full_name='injective.exchange.v1beta1.MsgIncreasePositionMarginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7342,
  serialized_end=7377,
)


_MSGEXEC = _descriptor.Descriptor(
  name='MsgExec',
  full_name='injective.exchange.v1beta1.MsgExec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgExec.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bank_funds', full_name='injective.exchange.v1beta1.MsgExec.bank_funds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposits_subaccount_id', full_name='injective.exchange.v1beta1.MsgExec.deposits_subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit_funds', full_name='injective.exchange.v1beta1.MsgExec.deposit_funds', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_address', full_name='injective.exchange.v1beta1.MsgExec.contract_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.exchange.v1beta1.MsgExec.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7380,
  serialized_end=7684,
)


_MSGEXECRESPONSE = _descriptor.Descriptor(
  name='MsgExecResponse',
  full_name='injective.exchange.v1beta1.MsgExecResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7686,
  serialized_end=7703,
)


_SPOTMARKETPARAMUPDATEPROPOSAL = _descriptor.Descriptor(
  name='SpotMarketParamUpdateProposal',
  full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.maker_fee_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.taker_fee_rate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer_fee_share_rate', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.relayer_fee_share_rate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.min_price_tick_size', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.min_quantity_tick_size', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.SpotMarketParamUpdateProposal.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7706,
  serialized_end=8241,
)


_EXCHANGEENABLEPROPOSAL = _descriptor.Descriptor(
  name='ExchangeEnableProposal',
  full_name='injective.exchange.v1beta1.ExchangeEnableProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.ExchangeEnableProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.ExchangeEnableProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeType', full_name='injective.exchange.v1beta1.ExchangeEnableProposal.exchangeType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8244,
  serialized_end=8378,
)


_BATCHEXCHANGEMODIFICATIONPROPOSAL = _descriptor.Descriptor(
  name='BatchExchangeModificationProposal',
  full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_market_param_update_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.spot_market_param_update_proposals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_market_param_update_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.derivative_market_param_update_proposals', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_market_launch_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.spot_market_launch_proposals', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_launch_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.perpetual_market_launch_proposals', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_futures_market_launch_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.expiry_futures_market_launch_proposals', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_campaign_update_proposal', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.trading_reward_campaign_update_proposal', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_market_launch_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.binary_options_market_launch_proposals', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_param_update_proposals', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.binary_options_param_update_proposals', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom_decimals_update_proposal', full_name='injective.exchange.v1beta1.BatchExchangeModificationProposal.denom_decimals_update_proposal', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8381,
  serialized_end=9422,
)


_SPOTMARKETLAUNCHPROPOSAL = _descriptor.Descriptor(
  name='SpotMarketLaunchProposal',
  full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_denom', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.base_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.quote_denom', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.min_price_tick_size', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.min_quantity_tick_size', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.maker_fee_rate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.SpotMarketLaunchProposal.taker_fee_rate', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9425,
  serialized_end=9855,
)


_PERPETUALMARKETLAUNCHPROPOSAL = _descriptor.Descriptor(
  name='PerpetualMarketLaunchProposal',
  full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.quote_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.oracle_base', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.oracle_quote', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.oracle_scale_factor', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.oracle_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.initial_margin_ratio', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.maintenance_margin_ratio', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.maker_fee_rate', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.taker_fee_rate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.min_price_tick_size', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.PerpetualMarketLaunchProposal.min_quantity_tick_size', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9858,
  serialized_end=10564,
)


_BINARYOPTIONSMARKETLAUNCHPROPOSAL = _descriptor.Descriptor(
  name='BinaryOptionsMarketLaunchProposal',
  full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_symbol', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.oracle_symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_provider', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.oracle_provider', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.oracle_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.oracle_scale_factor', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.expiration_timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_timestamp', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.settlement_timestamp', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.admin', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.quote_denom', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.maker_fee_rate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.taker_fee_rate', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.min_price_tick_size', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal.min_quantity_tick_size', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10567,
  serialized_end=11197,
)


_EXPIRYFUTURESMARKETLAUNCHPROPOSAL = _descriptor.Descriptor(
  name='ExpiryFuturesMarketLaunchProposal',
  full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.quote_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.oracle_base', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.oracle_quote', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.oracle_scale_factor', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.oracle_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.expiry', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.initial_margin_ratio', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.maintenance_margin_ratio', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.maker_fee_rate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.taker_fee_rate', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.min_price_tick_size', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal.min_quantity_tick_size', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11200,
  serialized_end=11926,
)


_DERIVATIVEMARKETPARAMUPDATEPROPOSAL = _descriptor.Descriptor(
  name='DerivativeMarketParamUpdateProposal',
  full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.initial_margin_ratio', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.maintenance_margin_ratio', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.maker_fee_rate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.taker_fee_rate', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer_fee_share_rate', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.relayer_fee_share_rate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.min_price_tick_size', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.min_quantity_tick_size', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HourlyInterestRate', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.HourlyInterestRate', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HourlyFundingRateCap', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.HourlyFundingRateCap', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.status', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_params', full_name='injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal.oracle_params', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11929,
  serialized_end=12849,
)


_MARKETFORCEDSETTLEMENTPROPOSAL = _descriptor.Descriptor(
  name='MarketForcedSettlementProposal',
  full_name='injective.exchange.v1beta1.MarketForcedSettlementProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.MarketForcedSettlementProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.MarketForcedSettlementProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MarketForcedSettlementProposal.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective.exchange.v1beta1.MarketForcedSettlementProposal.settlement_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12852,
  serialized_end=13023,
)


_UPDATEDENOMDECIMALSPROPOSAL = _descriptor.Descriptor(
  name='UpdateDenomDecimalsProposal',
  full_name='injective.exchange.v1beta1.UpdateDenomDecimalsProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.UpdateDenomDecimalsProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.UpdateDenomDecimalsProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom_decimals', full_name='injective.exchange.v1beta1.UpdateDenomDecimalsProposal.denom_decimals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13026,
  serialized_end=13168,
)


_DENOMDECIMALS = _descriptor.Descriptor(
  name='DenomDecimals',
  full_name='injective.exchange.v1beta1.DenomDecimals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.DenomDecimals.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective.exchange.v1beta1.DenomDecimals.decimals', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13170,
  serialized_end=13218,
)


_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL = _descriptor.Descriptor(
  name='BinaryOptionsMarketParamUpdateProposal',
  full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.maker_fee_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.taker_fee_rate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer_fee_share_rate', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.relayer_fee_share_rate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.min_price_tick_size', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.min_quantity_tick_size', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.expiration_timestamp', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_timestamp', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.settlement_timestamp', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.settlement_price', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.admin', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.status', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_params', full_name='injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal.oracle_params', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13221,
  serialized_end=13987,
)


_PROVIDERORACLEPARAMS = _descriptor.Descriptor(
  name='ProviderOracleParams',
  full_name='injective.exchange.v1beta1.ProviderOracleParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.exchange.v1beta1.ProviderOracleParams.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.exchange.v1beta1.ProviderOracleParams.provider', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.ProviderOracleParams.oracle_scale_factor', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.ProviderOracleParams.oracle_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13990,
  serialized_end=14134,
)


_ORACLEPARAMS = _descriptor.Descriptor(
  name='OracleParams',
  full_name='injective.exchange.v1beta1.OracleParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.exchange.v1beta1.OracleParams.oracle_base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.exchange.v1beta1.OracleParams.oracle_quote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.OracleParams.oracle_scale_factor', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.OracleParams.oracle_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14137,
  serialized_end=14282,
)


_TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL = _descriptor.Descriptor(
  name='TradingRewardCampaignLaunchProposal',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignLaunchProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.TradingRewardCampaignLaunchProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.TradingRewardCampaignLaunchProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_info', full_name='injective.exchange.v1beta1.TradingRewardCampaignLaunchProposal.campaign_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_reward_pools', full_name='injective.exchange.v1beta1.TradingRewardCampaignLaunchProposal.campaign_reward_pools', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14285,
  serialized_end=14525,
)


_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL = _descriptor.Descriptor(
  name='TradingRewardCampaignUpdateProposal',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_info', full_name='injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal.campaign_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_reward_pools_additions', full_name='injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal.campaign_reward_pools_additions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_reward_pools_updates', full_name='injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal.campaign_reward_pools_updates', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14528,
  serialized_end=14865,
)


_REWARDPOINTUPDATE = _descriptor.Descriptor(
  name='RewardPointUpdate',
  full_name='injective.exchange.v1beta1.RewardPointUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_address', full_name='injective.exchange.v1beta1.RewardPointUpdate.account_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_points', full_name='injective.exchange.v1beta1.RewardPointUpdate.new_points', index=1,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14867,
  serialized_end=14979,
)


_TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL = _descriptor.Descriptor(
  name='TradingRewardPendingPointsUpdateProposal',
  full_name='injective.exchange.v1beta1.TradingRewardPendingPointsUpdateProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.TradingRewardPendingPointsUpdateProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.TradingRewardPendingPointsUpdateProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_pool_timestamp', full_name='injective.exchange.v1beta1.TradingRewardPendingPointsUpdateProposal.pending_pool_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_point_updates', full_name='injective.exchange.v1beta1.TradingRewardPendingPointsUpdateProposal.reward_point_updates', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14982,
  serialized_end=15179,
)


_FEEDISCOUNTPROPOSAL = _descriptor.Descriptor(
  name='FeeDiscountProposal',
  full_name='injective.exchange.v1beta1.FeeDiscountProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.FeeDiscountProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.FeeDiscountProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.exchange.v1beta1.FeeDiscountProposal.schedule', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15182,
  serialized_end=15316,
)


_BATCHCOMMUNITYPOOLSPENDPROPOSAL = _descriptor.Descriptor(
  name='BatchCommunityPoolSpendProposal',
  full_name='injective.exchange.v1beta1.BatchCommunityPoolSpendProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.exchange.v1beta1.BatchCommunityPoolSpendProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.exchange.v1beta1.BatchCommunityPoolSpendProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposals', full_name='injective.exchange.v1beta1.BatchCommunityPoolSpendProposal.proposals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15319,
  serialized_end=15474,
)


_MSGREWARDSOPTOUT = _descriptor.Descriptor(
  name='MsgRewardsOptOut',
  full_name='injective.exchange.v1beta1.MsgRewardsOptOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgRewardsOptOut.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15476,
  serialized_end=15510,
)


_MSGREWARDSOPTOUTRESPONSE = _descriptor.Descriptor(
  name='MsgRewardsOptOutResponse',
  full_name='injective.exchange.v1beta1.MsgRewardsOptOutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15512,
  serialized_end=15538,
)


_MSGADMINUPDATEBINARYOPTIONSMARKET = _descriptor.Descriptor(
  name='MsgAdminUpdateBinaryOptionsMarket',
  full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket.settlement_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket.expiration_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_timestamp', full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket.settlement_timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15541,
  serialized_end=15803,
)


_MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE = _descriptor.Descriptor(
  name='MsgAdminUpdateBinaryOptionsMarketResponse',
  full_name='injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15805,
  serialized_end=15848,
)

_MSGDEPOSIT.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGWITHDRAW.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGCREATESPOTLIMITORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTORDER
_MSGBATCHCREATESPOTLIMITORDERS.fields_by_name['orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTORDER
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_MSGCREATESPOTMARKETORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTORDER
_MSGCREATEDERIVATIVELIMITORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGCREATEBINARYOPTIONSLIMITORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGBATCHCREATEDERIVATIVELIMITORDERS.fields_by_name['orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGBATCHCANCELSPOTORDERS.fields_by_name['data'].message_type = _ORDERDATA
_MSGBATCHCANCELBINARYOPTIONSORDERS.fields_by_name['data'].message_type = _ORDERDATA
_MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_cancel'].message_type = _ORDERDATA
_MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_cancel'].message_type = _ORDERDATA
_MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_create'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTORDER
_MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_create'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_cancel'].message_type = _ORDERDATA
_MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_create'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGCREATEDERIVATIVEMARKETORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGCREATEBINARYOPTIONSMARKETORDER.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGBATCHCANCELDERIVATIVEORDERS.fields_by_name['data'].message_type = _ORDERDATA
_MSGSUBACCOUNTTRANSFER.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGEXTERNALTRANSFER.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGLIQUIDATEPOSITION.fields_by_name['order'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEORDER
_MSGEXEC.fields_by_name['bank_funds'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGEXEC.fields_by_name['deposit_funds'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['status'].enum_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._MARKETSTATUS
_EXCHANGEENABLEPROPOSAL.fields_by_name['exchangeType'].enum_type = _EXCHANGETYPE
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['spot_market_param_update_proposals'].message_type = _SPOTMARKETPARAMUPDATEPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['derivative_market_param_update_proposals'].message_type = _DERIVATIVEMARKETPARAMUPDATEPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['spot_market_launch_proposals'].message_type = _SPOTMARKETLAUNCHPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['perpetual_market_launch_proposals'].message_type = _PERPETUALMARKETLAUNCHPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['expiry_futures_market_launch_proposals'].message_type = _EXPIRYFUTURESMARKETLAUNCHPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['trading_reward_campaign_update_proposal'].message_type = _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['binary_options_market_launch_proposals'].message_type = _BINARYOPTIONSMARKETLAUNCHPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['binary_options_param_update_proposals'].message_type = _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL
_BATCHEXCHANGEMODIFICATIONPROPOSAL.fields_by_name['denom_decimals_update_proposal'].message_type = _UPDATEDENOMDECIMALSPROPOSAL
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['status'].enum_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._MARKETSTATUS
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['oracle_params'].message_type = _ORACLEPARAMS
_UPDATEDENOMDECIMALSPROPOSAL.fields_by_name['denom_decimals'].message_type = _DENOMDECIMALS
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['status'].enum_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._MARKETSTATUS
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['oracle_params'].message_type = _PROVIDERORACLEPARAMS
_PROVIDERORACLEPARAMS.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_ORACLEPARAMS.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL.fields_by_name['campaign_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADINGREWARDCAMPAIGNINFO
_TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL.fields_by_name['campaign_reward_pools'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL.fields_by_name['campaign_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADINGREWARDCAMPAIGNINFO
_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL.fields_by_name['campaign_reward_pools_additions'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL.fields_by_name['campaign_reward_pools_updates'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL.fields_by_name['reward_point_updates'].message_type = _REWARDPOINTUPDATE
_FEEDISCOUNTPROPOSAL.fields_by_name['schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTSCHEDULE
_BATCHCOMMUNITYPOOLSPENDPROPOSAL.fields_by_name['proposals'].message_type = cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2._COMMUNITYPOOLSPENDPROPOSAL
_MSGADMINUPDATEBINARYOPTIONSMARKET.fields_by_name['status'].enum_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._MARKETSTATUS
DESCRIPTOR.message_types_by_name['MsgDeposit'] = _MSGDEPOSIT
DESCRIPTOR.message_types_by_name['MsgDepositResponse'] = _MSGDEPOSITRESPONSE
DESCRIPTOR.message_types_by_name['MsgWithdraw'] = _MSGWITHDRAW
DESCRIPTOR.message_types_by_name['MsgWithdrawResponse'] = _MSGWITHDRAWRESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateSpotLimitOrder'] = _MSGCREATESPOTLIMITORDER
DESCRIPTOR.message_types_by_name['MsgCreateSpotLimitOrderResponse'] = _MSGCREATESPOTLIMITORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgBatchCreateSpotLimitOrders'] = _MSGBATCHCREATESPOTLIMITORDERS
DESCRIPTOR.message_types_by_name['MsgBatchCreateSpotLimitOrdersResponse'] = _MSGBATCHCREATESPOTLIMITORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MsgInstantSpotMarketLaunch'] = _MSGINSTANTSPOTMARKETLAUNCH
DESCRIPTOR.message_types_by_name['MsgInstantSpotMarketLaunchResponse'] = _MSGINSTANTSPOTMARKETLAUNCHRESPONSE
DESCRIPTOR.message_types_by_name['MsgInstantPerpetualMarketLaunch'] = _MSGINSTANTPERPETUALMARKETLAUNCH
DESCRIPTOR.message_types_by_name['MsgInstantPerpetualMarketLaunchResponse'] = _MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE
DESCRIPTOR.message_types_by_name['MsgInstantBinaryOptionsMarketLaunch'] = _MSGINSTANTBINARYOPTIONSMARKETLAUNCH
DESCRIPTOR.message_types_by_name['MsgInstantBinaryOptionsMarketLaunchResponse'] = _MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE
DESCRIPTOR.message_types_by_name['MsgInstantExpiryFuturesMarketLaunch'] = _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH
DESCRIPTOR.message_types_by_name['MsgInstantExpiryFuturesMarketLaunchResponse'] = _MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateSpotMarketOrder'] = _MSGCREATESPOTMARKETORDER
DESCRIPTOR.message_types_by_name['MsgCreateSpotMarketOrderResponse'] = _MSGCREATESPOTMARKETORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateDerivativeLimitOrder'] = _MSGCREATEDERIVATIVELIMITORDER
DESCRIPTOR.message_types_by_name['MsgCreateDerivativeLimitOrderResponse'] = _MSGCREATEDERIVATIVELIMITORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateBinaryOptionsLimitOrder'] = _MSGCREATEBINARYOPTIONSLIMITORDER
DESCRIPTOR.message_types_by_name['MsgCreateBinaryOptionsLimitOrderResponse'] = _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgBatchCreateDerivativeLimitOrders'] = _MSGBATCHCREATEDERIVATIVELIMITORDERS
DESCRIPTOR.message_types_by_name['MsgBatchCreateDerivativeLimitOrdersResponse'] = _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MsgCancelSpotOrder'] = _MSGCANCELSPOTORDER
DESCRIPTOR.message_types_by_name['MsgCancelSpotOrderResponse'] = _MSGCANCELSPOTORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgBatchCancelSpotOrders'] = _MSGBATCHCANCELSPOTORDERS
DESCRIPTOR.message_types_by_name['MsgBatchCancelSpotOrdersResponse'] = _MSGBATCHCANCELSPOTORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MsgBatchCancelBinaryOptionsOrders'] = _MSGBATCHCANCELBINARYOPTIONSORDERS
DESCRIPTOR.message_types_by_name['MsgBatchCancelBinaryOptionsOrdersResponse'] = _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MsgBatchUpdateOrders'] = _MSGBATCHUPDATEORDERS
DESCRIPTOR.message_types_by_name['MsgBatchUpdateOrdersResponse'] = _MSGBATCHUPDATEORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateDerivativeMarketOrder'] = _MSGCREATEDERIVATIVEMARKETORDER
DESCRIPTOR.message_types_by_name['MsgCreateDerivativeMarketOrderResponse'] = _MSGCREATEDERIVATIVEMARKETORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateBinaryOptionsMarketOrder'] = _MSGCREATEBINARYOPTIONSMARKETORDER
DESCRIPTOR.message_types_by_name['MsgCreateBinaryOptionsMarketOrderResponse'] = _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgCancelDerivativeOrder'] = _MSGCANCELDERIVATIVEORDER
DESCRIPTOR.message_types_by_name['MsgCancelDerivativeOrderResponse'] = _MSGCANCELDERIVATIVEORDERRESPONSE
DESCRIPTOR.message_types_by_name['MsgCancelBinaryOptionsOrder'] = _MSGCANCELBINARYOPTIONSORDER
DESCRIPTOR.message_types_by_name['MsgCancelBinaryOptionsOrderResponse'] = _MSGCANCELBINARYOPTIONSORDERRESPONSE
DESCRIPTOR.message_types_by_name['OrderData'] = _ORDERDATA
DESCRIPTOR.message_types_by_name['MsgBatchCancelDerivativeOrders'] = _MSGBATCHCANCELDERIVATIVEORDERS
DESCRIPTOR.message_types_by_name['MsgBatchCancelDerivativeOrdersResponse'] = _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MsgSubaccountTransfer'] = _MSGSUBACCOUNTTRANSFER
DESCRIPTOR.message_types_by_name['MsgSubaccountTransferResponse'] = _MSGSUBACCOUNTTRANSFERRESPONSE
DESCRIPTOR.message_types_by_name['MsgExternalTransfer'] = _MSGEXTERNALTRANSFER
DESCRIPTOR.message_types_by_name['MsgExternalTransferResponse'] = _MSGEXTERNALTRANSFERRESPONSE
DESCRIPTOR.message_types_by_name['MsgLiquidatePosition'] = _MSGLIQUIDATEPOSITION
DESCRIPTOR.message_types_by_name['MsgLiquidatePositionResponse'] = _MSGLIQUIDATEPOSITIONRESPONSE
DESCRIPTOR.message_types_by_name['MsgIncreasePositionMargin'] = _MSGINCREASEPOSITIONMARGIN
DESCRIPTOR.message_types_by_name['MsgIncreasePositionMarginResponse'] = _MSGINCREASEPOSITIONMARGINRESPONSE
DESCRIPTOR.message_types_by_name['MsgExec'] = _MSGEXEC
DESCRIPTOR.message_types_by_name['MsgExecResponse'] = _MSGEXECRESPONSE
DESCRIPTOR.message_types_by_name['SpotMarketParamUpdateProposal'] = _SPOTMARKETPARAMUPDATEPROPOSAL
DESCRIPTOR.message_types_by_name['ExchangeEnableProposal'] = _EXCHANGEENABLEPROPOSAL
DESCRIPTOR.message_types_by_name['BatchExchangeModificationProposal'] = _BATCHEXCHANGEMODIFICATIONPROPOSAL
DESCRIPTOR.message_types_by_name['SpotMarketLaunchProposal'] = _SPOTMARKETLAUNCHPROPOSAL
DESCRIPTOR.message_types_by_name['PerpetualMarketLaunchProposal'] = _PERPETUALMARKETLAUNCHPROPOSAL
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketLaunchProposal'] = _BINARYOPTIONSMARKETLAUNCHPROPOSAL
DESCRIPTOR.message_types_by_name['ExpiryFuturesMarketLaunchProposal'] = _EXPIRYFUTURESMARKETLAUNCHPROPOSAL
DESCRIPTOR.message_types_by_name['DerivativeMarketParamUpdateProposal'] = _DERIVATIVEMARKETPARAMUPDATEPROPOSAL
DESCRIPTOR.message_types_by_name['MarketForcedSettlementProposal'] = _MARKETFORCEDSETTLEMENTPROPOSAL
DESCRIPTOR.message_types_by_name['UpdateDenomDecimalsProposal'] = _UPDATEDENOMDECIMALSPROPOSAL
DESCRIPTOR.message_types_by_name['DenomDecimals'] = _DENOMDECIMALS
DESCRIPTOR.message_types_by_name['BinaryOptionsMarketParamUpdateProposal'] = _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL
DESCRIPTOR.message_types_by_name['ProviderOracleParams'] = _PROVIDERORACLEPARAMS
DESCRIPTOR.message_types_by_name['OracleParams'] = _ORACLEPARAMS
DESCRIPTOR.message_types_by_name['TradingRewardCampaignLaunchProposal'] = _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL
DESCRIPTOR.message_types_by_name['TradingRewardCampaignUpdateProposal'] = _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL
DESCRIPTOR.message_types_by_name['RewardPointUpdate'] = _REWARDPOINTUPDATE
DESCRIPTOR.message_types_by_name['TradingRewardPendingPointsUpdateProposal'] = _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL
DESCRIPTOR.message_types_by_name['FeeDiscountProposal'] = _FEEDISCOUNTPROPOSAL
DESCRIPTOR.message_types_by_name['BatchCommunityPoolSpendProposal'] = _BATCHCOMMUNITYPOOLSPENDPROPOSAL
DESCRIPTOR.message_types_by_name['MsgRewardsOptOut'] = _MSGREWARDSOPTOUT
DESCRIPTOR.message_types_by_name['MsgRewardsOptOutResponse'] = _MSGREWARDSOPTOUTRESPONSE
DESCRIPTOR.message_types_by_name['MsgAdminUpdateBinaryOptionsMarket'] = _MSGADMINUPDATEBINARYOPTIONSMARKET
DESCRIPTOR.message_types_by_name['MsgAdminUpdateBinaryOptionsMarketResponse'] = _MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE
DESCRIPTOR.enum_types_by_name['ExchangeType'] = _EXCHANGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgDeposit = _reflection.GeneratedProtocolMessageType('MsgDeposit', (_message.Message,), {
  'DESCRIPTOR' : _MSGDEPOSIT,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgDeposit)
  })
_sym_db.RegisterMessage(MsgDeposit)

MsgDepositResponse = _reflection.GeneratedProtocolMessageType('MsgDepositResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGDEPOSITRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgDepositResponse)
  })
_sym_db.RegisterMessage(MsgDepositResponse)

MsgWithdraw = _reflection.GeneratedProtocolMessageType('MsgWithdraw', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAW,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgWithdraw)
  })
_sym_db.RegisterMessage(MsgWithdraw)

MsgWithdrawResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgWithdrawResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawResponse)

MsgCreateSpotLimitOrder = _reflection.GeneratedProtocolMessageType('MsgCreateSpotLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATESPOTLIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateSpotLimitOrder)
  })
_sym_db.RegisterMessage(MsgCreateSpotLimitOrder)

MsgCreateSpotLimitOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCreateSpotLimitOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATESPOTLIMITORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateSpotLimitOrderResponse)
  })
_sym_db.RegisterMessage(MsgCreateSpotLimitOrderResponse)

MsgBatchCreateSpotLimitOrders = _reflection.GeneratedProtocolMessageType('MsgBatchCreateSpotLimitOrders', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCREATESPOTLIMITORDERS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders)
  })
_sym_db.RegisterMessage(MsgBatchCreateSpotLimitOrders)

MsgBatchCreateSpotLimitOrdersResponse = _reflection.GeneratedProtocolMessageType('MsgBatchCreateSpotLimitOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCREATESPOTLIMITORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrdersResponse)
  })
_sym_db.RegisterMessage(MsgBatchCreateSpotLimitOrdersResponse)

MsgInstantSpotMarketLaunch = _reflection.GeneratedProtocolMessageType('MsgInstantSpotMarketLaunch', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTSPOTMARKETLAUNCH,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantSpotMarketLaunch)
  })
_sym_db.RegisterMessage(MsgInstantSpotMarketLaunch)

MsgInstantSpotMarketLaunchResponse = _reflection.GeneratedProtocolMessageType('MsgInstantSpotMarketLaunchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTSPOTMARKETLAUNCHRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantSpotMarketLaunchResponse)
  })
_sym_db.RegisterMessage(MsgInstantSpotMarketLaunchResponse)

MsgInstantPerpetualMarketLaunch = _reflection.GeneratedProtocolMessageType('MsgInstantPerpetualMarketLaunch', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTPERPETUALMARKETLAUNCH,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch)
  })
_sym_db.RegisterMessage(MsgInstantPerpetualMarketLaunch)

MsgInstantPerpetualMarketLaunchResponse = _reflection.GeneratedProtocolMessageType('MsgInstantPerpetualMarketLaunchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunchResponse)
  })
_sym_db.RegisterMessage(MsgInstantPerpetualMarketLaunchResponse)

MsgInstantBinaryOptionsMarketLaunch = _reflection.GeneratedProtocolMessageType('MsgInstantBinaryOptionsMarketLaunch', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTBINARYOPTIONSMARKETLAUNCH,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch)
  })
_sym_db.RegisterMessage(MsgInstantBinaryOptionsMarketLaunch)

MsgInstantBinaryOptionsMarketLaunchResponse = _reflection.GeneratedProtocolMessageType('MsgInstantBinaryOptionsMarketLaunchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunchResponse)
  })
_sym_db.RegisterMessage(MsgInstantBinaryOptionsMarketLaunchResponse)

MsgInstantExpiryFuturesMarketLaunch = _reflection.GeneratedProtocolMessageType('MsgInstantExpiryFuturesMarketLaunch', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch)
  })
_sym_db.RegisterMessage(MsgInstantExpiryFuturesMarketLaunch)

MsgInstantExpiryFuturesMarketLaunchResponse = _reflection.GeneratedProtocolMessageType('MsgInstantExpiryFuturesMarketLaunchResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunchResponse)
  })
_sym_db.RegisterMessage(MsgInstantExpiryFuturesMarketLaunchResponse)

MsgCreateSpotMarketOrder = _reflection.GeneratedProtocolMessageType('MsgCreateSpotMarketOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATESPOTMARKETORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateSpotMarketOrder)
  })
_sym_db.RegisterMessage(MsgCreateSpotMarketOrder)

MsgCreateSpotMarketOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCreateSpotMarketOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATESPOTMARKETORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateSpotMarketOrderResponse)
  })
_sym_db.RegisterMessage(MsgCreateSpotMarketOrderResponse)

MsgCreateDerivativeLimitOrder = _reflection.GeneratedProtocolMessageType('MsgCreateDerivativeLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDERIVATIVELIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder)
  })
_sym_db.RegisterMessage(MsgCreateDerivativeLimitOrder)

MsgCreateDerivativeLimitOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCreateDerivativeLimitOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDERIVATIVELIMITORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateDerivativeLimitOrderResponse)
  })
_sym_db.RegisterMessage(MsgCreateDerivativeLimitOrderResponse)

MsgCreateBinaryOptionsLimitOrder = _reflection.GeneratedProtocolMessageType('MsgCreateBinaryOptionsLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEBINARYOPTIONSLIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder)
  })
_sym_db.RegisterMessage(MsgCreateBinaryOptionsLimitOrder)

MsgCreateBinaryOptionsLimitOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCreateBinaryOptionsLimitOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrderResponse)
  })
_sym_db.RegisterMessage(MsgCreateBinaryOptionsLimitOrderResponse)

MsgBatchCreateDerivativeLimitOrders = _reflection.GeneratedProtocolMessageType('MsgBatchCreateDerivativeLimitOrders', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCREATEDERIVATIVELIMITORDERS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders)
  })
_sym_db.RegisterMessage(MsgBatchCreateDerivativeLimitOrders)

MsgBatchCreateDerivativeLimitOrdersResponse = _reflection.GeneratedProtocolMessageType('MsgBatchCreateDerivativeLimitOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrdersResponse)
  })
_sym_db.RegisterMessage(MsgBatchCreateDerivativeLimitOrdersResponse)

MsgCancelSpotOrder = _reflection.GeneratedProtocolMessageType('MsgCancelSpotOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELSPOTORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCancelSpotOrder)
  })
_sym_db.RegisterMessage(MsgCancelSpotOrder)

MsgCancelSpotOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCancelSpotOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELSPOTORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCancelSpotOrderResponse)
  })
_sym_db.RegisterMessage(MsgCancelSpotOrderResponse)

MsgBatchCancelSpotOrders = _reflection.GeneratedProtocolMessageType('MsgBatchCancelSpotOrders', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCANCELSPOTORDERS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCancelSpotOrders)
  })
_sym_db.RegisterMessage(MsgBatchCancelSpotOrders)

MsgBatchCancelSpotOrdersResponse = _reflection.GeneratedProtocolMessageType('MsgBatchCancelSpotOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCANCELSPOTORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCancelSpotOrdersResponse)
  })
_sym_db.RegisterMessage(MsgBatchCancelSpotOrdersResponse)

MsgBatchCancelBinaryOptionsOrders = _reflection.GeneratedProtocolMessageType('MsgBatchCancelBinaryOptionsOrders', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCANCELBINARYOPTIONSORDERS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders)
  })
_sym_db.RegisterMessage(MsgBatchCancelBinaryOptionsOrders)

MsgBatchCancelBinaryOptionsOrdersResponse = _reflection.GeneratedProtocolMessageType('MsgBatchCancelBinaryOptionsOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrdersResponse)
  })
_sym_db.RegisterMessage(MsgBatchCancelBinaryOptionsOrdersResponse)

MsgBatchUpdateOrders = _reflection.GeneratedProtocolMessageType('MsgBatchUpdateOrders', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHUPDATEORDERS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchUpdateOrders)
  })
_sym_db.RegisterMessage(MsgBatchUpdateOrders)

MsgBatchUpdateOrdersResponse = _reflection.GeneratedProtocolMessageType('MsgBatchUpdateOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHUPDATEORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse)
  })
_sym_db.RegisterMessage(MsgBatchUpdateOrdersResponse)

MsgCreateDerivativeMarketOrder = _reflection.GeneratedProtocolMessageType('MsgCreateDerivativeMarketOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDERIVATIVEMARKETORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder)
  })
_sym_db.RegisterMessage(MsgCreateDerivativeMarketOrder)

MsgCreateDerivativeMarketOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCreateDerivativeMarketOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDERIVATIVEMARKETORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateDerivativeMarketOrderResponse)
  })
_sym_db.RegisterMessage(MsgCreateDerivativeMarketOrderResponse)

MsgCreateBinaryOptionsMarketOrder = _reflection.GeneratedProtocolMessageType('MsgCreateBinaryOptionsMarketOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEBINARYOPTIONSMARKETORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder)
  })
_sym_db.RegisterMessage(MsgCreateBinaryOptionsMarketOrder)

MsgCreateBinaryOptionsMarketOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCreateBinaryOptionsMarketOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrderResponse)
  })
_sym_db.RegisterMessage(MsgCreateBinaryOptionsMarketOrderResponse)

MsgCancelDerivativeOrder = _reflection.GeneratedProtocolMessageType('MsgCancelDerivativeOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELDERIVATIVEORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCancelDerivativeOrder)
  })
_sym_db.RegisterMessage(MsgCancelDerivativeOrder)

MsgCancelDerivativeOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCancelDerivativeOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELDERIVATIVEORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCancelDerivativeOrderResponse)
  })
_sym_db.RegisterMessage(MsgCancelDerivativeOrderResponse)

MsgCancelBinaryOptionsOrder = _reflection.GeneratedProtocolMessageType('MsgCancelBinaryOptionsOrder', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELBINARYOPTIONSORDER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder)
  })
_sym_db.RegisterMessage(MsgCancelBinaryOptionsOrder)

MsgCancelBinaryOptionsOrderResponse = _reflection.GeneratedProtocolMessageType('MsgCancelBinaryOptionsOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCANCELBINARYOPTIONSORDERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgCancelBinaryOptionsOrderResponse)
  })
_sym_db.RegisterMessage(MsgCancelBinaryOptionsOrderResponse)

OrderData = _reflection.GeneratedProtocolMessageType('OrderData', (_message.Message,), {
  'DESCRIPTOR' : _ORDERDATA,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.OrderData)
  })
_sym_db.RegisterMessage(OrderData)

MsgBatchCancelDerivativeOrders = _reflection.GeneratedProtocolMessageType('MsgBatchCancelDerivativeOrders', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCANCELDERIVATIVEORDERS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders)
  })
_sym_db.RegisterMessage(MsgBatchCancelDerivativeOrders)

MsgBatchCancelDerivativeOrdersResponse = _reflection.GeneratedProtocolMessageType('MsgBatchCancelDerivativeOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgBatchCancelDerivativeOrdersResponse)
  })
_sym_db.RegisterMessage(MsgBatchCancelDerivativeOrdersResponse)

MsgSubaccountTransfer = _reflection.GeneratedProtocolMessageType('MsgSubaccountTransfer', (_message.Message,), {
  'DESCRIPTOR' : _MSGSUBACCOUNTTRANSFER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgSubaccountTransfer)
  })
_sym_db.RegisterMessage(MsgSubaccountTransfer)

MsgSubaccountTransferResponse = _reflection.GeneratedProtocolMessageType('MsgSubaccountTransferResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSUBACCOUNTTRANSFERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgSubaccountTransferResponse)
  })
_sym_db.RegisterMessage(MsgSubaccountTransferResponse)

MsgExternalTransfer = _reflection.GeneratedProtocolMessageType('MsgExternalTransfer', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXTERNALTRANSFER,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgExternalTransfer)
  })
_sym_db.RegisterMessage(MsgExternalTransfer)

MsgExternalTransferResponse = _reflection.GeneratedProtocolMessageType('MsgExternalTransferResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXTERNALTRANSFERRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgExternalTransferResponse)
  })
_sym_db.RegisterMessage(MsgExternalTransferResponse)

MsgLiquidatePosition = _reflection.GeneratedProtocolMessageType('MsgLiquidatePosition', (_message.Message,), {
  'DESCRIPTOR' : _MSGLIQUIDATEPOSITION,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgLiquidatePosition)
  })
_sym_db.RegisterMessage(MsgLiquidatePosition)

MsgLiquidatePositionResponse = _reflection.GeneratedProtocolMessageType('MsgLiquidatePositionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGLIQUIDATEPOSITIONRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgLiquidatePositionResponse)
  })
_sym_db.RegisterMessage(MsgLiquidatePositionResponse)

MsgIncreasePositionMargin = _reflection.GeneratedProtocolMessageType('MsgIncreasePositionMargin', (_message.Message,), {
  'DESCRIPTOR' : _MSGINCREASEPOSITIONMARGIN,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgIncreasePositionMargin)
  })
_sym_db.RegisterMessage(MsgIncreasePositionMargin)

MsgIncreasePositionMarginResponse = _reflection.GeneratedProtocolMessageType('MsgIncreasePositionMarginResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGINCREASEPOSITIONMARGINRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgIncreasePositionMarginResponse)
  })
_sym_db.RegisterMessage(MsgIncreasePositionMarginResponse)

MsgExec = _reflection.GeneratedProtocolMessageType('MsgExec', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXEC,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgExec)
  })
_sym_db.RegisterMessage(MsgExec)

MsgExecResponse = _reflection.GeneratedProtocolMessageType('MsgExecResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXECRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgExecResponse)
  })
_sym_db.RegisterMessage(MsgExecResponse)

SpotMarketParamUpdateProposal = _reflection.GeneratedProtocolMessageType('SpotMarketParamUpdateProposal', (_message.Message,), {
  'DESCRIPTOR' : _SPOTMARKETPARAMUPDATEPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotMarketParamUpdateProposal)
  })
_sym_db.RegisterMessage(SpotMarketParamUpdateProposal)

ExchangeEnableProposal = _reflection.GeneratedProtocolMessageType('ExchangeEnableProposal', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEENABLEPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ExchangeEnableProposal)
  })
_sym_db.RegisterMessage(ExchangeEnableProposal)

BatchExchangeModificationProposal = _reflection.GeneratedProtocolMessageType('BatchExchangeModificationProposal', (_message.Message,), {
  'DESCRIPTOR' : _BATCHEXCHANGEMODIFICATIONPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchExchangeModificationProposal)
  })
_sym_db.RegisterMessage(BatchExchangeModificationProposal)

SpotMarketLaunchProposal = _reflection.GeneratedProtocolMessageType('SpotMarketLaunchProposal', (_message.Message,), {
  'DESCRIPTOR' : _SPOTMARKETLAUNCHPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotMarketLaunchProposal)
  })
_sym_db.RegisterMessage(SpotMarketLaunchProposal)

PerpetualMarketLaunchProposal = _reflection.GeneratedProtocolMessageType('PerpetualMarketLaunchProposal', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETLAUNCHPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PerpetualMarketLaunchProposal)
  })
_sym_db.RegisterMessage(PerpetualMarketLaunchProposal)

BinaryOptionsMarketLaunchProposal = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketLaunchProposal', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETLAUNCHPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketLaunchProposal)

ExpiryFuturesMarketLaunchProposal = _reflection.GeneratedProtocolMessageType('ExpiryFuturesMarketLaunchProposal', (_message.Message,), {
  'DESCRIPTOR' : _EXPIRYFUTURESMARKETLAUNCHPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal)
  })
_sym_db.RegisterMessage(ExpiryFuturesMarketLaunchProposal)

DerivativeMarketParamUpdateProposal = _reflection.GeneratedProtocolMessageType('DerivativeMarketParamUpdateProposal', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKETPARAMUPDATEPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal)
  })
_sym_db.RegisterMessage(DerivativeMarketParamUpdateProposal)

MarketForcedSettlementProposal = _reflection.GeneratedProtocolMessageType('MarketForcedSettlementProposal', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFORCEDSETTLEMENTPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MarketForcedSettlementProposal)
  })
_sym_db.RegisterMessage(MarketForcedSettlementProposal)

UpdateDenomDecimalsProposal = _reflection.GeneratedProtocolMessageType('UpdateDenomDecimalsProposal', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDENOMDECIMALSPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.UpdateDenomDecimalsProposal)
  })
_sym_db.RegisterMessage(UpdateDenomDecimalsProposal)

DenomDecimals = _reflection.GeneratedProtocolMessageType('DenomDecimals', (_message.Message,), {
  'DESCRIPTOR' : _DENOMDECIMALS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DenomDecimals)
  })
_sym_db.RegisterMessage(DenomDecimals)

BinaryOptionsMarketParamUpdateProposal = _reflection.GeneratedProtocolMessageType('BinaryOptionsMarketParamUpdateProposal', (_message.Message,), {
  'DESCRIPTOR' : _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal)
  })
_sym_db.RegisterMessage(BinaryOptionsMarketParamUpdateProposal)

ProviderOracleParams = _reflection.GeneratedProtocolMessageType('ProviderOracleParams', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERORACLEPARAMS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ProviderOracleParams)
  })
_sym_db.RegisterMessage(ProviderOracleParams)

OracleParams = _reflection.GeneratedProtocolMessageType('OracleParams', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEPARAMS,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.OracleParams)
  })
_sym_db.RegisterMessage(OracleParams)

TradingRewardCampaignLaunchProposal = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignLaunchProposal', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignLaunchProposal)
  })
_sym_db.RegisterMessage(TradingRewardCampaignLaunchProposal)

TradingRewardCampaignUpdateProposal = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignUpdateProposal', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal)
  })
_sym_db.RegisterMessage(TradingRewardCampaignUpdateProposal)

RewardPointUpdate = _reflection.GeneratedProtocolMessageType('RewardPointUpdate', (_message.Message,), {
  'DESCRIPTOR' : _REWARDPOINTUPDATE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.RewardPointUpdate)
  })
_sym_db.RegisterMessage(RewardPointUpdate)

TradingRewardPendingPointsUpdateProposal = _reflection.GeneratedProtocolMessageType('TradingRewardPendingPointsUpdateProposal', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardPendingPointsUpdateProposal)
  })
_sym_db.RegisterMessage(TradingRewardPendingPointsUpdateProposal)

FeeDiscountProposal = _reflection.GeneratedProtocolMessageType('FeeDiscountProposal', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountProposal)
  })
_sym_db.RegisterMessage(FeeDiscountProposal)

BatchCommunityPoolSpendProposal = _reflection.GeneratedProtocolMessageType('BatchCommunityPoolSpendProposal', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCOMMUNITYPOOLSPENDPROPOSAL,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCommunityPoolSpendProposal)
  })
_sym_db.RegisterMessage(BatchCommunityPoolSpendProposal)

MsgRewardsOptOut = _reflection.GeneratedProtocolMessageType('MsgRewardsOptOut', (_message.Message,), {
  'DESCRIPTOR' : _MSGREWARDSOPTOUT,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgRewardsOptOut)
  })
_sym_db.RegisterMessage(MsgRewardsOptOut)

MsgRewardsOptOutResponse = _reflection.GeneratedProtocolMessageType('MsgRewardsOptOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREWARDSOPTOUTRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgRewardsOptOutResponse)
  })
_sym_db.RegisterMessage(MsgRewardsOptOutResponse)

MsgAdminUpdateBinaryOptionsMarket = _reflection.GeneratedProtocolMessageType('MsgAdminUpdateBinaryOptionsMarket', (_message.Message,), {
  'DESCRIPTOR' : _MSGADMINUPDATEBINARYOPTIONSMARKET,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket)
  })
_sym_db.RegisterMessage(MsgAdminUpdateBinaryOptionsMarket)

MsgAdminUpdateBinaryOptionsMarketResponse = _reflection.GeneratedProtocolMessageType('MsgAdminUpdateBinaryOptionsMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarketResponse)
  })
_sym_db.RegisterMessage(MsgAdminUpdateBinaryOptionsMarketResponse)


DESCRIPTOR._options = None
_EXCHANGETYPE.values_by_name["EXCHANGE_UNSPECIFIED"]._options = None
_EXCHANGETYPE.values_by_name["SPOT"]._options = None
_EXCHANGETYPE.values_by_name["DERIVATIVES"]._options = None
_MSGDEPOSIT.fields_by_name['amount']._options = None
_MSGDEPOSIT._options = None
_MSGWITHDRAW.fields_by_name['amount']._options = None
_MSGWITHDRAW._options = None
_MSGCREATESPOTLIMITORDER.fields_by_name['order']._options = None
_MSGCREATESPOTLIMITORDER._options = None
_MSGCREATESPOTLIMITORDERRESPONSE._options = None
_MSGBATCHCREATESPOTLIMITORDERS.fields_by_name['orders']._options = None
_MSGBATCHCREATESPOTLIMITORDERS._options = None
_MSGBATCHCREATESPOTLIMITORDERSRESPONSE._options = None
_MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
_MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
_MSGINSTANTSPOTMARKETLAUNCH._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['initial_margin_ratio']._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
_MSGINSTANTPERPETUALMARKETLAUNCH._options = None
_MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
_MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
_MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
_MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
_MSGINSTANTBINARYOPTIONSMARKETLAUNCH._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['initial_margin_ratio']._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._options = None
_MSGCREATESPOTMARKETORDER.fields_by_name['order']._options = None
_MSGCREATESPOTMARKETORDER._options = None
_MSGCREATESPOTMARKETORDERRESPONSE._options = None
_MSGCREATEDERIVATIVELIMITORDER.fields_by_name['order']._options = None
_MSGCREATEDERIVATIVELIMITORDER._options = None
_MSGCREATEDERIVATIVELIMITORDERRESPONSE._options = None
_MSGCREATEBINARYOPTIONSLIMITORDER.fields_by_name['order']._options = None
_MSGCREATEBINARYOPTIONSLIMITORDER._options = None
_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._options = None
_MSGBATCHCREATEDERIVATIVELIMITORDERS.fields_by_name['orders']._options = None
_MSGBATCHCREATEDERIVATIVELIMITORDERS._options = None
_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._options = None
_MSGCANCELSPOTORDER._options = None
_MSGBATCHCANCELSPOTORDERS.fields_by_name['data']._options = None
_MSGBATCHCANCELSPOTORDERS._options = None
_MSGBATCHCANCELSPOTORDERSRESPONSE._options = None
_MSGBATCHCANCELBINARYOPTIONSORDERS.fields_by_name['data']._options = None
_MSGBATCHCANCELBINARYOPTIONSORDERS._options = None
_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._options = None
_MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_cancel']._options = None
_MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_cancel']._options = None
_MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_create']._options = None
_MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_create']._options = None
_MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_cancel']._options = None
_MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_create']._options = None
_MSGBATCHUPDATEORDERS._options = None
_MSGBATCHUPDATEORDERSRESPONSE._options = None
_MSGCREATEDERIVATIVEMARKETORDER.fields_by_name['order']._options = None
_MSGCREATEDERIVATIVEMARKETORDER._options = None
_MSGCREATEDERIVATIVEMARKETORDERRESPONSE._options = None
_MSGCREATEBINARYOPTIONSMARKETORDER.fields_by_name['order']._options = None
_MSGCREATEBINARYOPTIONSMARKETORDER._options = None
_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._options = None
_MSGCANCELDERIVATIVEORDER._options = None
_MSGCANCELBINARYOPTIONSORDER._options = None
_MSGBATCHCANCELDERIVATIVEORDERS.fields_by_name['data']._options = None
_MSGBATCHCANCELDERIVATIVEORDERS._options = None
_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._options = None
_MSGSUBACCOUNTTRANSFER.fields_by_name['amount']._options = None
_MSGEXTERNALTRANSFER.fields_by_name['amount']._options = None
_MSGLIQUIDATEPOSITION.fields_by_name['order']._options = None
_MSGINCREASEPOSITIONMARGIN.fields_by_name['amount']._options = None
_MSGEXEC.fields_by_name['bank_funds']._options = None
_MSGEXEC.fields_by_name['deposit_funds']._options = None
_MSGEXEC._options = None
_SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
_SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_SPOTMARKETPARAMUPDATEPROPOSAL._options = None
_EXCHANGEENABLEPROPOSAL._options = None
_BATCHEXCHANGEMODIFICATIONPROPOSAL._options = None
_SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_SPOTMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_SPOTMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_SPOTMARKETLAUNCHPROPOSAL._options = None
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_PERPETUALMARKETLAUNCHPROPOSAL._options = None
_BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_BINARYOPTIONSMARKETLAUNCHPROPOSAL._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_EXPIRYFUTURESMARKETLAUNCHPROPOSAL._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyInterestRate']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyFundingRateCap']._options = None
_DERIVATIVEMARKETPARAMUPDATEPROPOSAL._options = None
_MARKETFORCEDSETTLEMENTPROPOSAL.fields_by_name['settlement_price']._options = None
_MARKETFORCEDSETTLEMENTPROPOSAL._options = None
_UPDATEDENOMDECIMALSPROPOSAL._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['settlement_price']._options = None
_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._options = None
_TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._options = None
_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._options = None
_REWARDPOINTUPDATE.fields_by_name['new_points']._options = None
_TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._options = None
_FEEDISCOUNTPROPOSAL._options = None
_BATCHCOMMUNITYPOOLSPENDPROPOSAL._options = None
_MSGADMINUPDATEBINARYOPTIONSMARKET.fields_by_name['settlement_price']._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.exchange.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=15973,
  serialized_end=20030,
  methods=[
  _descriptor.MethodDescriptor(
    name='Deposit',
    full_name='injective.exchange.v1beta1.Msg.Deposit',
    index=0,
    containing_service=None,
    input_type=_MSGDEPOSIT,
    output_type=_MSGDEPOSITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Withdraw',
    full_name='injective.exchange.v1beta1.Msg.Withdraw',
    index=1,
    containing_service=None,
    input_type=_MSGWITHDRAW,
    output_type=_MSGWITHDRAWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InstantSpotMarketLaunch',
    full_name='injective.exchange.v1beta1.Msg.InstantSpotMarketLaunch',
    index=2,
    containing_service=None,
    input_type=_MSGINSTANTSPOTMARKETLAUNCH,
    output_type=_MSGINSTANTSPOTMARKETLAUNCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InstantPerpetualMarketLaunch',
    full_name='injective.exchange.v1beta1.Msg.InstantPerpetualMarketLaunch',
    index=3,
    containing_service=None,
    input_type=_MSGINSTANTPERPETUALMARKETLAUNCH,
    output_type=_MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InstantExpiryFuturesMarketLaunch',
    full_name='injective.exchange.v1beta1.Msg.InstantExpiryFuturesMarketLaunch',
    index=4,
    containing_service=None,
    input_type=_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH,
    output_type=_MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSpotLimitOrder',
    full_name='injective.exchange.v1beta1.Msg.CreateSpotLimitOrder',
    index=5,
    containing_service=None,
    input_type=_MSGCREATESPOTLIMITORDER,
    output_type=_MSGCREATESPOTLIMITORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchCreateSpotLimitOrders',
    full_name='injective.exchange.v1beta1.Msg.BatchCreateSpotLimitOrders',
    index=6,
    containing_service=None,
    input_type=_MSGBATCHCREATESPOTLIMITORDERS,
    output_type=_MSGBATCHCREATESPOTLIMITORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSpotMarketOrder',
    full_name='injective.exchange.v1beta1.Msg.CreateSpotMarketOrder',
    index=7,
    containing_service=None,
    input_type=_MSGCREATESPOTMARKETORDER,
    output_type=_MSGCREATESPOTMARKETORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelSpotOrder',
    full_name='injective.exchange.v1beta1.Msg.CancelSpotOrder',
    index=8,
    containing_service=None,
    input_type=_MSGCANCELSPOTORDER,
    output_type=_MSGCANCELSPOTORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchCancelSpotOrders',
    full_name='injective.exchange.v1beta1.Msg.BatchCancelSpotOrders',
    index=9,
    containing_service=None,
    input_type=_MSGBATCHCANCELSPOTORDERS,
    output_type=_MSGBATCHCANCELSPOTORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchUpdateOrders',
    full_name='injective.exchange.v1beta1.Msg.BatchUpdateOrders',
    index=10,
    containing_service=None,
    input_type=_MSGBATCHUPDATEORDERS,
    output_type=_MSGBATCHUPDATEORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Exec',
    full_name='injective.exchange.v1beta1.Msg.Exec',
    index=11,
    containing_service=None,
    input_type=_MSGEXEC,
    output_type=_MSGEXECRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDerivativeLimitOrder',
    full_name='injective.exchange.v1beta1.Msg.CreateDerivativeLimitOrder',
    index=12,
    containing_service=None,
    input_type=_MSGCREATEDERIVATIVELIMITORDER,
    output_type=_MSGCREATEDERIVATIVELIMITORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchCreateDerivativeLimitOrders',
    full_name='injective.exchange.v1beta1.Msg.BatchCreateDerivativeLimitOrders',
    index=13,
    containing_service=None,
    input_type=_MSGBATCHCREATEDERIVATIVELIMITORDERS,
    output_type=_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDerivativeMarketOrder',
    full_name='injective.exchange.v1beta1.Msg.CreateDerivativeMarketOrder',
    index=14,
    containing_service=None,
    input_type=_MSGCREATEDERIVATIVEMARKETORDER,
    output_type=_MSGCREATEDERIVATIVEMARKETORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelDerivativeOrder',
    full_name='injective.exchange.v1beta1.Msg.CancelDerivativeOrder',
    index=15,
    containing_service=None,
    input_type=_MSGCANCELDERIVATIVEORDER,
    output_type=_MSGCANCELDERIVATIVEORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchCancelDerivativeOrders',
    full_name='injective.exchange.v1beta1.Msg.BatchCancelDerivativeOrders',
    index=16,
    containing_service=None,
    input_type=_MSGBATCHCANCELDERIVATIVEORDERS,
    output_type=_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InstantBinaryOptionsMarketLaunch',
    full_name='injective.exchange.v1beta1.Msg.InstantBinaryOptionsMarketLaunch',
    index=17,
    containing_service=None,
    input_type=_MSGINSTANTBINARYOPTIONSMARKETLAUNCH,
    output_type=_MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBinaryOptionsLimitOrder',
    full_name='injective.exchange.v1beta1.Msg.CreateBinaryOptionsLimitOrder',
    index=18,
    containing_service=None,
    input_type=_MSGCREATEBINARYOPTIONSLIMITORDER,
    output_type=_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBinaryOptionsMarketOrder',
    full_name='injective.exchange.v1beta1.Msg.CreateBinaryOptionsMarketOrder',
    index=19,
    containing_service=None,
    input_type=_MSGCREATEBINARYOPTIONSMARKETORDER,
    output_type=_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelBinaryOptionsOrder',
    full_name='injective.exchange.v1beta1.Msg.CancelBinaryOptionsOrder',
    index=20,
    containing_service=None,
    input_type=_MSGCANCELBINARYOPTIONSORDER,
    output_type=_MSGCANCELBINARYOPTIONSORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchCancelBinaryOptionsOrders',
    full_name='injective.exchange.v1beta1.Msg.BatchCancelBinaryOptionsOrders',
    index=21,
    containing_service=None,
    input_type=_MSGBATCHCANCELBINARYOPTIONSORDERS,
    output_type=_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountTransfer',
    full_name='injective.exchange.v1beta1.Msg.SubaccountTransfer',
    index=22,
    containing_service=None,
    input_type=_MSGSUBACCOUNTTRANSFER,
    output_type=_MSGSUBACCOUNTTRANSFERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExternalTransfer',
    full_name='injective.exchange.v1beta1.Msg.ExternalTransfer',
    index=23,
    containing_service=None,
    input_type=_MSGEXTERNALTRANSFER,
    output_type=_MSGEXTERNALTRANSFERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LiquidatePosition',
    full_name='injective.exchange.v1beta1.Msg.LiquidatePosition',
    index=24,
    containing_service=None,
    input_type=_MSGLIQUIDATEPOSITION,
    output_type=_MSGLIQUIDATEPOSITIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IncreasePositionMargin',
    full_name='injective.exchange.v1beta1.Msg.IncreasePositionMargin',
    index=25,
    containing_service=None,
    input_type=_MSGINCREASEPOSITIONMARGIN,
    output_type=_MSGINCREASEPOSITIONMARGINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RewardsOptOut',
    full_name='injective.exchange.v1beta1.Msg.RewardsOptOut',
    index=26,
    containing_service=None,
    input_type=_MSGREWARDSOPTOUT,
    output_type=_MSGREWARDSOPTOUTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AdminUpdateBinaryOptionsMarket',
    full_name='injective.exchange.v1beta1.Msg.AdminUpdateBinaryOptionsMarket',
    index=27,
    containing_service=None,
    input_type=_MSGADMINUPDATEBINARYOPTIONSMARKET,
    output_type=_MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
